@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2015 IBM Corporation and others.
+ * Copyright (c) 2008, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,20 +12,23 @@ package org.eclipse.swt.tools.internal;
 
 import java.io.*;
 import java.util.*;
+import java.util.Map.*;
+import java.util.stream.*;
 
 import javax.xml.parsers.*;
 
 import org.w3c.dom.*;
+import org.w3c.dom.Node;
 import org.xml.sax.*;
 @SuppressWarnings("unchecked")
 public class MacGenerator {
 	String[] xmls;
 	Document[] documents;
-	String outputDir, outputLibDir, extrasDir, mainClassName;
+	String outputDir, outputLibDir, extrasDir, mainClassName, selectorEnumName;
 	String delimiter = System.getProperty("line.separator");
 	boolean generate64Code;
 	PrintWriter out;
-	
+
 	public static boolean BUILD_C_SOURCE = true;
 	public static boolean GENERATE_ALLOC = true;
 	public static boolean GENERATE_STRUCTS = false;
@@ -132,7 +135,7 @@ int getLevel(Node node) {
 
 void merge(Document document, Document extraDocument) {
 	if (extraDocument == null) return;
-	
+
 	/* Build a lookup table for extraDocument */
 	HashMap<String, Node> extras = new HashMap<>();
 	buildLookup(extraDocument, extras);
@@ -140,25 +143,21 @@ void merge(Document document, Document extraDocument) {
 	/* Merge attributes on existing elements building a lookup table for document */
 	HashMap<String, Node> lookup = new HashMap<>();
 	merge(document, extras, lookup);
-	
-	/* 
+
+	/*
 	 * Merge new elements. Extras at this point contains only elements that were
 	 * not found in the document.
 	 */
 	ArrayList<Node> sortedNodes = Collections.list(Collections.enumeration(extras.values()));
-	Collections.sort(sortedNodes, new Comparator<Object>() {
-		@Override
-		public int compare(Object arg0, Object arg1) {
-			int compare = getLevel((Node)arg0) - getLevel((Node)arg1);
-			if (compare == 0) {
-				return ((Node)arg0).getNodeName().compareTo(((Node)arg1).getNodeName());
-			}
-			return compare;
+	Collections.sort(sortedNodes, (arg0, arg1) -> {
+		int compare = getLevel(arg0) - getLevel(arg1);
+		if (compare == 0) {
+			return arg0.getNodeName().compareTo(arg1.getNodeName());
 		}
+		return compare;
 	});
 	String delimiter = System.getProperty("line.separator");
-	for (Iterator<Node> iterator = sortedNodes.iterator(); iterator.hasNext();) {
-		Node node = iterator.next();
+	for (Node node : sortedNodes) {
 		String name = node.getNodeName();
 		if ("arg".equals(name) || "retval".equals(name)) {
 			if (!sortedNodes.contains(node.getParentNode())) continue;
@@ -183,7 +182,7 @@ void merge(Document document, Document extraDocument) {
 
 public void generate(ProgressMonitor progress) {
 	if (progress != null) {
-		progress.setTotal(BUILD_C_SOURCE ? 4 : 3);
+		progress.setTotal(BUILD_C_SOURCE ? 5 : 4);
 		progress.setMessage("extra attributes...");
 	}
 	generateExtraAttributes();
@@ -196,6 +195,11 @@ public void generate(ProgressMonitor progress) {
 		progress.step();
 		progress.setMessage("classes...");
 	}
+	generateSelectorEnum();
+	if (progress != null) {
+		progress.step();
+		progress.setMessage("selector enum...");
+	}
 	generateClasses();
 	if (GENERATE_STRUCTS) {
 		if (progress != null) {
@@ -227,7 +231,7 @@ void generateCSource() {
 String fixDelimiter(String str) {
 	if (delimiter.equals("\n")) return str;
 	int index = 0, length = str.length();
-	StringBuffer buffer = new StringBuffer();
+	StringBuilder buffer = new StringBuilder();
 	while (index != -1) {
 		int start = index;
 		index = str.indexOf('\n', start);
@@ -266,9 +270,8 @@ String getParamName(Node param, int i) {
 	return paramName;
 }
 
-void generateFields(String structName, ArrayList<?> fields) {
-	for (Iterator<?> iterator = fields.iterator(); iterator.hasNext();) {
-		Node field = (Node)iterator.next();
+void generateFields(ArrayList<Node> fields) {
+	for (Node field : fields) {
 		NamedNodeMap fieldAttributes = field.getAttributes();
 		String fieldName = fieldAttributes.getNamedItem("name").getNodeValue();
 		String type = getJavaType(field), type64 = getJavaType64(field);
@@ -284,7 +287,7 @@ void generateFields(String structName, ArrayList<?> fields) {
 		out(fieldName);
 		if (isStruct(field)) {
 			out(" = new ");
-			String clazz = fieldAttributes.getNamedItem("declared_type").getNodeValue();
+			String clazz = getDeclaredType(fieldAttributes, field);
 			out (clazz);
 			out ("()");
 		}
@@ -293,22 +296,45 @@ void generateFields(String structName, ArrayList<?> fields) {
 	}
 }
 
-void generateMethods(String className, ArrayList<?> methods) {
-	for (Iterator<?> iterator = methods.iterator(); iterator.hasNext();) {
-		Node method = (Node)iterator.next();
+private String getDeclaredType(NamedNodeMap map, Node location) {
+	Node declaredType = map.getNamedItem("declared_type");
+	String value = declaredType != null ? declaredType.getNodeValue() : null;
+	if(value == null) {
+		System.err.printf("Unable to detect declared_type. Check bridge file! It might have been removed, inheritance changed, etc. It could also be an issue with gen_bridge_metadata. Location: %s %n", toDebugLocation(location));
+		return "nodeclaredtype";
+	}
+
+	// strip any _Nullable and _Nonnull annotations
+	value = value.replace("_Nullable", "").replace("_Nonnull", "").replace("_Null_unspecified", "");
+
+	// also remove any white spaces
+	value = value.chars().filter((c)->!Character.isWhitespace(c)).mapToObj(c -> String.valueOf((char)c)).collect(Collectors.joining());
+
+	return value;
+}
+
+void generateMethods(String className, ArrayList<Node> methods) {
+	for (Node method : methods) {
 		NamedNodeMap mthAttributes = method.getAttributes();
 		String sel = mthAttributes.getNamedItem("selector").getNodeValue();
 		if ("NSObject".equals(className)) {
 		    if ("alloc".equals(sel) || "dealloc".equals(sel)) continue;
 		}
 		out("public ");
-		boolean isStatic = isStatic(method); 
+		boolean isStatic = isStatic(method);
 		if (isStatic) out("static ");
 		Node returnNode = getReturnNode(method.getChildNodes());
 		if (getType(returnNode).equals("void")) returnNode = null;
 		String returnType = "", returnType64 = "";
 		if (returnNode != null) {
 			String type = returnType = getJavaType(returnNode), type64 = returnType64 = getJavaType64(returnNode);
+
+			// convert "instancetype" to class name
+			if(type.equals("instancetype")) {
+				type = returnType = className;
+				type64 = returnType64 = className;
+			}
+
 			out(type);
 			if (!type.equals(type64)) {
 				out(" /*");
@@ -561,7 +587,7 @@ void generateExtraMethods(String className) {
 		out("}");
 		outln();
 		outln();
-	}	
+	}
 }
 
 TreeMap<String, Object[]> getGeneratedClasses() {
@@ -587,7 +613,7 @@ TreeMap<String, Object[]> getGeneratedClasses() {
 					Node method = methodList.item(j);
 					if ("method".equals(method.getNodeName()) && getGen(method)) {
 						methods.add(method);
-					}					
+					}
 				}
 			}
 		}
@@ -636,21 +662,20 @@ void copyClassMethodsDown(final Map<String, Object[]> classes) {
 				level++;
 				superclass = getSuperclassName((Node)classes.get(superclass)[0]);
 			}
-			return level;			
+			return level;
 		}
 		@Override
 		public int compare(Object arg0, Object arg1) {
-			return getHierarchyLevel((Node)((Object[])arg0)[0]) - getHierarchyLevel((Node)((Object[])arg1)[0]);  
+			return getHierarchyLevel((Node)((Object[])arg0)[0]) - getHierarchyLevel((Node)((Object[])arg1)[0]);
 		}
 	});
-	for (Iterator<Object[]> iterator = sortedClasses.iterator(); iterator.hasNext();) {
-		Object[] clazz = iterator.next();
+	for (Object[] clazz : sortedClasses) {
 		Node node = (Node)clazz[0];
 		ArrayList<Node> methods = (ArrayList<Node>)clazz[1];
 		Object[] superclass = classes.get(getSuperclassName(node));
 		if (superclass != null) {
-			for (Iterator<?> iterator2 = ((ArrayList<?>)superclass[1]).iterator(); iterator2.hasNext();) {
-				Node method = (Node) iterator2.next();
+			for (Iterator<Node> iterator2 = ((ArrayList<Node>)superclass[1]).iterator(); iterator2.hasNext();) {
+				Node method = iterator2.next();
 				if (isStatic(method)) {
 					methods.add(method);
 				}
@@ -664,34 +689,31 @@ String getSuperclassName (Node node) {
 	Node superclass = attributes.getNamedItem("swt_superclass");
 	if (superclass != null) {
 		return superclass.getNodeValue();
-	} else {
-		Node name = attributes.getNamedItem("name");
-		if (name.getNodeValue().equals("NSObject")) {
-			return "id";
-		} else {
-			return "NSObject";
-		}
+	} 
+	Node name = attributes.getNamedItem("name");
+	if (name.getNodeValue().equals("NSObject")) {
+		return "id";
 	}
+	return "NSObject";
 }
 
 void generateClasses() {
-	MetaData metaData = new MetaData(mainClassName);	
+	MetaData metaData = new MetaData(mainClassName);
 	TreeMap<String, Object[]> classes = getGeneratedClasses();
 	copyClassMethodsDown(classes);
-	
-	Set<String> classNames = classes.keySet();
-	for (Iterator<String> iterator = classNames.iterator(); iterator.hasNext();) {
+
+	for (Entry<String, Object[]> clazzes: classes.entrySet()) {
 		CharArrayWriter out = new CharArrayWriter();
 		this.out = new PrintWriter(out);
 
 		out(fixDelimiter(metaData.getCopyright()));
 
-		String className = iterator.next();
-		Object[] clazz = classes.get(className);
+		String className = clazzes.getKey();
+		Object[] clazz = clazzes.getValue();
 		Node node = (Node)clazz[0];
-		ArrayList<?> methods = (ArrayList<?>)clazz[1];
+		ArrayList<Node> methods = (ArrayList<Node>)clazz[1];
 		out("package ");
-		String packageName = getPackageName(mainClassName);
+		String packageName = getPackageName();
 		out(packageName);
 		out(";");
 		outln();
@@ -702,12 +724,12 @@ void generateClasses() {
 		out(getSuperclassName(node));
 		out(" {");
 		outln();
-		outln();		
+		outln();
 		generateExtraMethods(className);
-		generateMethods(className, methods);		
+		generateMethods(className, methods);
 		out("}");
 		outln();
-		
+
 		String fileName = outputDir + packageName.replace('.', '/') + "/" + className + ".java";
 		this.out.flush();
 		output(fileName, out.toCharArray());
@@ -716,21 +738,20 @@ void generateClasses() {
 }
 
 void generateStructs() {
-	MetaData metaData = new MetaData(mainClassName);	
+	MetaData metaData = new MetaData(mainClassName);
 	TreeMap<String, Object[]> structs = getGeneratedStructs();
 
-	Set<String> structNames = structs.keySet();
-	for (Iterator<String> iterator = structNames.iterator(); iterator.hasNext();) {
+	for (Entry<String, Object[]> structEntry: structs.entrySet()) {
 		CharArrayWriter out = new CharArrayWriter();
 		this.out = new PrintWriter(out);
 
 		out(fixDelimiter(metaData.getCopyright()));
 
-		String className = iterator.next();
-		Object[] clazz = structs.get(className);
-		ArrayList<?> methods = (ArrayList<?>)clazz[1];
+		String className = structEntry.getKey();
+		Object[] clazz = structEntry.getValue();
+		ArrayList<Node> methods = (ArrayList<Node>)clazz[1];
 		out("package ");
-		String packageName = getPackageName(mainClassName);
+		String packageName = getPackageName();
 		out(packageName);
 		out(";");
 		outln();
@@ -738,12 +759,12 @@ void generateStructs() {
 		out("public class ");
 		out(className);
 		out(" {");
-		outln();		
-		generateFields(className, methods);		
+		outln();
+		generateFields(methods);
 		generateExtraFields(className);
 		out("}");
 		outln();
-		
+
 		String fileName = outputDir + packageName.replace('.', '/') + "/" + className + ".java";
 		this.out.flush();
 		output(fileName, out.toCharArray());
@@ -768,7 +789,7 @@ void generateMainClass() {
 	String fileName = outputDir + mainClassName.replace('.', '/') + ".java";
 	try (FileInputStream is = new FileInputStream(fileName);
 		InputStreamReader input = new InputStreamReader(new BufferedInputStream(is))){
-		StringBuffer str = new StringBuffer();
+		StringBuilder str = new StringBuilder();
 		char[] buffer = new char[4096];
 		int read;
 		while ((read = input.read(buffer)) != -1) {
@@ -783,7 +804,7 @@ void generateMainClass() {
 		input.close();
 	} catch (IOException e) {
 	}
-	
+
 	out(header);
 	outln();
 	outln();
@@ -791,7 +812,7 @@ void generateMainClass() {
 	out("/** Custom callbacks */");
 	outln();
 	generateCustomCallbacks();
-	outln();	
+	outln();
 	out("/** Classes */");
 	outln();
 	generateClassesConst();
@@ -826,7 +847,7 @@ void generateMainClass() {
 	generateSends(false);
 	outln();
 	generateStructNatives();
-	
+
 	outln();
 	out(footer);
 	this.out.flush();
@@ -834,6 +855,57 @@ void generateMainClass() {
 	this.out = null;
 }
 
+void generateSelectorEnum() {
+	CharArrayWriter out = new CharArrayWriter();
+	this.out = new PrintWriter(out);
+
+	String header = "", footer = "";
+	String fileName = outputDir + selectorEnumName.replace('.', '/') + ".java";
+	try (FileInputStream is = new FileInputStream(fileName);
+		InputStreamReader input = new InputStreamReader(new BufferedInputStream(is))){
+		StringBuilder str = new StringBuilder();
+		char[] buffer = new char[4096];
+		int read;
+		while ((read = input.read(buffer)) != -1) {
+			str.append(buffer, 0, read);
+		}
+		String section = "/** This section is auto generated */";
+		int start = str.indexOf(section) + section.length();
+		int end = str.indexOf(section, start);
+		header = str.substring(0, start);
+		footer = end == -1 ? "\n}" : str.substring(end);
+		input.close();
+	} catch (IOException e) {
+	}
+
+	out(header);
+	outln();
+	outln();
+
+	generateSelectorsEnumLiteral();
+	
+	out(";"); outln();
+	
+	String mainClassShortName = mainClassName.substring(mainClassName.lastIndexOf('.')+1);
+	out("	final String name;"); outln();
+	out("	final long value;"); outln();
+	outln();
+	out("	private Selector(String name) {"); outln();
+	out("		this.name= name;"); outln();
+	out("		this.value = "+mainClassShortName+".sel_registerName(name);"); outln();
+	out("		"+mainClassShortName+".registerSelector(value,this);"); outln();
+	out("	}"); outln();
+	outln();
+	out("	public static Selector valueOf(long value) {"); outln();
+	out("		return "+mainClassShortName+".getSelector(value);"); outln();
+	out("	}"); outln();
+	
+	out(footer);
+	this.out.flush();
+	output(fileName, out.toCharArray());
+	this.out = null;
+}
+
 public Document[] getDocuments() {
 	if (documents == null) {
 		String[] xmls = getXmls();
@@ -843,7 +915,7 @@ public Document[] getDocuments() {
 			Document document = documents[i] = getDocument(xmlPath);
 			if (document == null) continue;
 			if (mainClassName != null && outputDir != null) {
-				String packageName = getPackageName(mainClassName);
+				String packageName = getPackageName();
 				String folder = extrasDir != null ? extrasDir : outputDir + packageName.replace('.', '/');
 				String extrasPath = folder + "/" + getFileName(xmlPath) + ".extras";
 				merge(document, getDocument(extrasPath));
@@ -861,24 +933,17 @@ public String[] getXmls() {
 			list(new File("/System/Library/Frameworks/CoreServices.framework/Frameworks"), array);
 			list(new File("/System/Library/Frameworks/ApplicationServices.framework/Frameworks"), array);
 		} else {
-			String packageName = getPackageName(mainClassName);
+			String packageName = getPackageName();
 			File folder = new File(extrasDir != null ? extrasDir : outputDir + packageName.replace('.', '/'));
-			File[] files = folder.listFiles(new FilenameFilter() {
-				@Override
-				public boolean accept(File dir, String name) {
-					return name.endsWith("Full.bridgesupport");
-				}
-			});
+			File[] files = folder.listFiles((FilenameFilter) (dir, name) -> name.endsWith("Full.bridgesupport"));
+			if(files == null) {
+				files = new File[0];
+			}
 			for (int i = 0; i < files.length; i++) {
 				array.add(files[i].getAbsolutePath());
 			}
 		}
-		Collections.sort(array, new Comparator<Object>() {
-			@Override
-			public int compare(Object o1, Object o2) {
-				return new File((String)o1).getName().compareTo(new File((String)o2).getName());
-			}
-		});
+		Collections.sort(array, (o1, o2) -> new File(o1).getName().compareTo(new File(o2).getName()));
 		xmls = array.toArray(new String[array.size()]);
 	}
 	return xmls;
@@ -886,7 +951,7 @@ public String[] getXmls() {
 
 void saveExtraAttributes(String xmlPath, Document document) {
 	try {
-		String packageName = getPackageName(mainClassName);
+		String packageName = getPackageName();
 		String folder = extrasDir != null ? extrasDir : outputDir + packageName.replace('.', '/');
 		String fileName = folder + "/" + getFileName(xmlPath) + ".extras";
 		ByteArrayOutputStream out = new ByteArrayOutputStream();
@@ -947,6 +1012,10 @@ public void setMainClass(String mainClassName) {
 	this.mainClassName = mainClassName;
 }
 
+public void setSelectorEnum(String selectorEnumName) {
+	this.selectorEnumName = selectorEnumName;
+}
+
 Document getDocument(String xmlPath) {
 	try {
 		InputStream is = null;
@@ -999,11 +1068,11 @@ int indexOfNode(Node node) {
 }
 
 String getKey (Node node) {
-	StringBuffer buffer = new StringBuffer();
+	StringBuilder buffer = new StringBuilder();
 	while (node != null) {
 		if (buffer.length() > 0) buffer.append("_");
 		String name = node.getNodeName();
-		StringBuffer key = new StringBuffer(name);
+		StringBuilder key = new StringBuilder(name);
 		if ("arg".equals(name)) {
 			key.append("-");
 			key.append(indexOfNode(node));
@@ -1070,7 +1139,7 @@ void merge(Node node, HashMap<String, Node> extras, HashMap<String, Node> docLoo
 	}
 }
 
-	
+
 void out(String str) {
 	PrintWriter out = this.out;
 	out.print(str);
@@ -1106,7 +1175,7 @@ void generateConstants() {
 					out(constName);
 					out("();");
 					outln();
-					if (attributes.getNamedItem("declared_type").getNodeValue().equals("NSString*")) {
+					if (getDeclaredType(attributes, node).equals("NSString*")) {
 						out("public static final NSString ");
 						out(constName);
 						out(" = new NSString(");
@@ -1116,7 +1185,7 @@ void generateConstants() {
 					}
 				}
 			}
-		}		
+		}
 	}
 }
 
@@ -1157,6 +1226,8 @@ void generateEnums() {
 						if (isLong && !value.endsWith("L")) out("L");
 						out(";");
 						outln();
+					} else {
+						System.err.printf("No value for enum. Check bridge file! It might have been removed, renamed, etc. Location: %s %n", toDebugLocation(node));
 					}
 				}
 			}
@@ -1235,7 +1306,7 @@ void buildLookup(Node node, HashMap<String, Node> table) {
 	}
 }
 
-boolean isUnique(Node method, ArrayList<?> methods) {
+boolean isUnique(Node method, ArrayList<Node> methods) {
 	String methodName = method.getAttributes().getNamedItem("selector").getNodeValue();
 	String signature = "";
 	NodeList params = method.getChildNodes();
@@ -1247,8 +1318,7 @@ boolean isUnique(Node method, ArrayList<?> methods) {
 	}
 	int index = methodName.indexOf(":");
 	if (index != -1) methodName = methodName.substring(0, index);
-	for (Iterator<?> iterator = methods.iterator(); iterator.hasNext();) {
-		Node other = (Node) iterator.next();
+	for (Node other : methods) {
 		NamedNodeMap attributes = other.getAttributes();
 		Node otherSel = null;
 		if (attributes != null) otherSel = attributes.getNamedItem("selector");
@@ -1301,15 +1371,56 @@ void generateSelectorsConst() {
 		set.add("alloc");
 		set.add("dealloc");
 	}
-	for (Iterator<String> iterator = set.iterator(); iterator.hasNext();) {
-		String sel = iterator.next();
+	out ("private static java.util.Map<Long,Selector> SELECTORS;"); outln();
+	out ("public static void registerSelector (Long value, Selector selector) {"); outln();
+	out ("	if (SELECTORS == null) {"); outln();
+	out ("		SELECTORS = new java.util.HashMap<>();"); outln();
+	out ("	}"); outln();
+	out ("	SELECTORS.put(value, selector);"); outln();
+	out ("}"); outln();
+	out ("public static Selector getSelector (long value) {"); outln();
+	out ("	return SELECTORS.get(value);"); outln();
+	out ("}"); outln();
+	for (String sel : set) {
 		String selConst = getSelConst(sel);
 		out("public static final int /*long*/ ");
 		out(selConst);
 		out(" = ");
-		out("sel_registerName(\"");
-		out(sel);
-		out("\");");
+		out("Selector."+selConst+".value;");
+		outln();
+	}
+}
+
+void generateSelectorsEnumLiteral() {
+	TreeSet<String> set = new TreeSet<>();
+	for (int x = 0; x < xmls.length; x++) {
+		Document document = documents[x];
+		if (document == null) continue;
+		NodeList list = document.getDocumentElement().getChildNodes();
+		for (int i = 0; i < list.getLength(); i++) {
+			Node node = list.item(i);
+			if ("class".equals(node.getNodeName()) || "informal_protocol".equals(node.getNodeName())) {
+				if (getGen(node)) {
+					NodeList methods = node.getChildNodes();
+					for (int j = 0; j < methods.getLength(); j++) {
+						Node method = methods.item(j);
+						if (getGen(method)) {
+							NamedNodeMap mthAttributes = method.getAttributes();
+							String sel = mthAttributes.getNamedItem("selector").getNodeValue();
+							set.add(sel);
+						}
+					}
+				}
+			}
+		}
+	}
+	if (set.size() > 0) {
+		set.add("alloc");
+		set.add("dealloc");
+	}
+	for (String sel: set) {
+		String selConst = getSelConst(sel);
+		out("	, "+selConst+"(\""+sel+"\")");
 		outln();
 	}
 }
@@ -1329,8 +1440,7 @@ void generateStructNatives() {
 	}
 	out("/** Sizeof natives */");
 	outln();
-	for (Iterator<String> iterator = set.iterator(); iterator.hasNext();) {
-		String struct = iterator.next();
+	for (String struct : set) {
 		out("public static final native int ");
 		out(struct);
 		out("_sizeof();");
@@ -1340,8 +1450,7 @@ void generateStructNatives() {
 	out("/** Memmove natives */");
 	outln();
 	outln();
-	for (Iterator<String> iterator = set.iterator(); iterator.hasNext();) {
-		String struct = iterator.next();
+	for (String struct : set) {
 		out("/**");
 		outln();
 		out(" * @param dest cast=(void *),flags=no_in critical");
@@ -1374,8 +1483,8 @@ void generateStructNatives() {
 
 String buildSend(Node method, boolean tags, boolean only64, boolean superCall) {
 	Node returnNode = getReturnNode(method.getChildNodes());
-	StringBuffer buffer = new StringBuffer();
-	buffer.append("public static final native "); 
+	StringBuilder buffer = new StringBuilder();
+	buffer.append("public static final native ");
 	if (returnNode != null && isStruct(returnNode)) {
 		buffer.append("void ");
 		buffer.append(superCall ? "objc_msgSendSuper_stret" : "objc_msgSend_stret");
@@ -1399,7 +1508,7 @@ String buildSend(Node method, boolean tags, boolean only64, boolean superCall) {
 	} else {
 		if (only64) {
 			buffer.append("long");
-		} else {		
+		} else {
 			if (tags) {
 				buffer.append("int /*long*/");
 			} else {
@@ -1460,7 +1569,7 @@ String buildSend(Node method, boolean tags, boolean only64, boolean superCall) {
 
 String getCType (Node node) {
 	NamedNodeMap attributes = node.getAttributes();
-	return attributes.getNamedItem("declared_type").getNodeValue();
+	return getDeclaredType(attributes, node);
 }
 
 Node findNSObjectMethod(Node method) {
@@ -1509,13 +1618,13 @@ void generateCustomCallbacks() {
 			}
 		}
 	}
-	for (Iterator<String> iterator = set.keySet().iterator(); iterator.hasNext();) {
-		String key = iterator.next();
-		Node method = set.get(key);
+	for (Entry<String, Node> entry: set.entrySet()) {
+		String key = entry.getKey();
+		Node method = entry.getValue();
 		if ("informal_protocol".equals(method.getParentNode().getNodeName())) {
 			method = findNSObjectMethod(method);
 			if (method == null) continue;
-		}		
+		}
 		String nativeMth = key.replaceAll(":", "_");
 		out("/** @method callback_types=");
 		Node returnNode = getReturnNode(method.getChildNodes());
@@ -1588,21 +1697,17 @@ void generateSends(boolean superCall) {
 		}
 	}
 	TreeMap<String, Node> all = new TreeMap<>();
-	for (Iterator<String> iterator = tagsSet.keySet().iterator(); iterator.hasNext();) {
-		String key = iterator.next();
+	for (String key : tagsSet.keySet()) {
 		Node method = tagsSet.get(key);
 		all.put(buildSend(method, true, false, superCall), method);
 	}
-	for (Iterator<String> iterator = set.keySet().iterator(); iterator.hasNext();) {
-		String key = iterator.next();
+	for (String key : set.keySet()) {
 		all.put(key, set.get(key));
 	}
-	for (Iterator<String> iterator = set64.keySet().iterator(); iterator.hasNext();) {
-		String key = iterator.next();
+	for (String key : set64.keySet()) {
 		all.put(key, set64.get(key));
 	}
-	for (Iterator<String> iterator = all.keySet().iterator(); iterator.hasNext();) {
-		String key = iterator.next();
+	for (String key : all.keySet()) {
 		Node method = all.get(key);
 		NodeList params = method.getChildNodes();
 		ArrayList<String> tags = new ArrayList<>();
@@ -1623,8 +1728,7 @@ void generateSends(boolean superCall) {
 		}
 		out(" @method flags=cast");
 		if (tags.size() > 0) outln();
-		for (Iterator<String> iterator2 = tags.iterator(); iterator2.hasNext();) {
-			String tag = iterator2.next();
+		for (String tag : tags) {
 			out(tag);
 			outln();
 		}
@@ -1656,8 +1760,7 @@ void generateClassesConst() {
 			}
 		}
 	}
-	for (Iterator<String> iterator = set.iterator(); iterator.hasNext();) {
-		String cls = iterator.next();
+	for (String cls : set) {
 		String clsConst = "class_" + cls;
 		out("public static final int /*long*/ ");
 		out(clsConst);
@@ -1686,8 +1789,7 @@ void generateProtocolsConst() {
 			}
 		}
 	}
-	for (Iterator<String> iterator = set.iterator(); iterator.hasNext();) {
-		String cls = iterator.next();
+	for (String cls : set) {
 		String clsConst = "protocol_" + cls;
 		out("public static final int /*long*/ ");
 		out(clsConst);
@@ -1699,13 +1801,13 @@ void generateProtocolsConst() {
 	}
 }
 
-String getPackageName(String className) {
+String getPackageName() {
 	int dot = mainClassName.lastIndexOf('.');
 	if (dot == -1) return "";
 	return mainClassName.substring(0, dot);
 }
 
-String getClassName(String className) {
+String getClassName() {
 	int dot = mainClassName.lastIndexOf('.');
 	if (dot == -1) return mainClassName;
 	return mainClassName.substring(dot + 1);
@@ -1726,9 +1828,45 @@ String getType(Node node) {
 	Node javaType = attributes.getNamedItem("swt_java_type");
 	if (javaType != null) return javaType.getNodeValue();
 	Node type = attributes.getNamedItem("type");
-	if (type == null) return "notype";
+	if (type == null) {
+		System.err.printf("Unable to detect type. Check bridge file! It might have been removed, inheritance changed, etc. Location: %s %n", toDebugLocation(node));
+		return "notype";
+	}
 	String code = type.getNodeValue();
-	return getType(code, attributes, false);
+	return getType(code, attributes, false, node);
+}
+
+private String toDebugLocation(Node location) {
+	StringBuilder result = new StringBuilder();
+	while(location != null) {
+		if(result.length() > 0) {
+			result.insert(0, " > ");
+		}
+		result.insert(0, getNodeInfo(location));
+		location = location.getParentNode();
+	}
+	return result.toString();
+}
+
+private String getNodeInfo(Node location) {
+	String name = location.getNodeName();
+	if (name != null) {
+		NamedNodeMap attributes = location.getAttributes();
+		if (attributes != null) {
+			StringBuilder info = new StringBuilder();
+			info.append(name).append("[");
+			for (int i = 0; i < attributes.getLength(); i++) {
+				Node attribute = attributes.item(i);
+				if (i > 0) {
+					info.append(", ");
+				}
+				info.append(attribute.getNodeName()).append("=").append(attribute.getNodeValue());
+			}
+			return info.append("]").toString();
+		}
+		return name;
+	}
+	return location.toString();
 }
 
 String getType64(Node node) {
@@ -1743,10 +1881,10 @@ String getType64(Node node) {
 	String code = attrib.getNodeValue();
 	Node attrib64 = attributes.getNamedItem("type64");
 	if (attrib64 != null) code = attrib64.getNodeValue();
-	return getType(code, attributes, true);
+	return getType(code, attributes, true, node);
 }
 
-String getType(String code, NamedNodeMap attributes, boolean is64) {
+String getType(String code, NamedNodeMap attributes, boolean is64, Node location) {
 	if (code.equals("c")) return "byte";
 	if (code.equals("i")) return "int";
 	if (code.equals("s")) return "short";
@@ -1766,8 +1904,8 @@ String getType(String code, NamedNodeMap attributes, boolean is64) {
 	if (code.equals("#")) return is64 ? "long" : "int";
 	if (code.equals(":")) return is64 ? "long" : "int";
 	if (code.startsWith("^")) return is64 ? "long" : "int";
-	if (code.startsWith("{")) {		
-		return attributes.getNamedItem("declared_type").getNodeValue();
+	if (code.startsWith("{")) {
+		return getDeclaredType(attributes, location);
 	}
     if (code.startsWith("@?")) {
         return is64 ? "long" : "int";
@@ -1799,7 +1937,7 @@ String getJNIType(Node node) {
 	if (code.startsWith("^")) return "I";
     if (code.startsWith("@?")) return "I";
 	if (code.startsWith("[")) return "BAD " + code;
-	if (code.startsWith("{")) {		
+	if (code.startsWith("{")) {
 		return "BAD " + code;
 	}
 	if (code.startsWith("(")) return "BAD " + code;
@@ -1813,7 +1951,7 @@ String getJavaType(Node node) {
 	Node type = attributes.getNamedItem("type");
 	if (type == null) return "notype";
 	String code = type.getNodeValue();
-	return getJavaType(code, attributes, false);
+	return getJavaType(code, attributes, false, node);
 }
 
 String getJavaType64(Node node) {
@@ -1828,10 +1966,10 @@ String getJavaType64(Node node) {
 	String code = attrib.getNodeValue();
 	Node attrib64 = attributes.getNamedItem("type64");
 	if (attrib64 != null) code = attrib64.getNodeValue();
-	return getJavaType(code, attributes, true);
+	return getJavaType(code, attributes, true, node);
 }
-	
-String getJavaType(String code, NamedNodeMap attributes, boolean is64) {
+
+String getJavaType(String code, NamedNodeMap attributes, boolean is64, Node location) {
 	if (code.equals("c")) return "byte";
 	if (code.equals("i")) return "int";
 	if (code.equals("s")) return "short";
@@ -1851,15 +1989,15 @@ String getJavaType(String code, NamedNodeMap attributes, boolean is64) {
 	if (code.equals(":")) return is64 ? "long" : "int";
 	if (code.startsWith("^")) return is64 ? "long" : "int";
 	if (code.equals("@")) {
-		String type = attributes.getNamedItem("declared_type").getNodeValue();
+		String type = getDeclaredType(attributes, location);
 		int index = type.indexOf('*');
 		if (index != -1) type = type.substring(0, index);
 		index = type.indexOf('<');
 		if (index != -1) type = type.substring(0, index);
 		return type.trim();
 	}
-	if (code.startsWith("{")) {		
-		return attributes.getNamedItem("declared_type").getNodeValue().trim();
+	if (code.startsWith("{")) {
+		return getDeclaredType(attributes, location).trim();
 	}
     if (code.startsWith("@?")) return is64 ? "long" : "int";
 	return "BAD " + code;
@@ -1909,8 +2047,7 @@ void generateFunctions() {
 								out(" cast=");
 								NamedNodeMap paramAttributes = param.getAttributes();
 								Node swtCast = paramAttributes.getNamedItem("swt_param_cast");
-								Node declaredType = swtCast != null ? swtCast : paramAttributes.getNamedItem("declared_type");
-								String cast = declaredType.getNodeValue();
+								String cast = swtCast != null ? swtCast.getNodeValue(): getDeclaredType(paramAttributes, param);
 								if (!cast.startsWith("(")) out("(");
 								out(cast);
 								if (!cast.endsWith(")")) out(")");
@@ -2000,6 +2137,7 @@ public static void main(String[] args) {
 		gen.setXmls(args);
 		gen.setOutputDir("../org.eclipse.swt/Eclipse SWT PI/cocoa/");
 		gen.setMainClass("org.eclipse.swt.internal.cocoa.OS");
+		gen.setSelectorEnum("org.eclipse.swt.internal.cocoa.Selector");
 		gen.generate(null);
 	} catch (Throwable e) {
 		e.printStackTrace();
