@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2014 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -36,12 +36,12 @@ public class Clipboard {
 	private static long /*int*/ TARGET;
 
 	static {
-		GTKCLIPBOARD = OS.gtk_clipboard_get(OS.GDK_NONE);
-		byte[] buffer = Converter.wcsToMbcs(null, "PRIMARY", true);
-		long /*int*/ primary = OS.gdk_atom_intern(buffer, false);
-		GTKPRIMARYCLIPBOARD = OS.gtk_clipboard_get(primary);
-		buffer = Converter.wcsToMbcs(null, "TARGETS", true);
-		TARGET = OS.gdk_atom_intern(buffer, false);
+		GTKCLIPBOARD = GTK.gtk_clipboard_get(GDK.GDK_NONE);
+		byte[] buffer = Converter.wcsToMbcs("PRIMARY", true);
+		long /*int*/ primary = GDK.gdk_atom_intern(buffer, false);
+		GTKPRIMARYCLIPBOARD = GTK.gtk_clipboard_get(primary);
+		buffer = Converter.wcsToMbcs("TARGETS", true);
+		TARGET = GDK.gdk_atom_intern(buffer, false);
 	}
 
 /**
@@ -297,7 +297,7 @@ public Object getContents(Transfer transfer, int clipboards) {
 			* code outside of SWT (i.e AWT, etc). It ensures that the current
 			* thread leaves the GTK lock acquired by the function above.
 			*/
-			OS.gdk_threads_leave();
+			GDK.gdk_threads_leave();
 		}
 		if (selection_data != 0) break;
 		if ((clipboards & DND.SELECTION_CLIPBOARD) != 0) {
@@ -308,17 +308,17 @@ public Object getContents(Transfer transfer, int clipboards) {
 			* code outside of SWT (i.e AWT, etc). It ensures that the current
 			* thread leaves the GTK lock acquired by the function above.
 			*/
-			OS.gdk_threads_leave();
+			GDK.gdk_threads_leave();
 		}
 	}
 	if (selection_data == 0) return null;
 	TransferData tdata = new TransferData();
-	tdata.type = OS.gtk_selection_data_get_data_type(selection_data);
-	tdata.pValue = OS.gtk_selection_data_get_data(selection_data);
-	tdata.length = OS.gtk_selection_data_get_length(selection_data);
-	tdata.format = OS.gtk_selection_data_get_format(selection_data);
+	tdata.type = GTK.gtk_selection_data_get_data_type(selection_data);
+	tdata.pValue = GTK.gtk_selection_data_get_data(selection_data);
+	tdata.length = GTK.gtk_selection_data_get_length(selection_data);
+	tdata.format = GTK.gtk_selection_data_get_format(selection_data);
 	Object result = transfer.nativeToJava(tdata);
-	OS.gtk_selection_data_free(selection_data);
+	GTK.gtk_selection_data_free(selection_data);
 	return result;
 }
 
@@ -560,24 +560,24 @@ public String[] getAvailableTypeNames() {
 	String[] result = new String[types1.length + types2.length];
 	int count = 0;
 	for (int i = 0; i < types1.length; i++) {
-		long /*int*/ pName = OS.gdk_atom_name(types1[i]);
+		long /*int*/ pName = GDK.gdk_atom_name(types1[i]);
 		if (pName == 0) {
 			continue;
 		}
-		byte[] buffer = new byte [OS.strlen(pName)];
-		OS.memmove (buffer, pName, buffer.length);
+		byte[] buffer = new byte [C.strlen(pName)];
+		C.memmove (buffer, pName, buffer.length);
 		OS.g_free (pName);
-		result[count++] = "GTKCLIPBOARD "+new String (Converter.mbcsToWcs (null, buffer));
+		result[count++] = "GTKCLIPBOARD "+new String (Converter.mbcsToWcs (buffer));
 	}
 	for (int i = 0; i < types2.length; i++) {
-		long /*int*/ pName = OS.gdk_atom_name(types2[i]);
+		long /*int*/ pName = GDK.gdk_atom_name(types2[i]);
 		if (pName == 0) {
 			continue;
 		}
-		byte[] buffer = new byte [OS.strlen(pName)];
-		OS.memmove (buffer, pName, buffer.length);
+		byte[] buffer = new byte [C.strlen(pName)];
+		C.memmove (buffer, pName, buffer.length);
 		OS.g_free (pName);
-		result[count++] = "GTKPRIMARYCLIPBOARD "+new String (Converter.mbcsToWcs (null, buffer));
+		result[count++] = "GTKPRIMARYCLIPBOARD "+new String (Converter.mbcsToWcs (buffer));
 	}
 	if (count < result.length){
 		String[] temp = new String[count];
@@ -596,18 +596,18 @@ private  int[] getAvailablePrimaryTypes() {
 	* code outside of SWT (i.e AWT, etc). It ensures that the current
 	* thread leaves the GTK lock acquired by the function above.
 	*/
-	OS.gdk_threads_leave();
+	GDK.gdk_threads_leave();
 	if (selection_data != 0) {
 		try {
-			int length = OS.gtk_selection_data_get_length(selection_data);
-			int format = OS.gtk_selection_data_get_format(selection_data);
-			long /*int*/ data = OS.gtk_selection_data_get_data(selection_data);
+			int length = GTK.gtk_selection_data_get_length(selection_data);
+			int format = GTK.gtk_selection_data_get_format(selection_data);
+			long /*int*/ data = GTK.gtk_selection_data_get_data(selection_data);
 			if (length != 0) {
 				types = new int[length * 8 / format];
-				OS.memmove(types, data, length);
+				C.memmove(types, data, length);
 			}
 		} finally {
-			OS.gtk_selection_data_free(selection_data);
+			GTK.gtk_selection_data_free(selection_data);
 		}
 	}
 	return types;
@@ -621,18 +621,18 @@ private int[] getAvailableClipboardTypes () {
 	* code outside of SWT (i.e AWT, etc). It ensures that the current
 	* thread leaves the GTK lock acquired by the function above.
 	*/
-	OS.gdk_threads_leave();
+	GDK.gdk_threads_leave();
 	if (selection_data != 0) {
 		try {
-			int length = OS.gtk_selection_data_get_length(selection_data);
-			int format = OS.gtk_selection_data_get_format(selection_data);
-			long /*int*/ data = OS.gtk_selection_data_get_data(selection_data);
+			int length = GTK.gtk_selection_data_get_length(selection_data);
+			int format = GTK.gtk_selection_data_get_format(selection_data);
+			long /*int*/ data = GTK.gtk_selection_data_get_data(selection_data);
 			if (length != 0) {
 				types = new int[length * 8 / format];
-				OS.memmove(types, data, length);
+				C.memmove(types, data, length);
 			}
 		} finally {
-			OS.gtk_selection_data_free(selection_data);
+			GTK.gtk_selection_data_free(selection_data);
 		}
 	}
 	return types;
@@ -642,8 +642,8 @@ long /*int*/ gtk_clipboard_wait_for_contents(long /*int*/ clipboard, long /*int*
 	long startTime = System.currentTimeMillis();
 	String key = "org.eclipse.swt.internal.gtk.dispatchEvent";
 	Display display = this.display;
-	display.setData(key, new int[]{OS.GDK_PROPERTY_NOTIFY, OS.GDK_SELECTION_CLEAR, OS.GDK_SELECTION_REQUEST, OS.GDK_SELECTION_NOTIFY});
-	long /*int*/ selection_data = OS.gtk_clipboard_wait_for_contents(clipboard, target);
+	display.setData(key, new int[]{GDK.GDK_PROPERTY_NOTIFY, GDK.GDK_SELECTION_CLEAR, GDK.GDK_SELECTION_REQUEST, GDK.GDK_SELECTION_NOTIFY});
+	long /*int*/ selection_data = GTK.gtk_clipboard_wait_for_contents(clipboard, target);
 	display.setData(key, null);
 	long duration = System.currentTimeMillis() - startTime;
 	if (selection_data == 0 && duration > 5000) {
