@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,15 +7,17 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 497807
  *******************************************************************************/
 package org.eclipse.swt.dnd;
 
 
 import org.eclipse.swt.*;
 import org.eclipse.swt.graphics.*;
-import org.eclipse.swt.widgets.*;
 import org.eclipse.swt.internal.*;
+import org.eclipse.swt.internal.dnd.gtk.*;
 import org.eclipse.swt.internal.gtk.*;
+import org.eclipse.swt.widgets.*;
 
 /**
  *
@@ -113,10 +115,13 @@ public class DragSource extends Widget {
 
 	static final String DEFAULT_DRAG_SOURCE_EFFECT = "DEFAULT_DRAG_SOURCE_EFFECT"; //$NON-NLS-1$
 
+	static Callback DragBegin;
 	static Callback DragGetData;
 	static Callback DragEnd;
 	static Callback DragDataDelete;
 	static {
+		DragBegin = new Callback(DragSource.class, "DragBegin", 2); //$NON-NLS-1$
+		if (DragBegin.getAddress() == 0) SWT.error(SWT.ERROR_NO_MORE_CALLBACKS);
 		DragGetData = new Callback(DragSource.class, "DragGetData", 5);	 //$NON-NLS-1$
 		if (DragGetData.getAddress() == 0) SWT.error(SWT.ERROR_NO_MORE_CALLBACKS);
 		DragEnd = new Callback(DragSource.class, "DragEnd", 2); //$NON-NLS-1$
@@ -165,22 +170,22 @@ public DragSource(Control control, int style) {
 	}
 	control.setData(DND.DRAG_SOURCE_KEY, this);
 
+	OS.g_signal_connect(control.handle, OS.drag_begin, DragBegin.getAddress(), 0);
 	OS.g_signal_connect(control.handle, OS.drag_data_get, DragGetData.getAddress(), 0);
 	OS.g_signal_connect(control.handle, OS.drag_end, DragEnd.getAddress(), 0);
 	OS.g_signal_connect(control.handle, OS.drag_data_delete, DragDataDelete.getAddress(), 0);
 
-	controlListener = new Listener () {
-		@Override
-		public void handleEvent (Event event) {
-			if (event.type == SWT.Dispose) {
-				if (!DragSource.this.isDisposed()) {
-					DragSource.this.dispose();
-				}
+
+
+	controlListener = event -> {
+		if (event.type == SWT.Dispose) {
+			if (!DragSource.this.isDisposed()) {
+				DragSource.this.dispose();
 			}
-			if (event.type == SWT.DragDetect) {
-				if (!DragSource.this.isDisposed()) {
-					DragSource.this.drag(event);
-				}
+		}
+		if (event.type == SWT.DragDetect) {
+			if (!DragSource.this.isDisposed()) {
+				DragSource.this.drag(event);
 			}
 		}
 	};
@@ -194,14 +199,11 @@ public DragSource(Control control, int style) {
 		dragEffect = new TreeDragSourceEffect((Tree) control);
 	} else if (control instanceof Table) {
 		dragEffect = new TableDragSourceEffect((Table) control);
+	} else if (control instanceof List) {
+		dragEffect = new ListDragSourceEffect((List) control);
 	}
 
-	this.addListener(SWT.Dispose, new Listener() {
-		@Override
-		public void handleEvent(Event e) {
-			onDispose();
-		}
-	});
+	this.addListener(SWT.Dispose, e -> onDispose());
 }
 
 static int checkStyle (int style) {
@@ -209,6 +211,13 @@ static int checkStyle (int style) {
 	return style;
 }
 
+static long /*int*/ DragBegin(long /*int*/ widget, long /*int*/ context){
+	DragSource source = FindDragSource(widget);
+	if (source == null) return 0;
+	source.dragBegin(widget, context);
+	return 0;
+}
+
 static long /*int*/ DragDataDelete(long /*int*/ widget, long /*int*/ context){
 	DragSource source = FindDragSource(widget);
 	if (source == null) return 0;
@@ -301,22 +310,46 @@ void drag(Event dragEvent) {
 	int actions = opToOsOp(getStyle());
 	Image image = event.image;
 	long /*int*/ context;
-	if (OS.GTK_VERSION >= OS.VERSION(3, 10, 0)) {
-		context = OS.gtk_drag_begin_with_coordinates(control.handle, targetList, actions, 1, 0, -1, -1);
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 10, 0)) {
+		context = GTK.gtk_drag_begin_with_coordinates(control.handle, targetList, actions, 1, 0, -1, -1);
 	} else {
-		context = OS.gtk_drag_begin(control.handle, targetList, actions, 1, 0);
+		context = GTK.gtk_drag_begin(control.handle, targetList, actions, 1, 0);
 	}
 	if (context != 0 && image != null) {
-		if (OS.GTK3) {
-			OS.gtk_drag_set_icon_surface(context, image.surface);
+		if (GTK.GTK3) {
+			GTK.gtk_drag_set_icon_surface(context, image.surface);
 		} else {
 			long /*int*/ pixbuf = ImageList.createPixbuf(image);
-			OS.gtk_drag_set_icon_pixbuf(context, pixbuf, 0, 0);
+			GTK.gtk_drag_set_icon_pixbuf(context, pixbuf, 0, 0);
 			OS.g_object_unref(pixbuf);
 		}
 	}
 }
 
+void dragBegin(long /*int*/ widget, long /*int*/ context) {
+	/*
+	 * Bug 515035: GTK DnD hijacks the D&D logic we have in SWT.
+	 * When we recieve the signal from GTK of DragBegin, we will
+	 * notify SWT that a drag has occurred.
+	 */
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0) && this.control instanceof Text) {
+		DNDEvent event = new DNDEvent();
+		Display display = Display.getCurrent();
+		Point loc = display.getCursorLocation();
+		event.widget = this;
+		event.doit = true;
+		event.x = loc.x;
+		event.y = loc.y;
+		notifyListeners(DND.DragStart, event);
+		if (!event.doit || transferAgents == null || transferAgents.length == 0) return;
+		if (targetList == 0) return;
+		Image image = event.image;
+		if (context != 0 && image != null) {
+			GTK.gtk_drag_set_icon_surface(context, image.surface);
+		}
+	}
+}
+
 void dragEnd(long /*int*/ widget, long /*int*/ context){
 	/*
 	 * Bug in GTK.  If a drag is initiated using gtk_drag_begin and the
@@ -327,32 +360,39 @@ void dragEnd(long /*int*/ widget, long /*int*/ context){
 	 * NOTE: We believe that it is never an error to ungrab when
 	 * a drag is finished.
 	 */
-	if (OS.GTK3) {
-		long /*int*/ display = OS.gdk_window_get_display(OS.gtk_widget_get_window(widget));
-		long /*int*/ device_manager = OS.gdk_display_get_device_manager(display);
-		long /*int*/ pointer = OS.gdk_device_manager_get_client_pointer(device_manager);
-		long /*int*/ keyboard = OS.gdk_device_get_associated_device(pointer);
-		OS.gdk_device_ungrab(pointer, OS.GDK_CURRENT_TIME);
-		OS.gdk_device_ungrab(keyboard, OS.GDK_CURRENT_TIME);
+	if (GTK.GTK3) {
+		long /*int*/ display = GDK.gdk_window_get_display(GTK.gtk_widget_get_window(widget));
+		long /*int*/ pointer = GDK.gdk_get_pointer(display);
+		long /*int*/ keyboard = GDK.gdk_device_get_associated_device(pointer);
+		GDK.gdk_device_ungrab(pointer, GDK.GDK_CURRENT_TIME);
+		GDK.gdk_device_ungrab(keyboard, GDK.GDK_CURRENT_TIME);
 	} else {
-		OS.gdk_pointer_ungrab(OS.GDK_CURRENT_TIME);
-		OS.gdk_keyboard_ungrab(OS.GDK_CURRENT_TIME);
+		GDK.gdk_pointer_ungrab(GDK.GDK_CURRENT_TIME);
+		GDK.gdk_keyboard_ungrab(GDK.GDK_CURRENT_TIME);
 	}
 
 	int operation = DND.DROP_NONE;
 	if (context != 0) {
 		long /*int*/ dest_window = 0;
 		int action = 0;
-		if (OS.GTK3) {
-			dest_window = OS.gdk_drag_context_get_dest_window(context);
-			action = OS.gdk_drag_context_get_selected_action(context);
+		/*
+		 * Feature in GTK: dest_window information is not gathered here in Wayland as the
+		 * DragEnd signal does not give the correct destination window. GTK3.14+ with
+		 * GTKGestures will handle file operations correctly without the
+		 * gdk_drag_context_get_dest_window() call. See Bug 503431.
+		 */
+		if (GTK.GTK3) {
+			action = GDK.gdk_drag_context_get_selected_action(context);
+			if (OS.isX11()) { // Wayland
+				dest_window = GDK.gdk_drag_context_get_dest_window(context);
+			}
 		} else {
 			GdkDragContext gdkDragContext = new GdkDragContext ();
 			OS.memmove(gdkDragContext, context, GdkDragContext.sizeof);
 			dest_window = gdkDragContext.dest_window;
 			action = gdkDragContext.action;
 		}
-		if (dest_window != 0) { //NOTE: if dest_window is 0, drag was aborted
+		if (dest_window != 0 || !OS.isX11()) { // Wayland. NOTE: if dest_window is 0, drag was aborted
 			if (moveData) {
 				operation = DND.DROP_MOVE;
 			} else {
@@ -361,22 +401,43 @@ void dragEnd(long /*int*/ widget, long /*int*/ context){
 			}
 		}
 	}
-
 	DNDEvent event = new DNDEvent();
 	event.widget = this;
 	//event.time = ???
 	event.doit = operation != 0;
 	event.detail = operation;
 	notifyListeners(DND.DragEnd, event);
+
+	if (!OS.isX11()) { // Wayland
+		/*
+		 * Feature in GTK: release events are not signaled during the dragEnd phrase of a Drag and Drop
+		 * in Wayland. In order to work with the current logic for DnD in multiselection
+		 * Widgets (tree, table, list), the selection function needs to be set back to
+		 * true on dragEnd as well as release_event(). See bug 503431.
+		 */
+		if (this.control instanceof Table
+				|| this.control instanceof Tree
+				|| this.control instanceof List) {
+			long /*int*/ selection = GTK.gtk_tree_view_get_selection (widget);
+			GTK.gtk_tree_selection_set_select_function(selection,0,0,0);
+		}
+
+		/*
+		 * send a mouse Up signal for >GTK3.14 as Wayland (support as of 3.14)
+		 * does not trigger a MouseUp/Mouse_release_event on DragEnd.
+		 * See Bug 510446.
+		 */
+		control.notifyListeners(SWT.MouseUp, event);
+	}
 	moveData = false;
 }
 
 void dragGetData(long /*int*/ widget, long /*int*/ context, long /*int*/ selection_data,  int info, int time){
 	if (selection_data == 0) return;
-	int length = OS.gtk_selection_data_get_length(selection_data);
-	int format = OS.gtk_selection_data_get_format(selection_data);
-	long /*int*/ data = OS.gtk_selection_data_get_data(selection_data);
-	long /*int*/ target = OS.gtk_selection_data_get_target(selection_data);
+	int length = GTK.gtk_selection_data_get_length(selection_data);
+	int format = GTK.gtk_selection_data_get_format(selection_data);
+	long /*int*/ data = GTK.gtk_selection_data_get_data(selection_data);
+	long /*int*/ target = GTK.gtk_selection_data_get_target(selection_data);
 	if (target == 0) return;
 
 	TransferData transferData = new TransferData();
@@ -403,7 +464,7 @@ void dragGetData(long /*int*/ widget, long /*int*/ context, long /*int*/ selecti
 	if (transfer == null) return;
 	transfer.javaToNative(event.data, transferData);
 	if (transferData.result != 1) return;
-	OS.gtk_selection_data_set(selection_data, transferData.type, transferData.format, transferData.pValue, transferData.length);
+	GTK.gtk_selection_data_set(selection_data, transferData.type, transferData.format, transferData.pValue, transferData.length);
 	OS.g_free(transferData.pValue);
 	return;
 }
@@ -484,7 +545,7 @@ public Transfer[] getTransfer(){
 void onDispose() {
 	if (control == null) return;
 	if (targetList != 0) {
-		OS.gtk_target_list_unref(targetList);
+		GTK.gtk_target_list_unref(targetList);
 	}
 	targetList = 0;
 	if (controlListener != null) {
@@ -501,11 +562,11 @@ int opToOsOp(int operation){
 	int osOperation = 0;
 
 	if ((operation & DND.DROP_COPY) == DND.DROP_COPY)
-		osOperation |= OS.GDK_ACTION_COPY;
+		osOperation |= GDK.GDK_ACTION_COPY;
 	if ((operation & DND.DROP_MOVE) == DND.DROP_MOVE)
-		osOperation |= OS.GDK_ACTION_MOVE;
+		osOperation |= GDK.GDK_ACTION_MOVE;
 	if ((operation & DND.DROP_LINK) == DND.DROP_LINK)
-		osOperation |= OS.GDK_ACTION_LINK;
+		osOperation |= GDK.GDK_ACTION_LINK;
 
 	return osOperation;
 }
@@ -513,11 +574,11 @@ int opToOsOp(int operation){
 int osOpToOp(int osOperation){
 	int operation = DND.DROP_NONE;
 
-	if ((osOperation & OS.GDK_ACTION_COPY) == OS.GDK_ACTION_COPY)
+	if ((osOperation & GDK.GDK_ACTION_COPY) == GDK.GDK_ACTION_COPY)
 		operation |= DND.DROP_COPY;
-	if ((osOperation & OS.GDK_ACTION_MOVE) == OS.GDK_ACTION_MOVE)
+	if ((osOperation & GDK.GDK_ACTION_MOVE) == GDK.GDK_ACTION_MOVE)
 		operation |= DND.DROP_MOVE;
-	if ((osOperation & OS.GDK_ACTION_LINK) == OS.GDK_ACTION_LINK)
+	if ((osOperation & GDK.GDK_ACTION_LINK) == GDK.GDK_ACTION_LINK)
 		operation |= DND.DROP_LINK;
 
 	return operation;
@@ -568,9 +629,9 @@ public void setDragSourceEffect(DragSourceEffect effect) {
  * @param transferAgents a list of Transfer objects which define the types of data that can be
  * dragged from this source
  */
-public void setTransfer(Transfer[] transferAgents){
+public void setTransfer(Transfer... transferAgents){
 	if (targetList != 0) {
-		OS.gtk_target_list_unref(targetList);
+		GTK.gtk_target_list_unref(targetList);
 		targetList = 0;
 	}
 	this.transferAgents = transferAgents;
@@ -584,9 +645,9 @@ public void setTransfer(Transfer[] transferAgents){
 			String[] typeNames = transfer.getTypeNames();
 			for (int j = 0; j < typeIds.length; j++) {
 				GtkTargetEntry entry = new GtkTargetEntry();
-				byte[] buffer = Converter.wcsToMbcs(null, typeNames[j], true);
+				byte[] buffer = Converter.wcsToMbcs(typeNames[j], true);
 				entry.target = OS.g_malloc(buffer.length);
-				OS.memmove(entry.target, buffer, buffer.length);
+				C.memmove(entry.target, buffer, buffer.length);
 				entry.info = typeIds[j];
 				GtkTargetEntry[] newTargets = new GtkTargetEntry[targets.length + 1];
 				System.arraycopy(targets, 0, newTargets, 0, targets.length);
@@ -600,7 +661,7 @@ public void setTransfer(Transfer[] transferAgents){
 	for (int i = 0; i < targets.length; i++) {
 		OS.memmove(pTargets + i*GtkTargetEntry.sizeof, targets[i], GtkTargetEntry.sizeof);
 	}
-	targetList = OS.gtk_target_list_new(pTargets, targets.length);
+	targetList = GTK.gtk_target_list_new(pTargets, targets.length);
 
 	for (int i = 0; i < targets.length; i++) {
 		OS.g_free(targets[i].target);
