@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -28,12 +28,12 @@ public long /*int*/ action() {
 	return OS.objc_msgSend(this.id, OS.sel_action);
 }
 
-public void setAction(long /*int*/ aSelector) {
-	OS.objc_msgSend(this.id, OS.sel_setAction_, aSelector);
+public void setAction(long /*int*/ action) {
+	OS.objc_msgSend(this.id, OS.sel_setAction_, action);
 }
 
-public void setTarget(id anObject) {
-	OS.objc_msgSend(this.id, OS.sel_setTarget_, anObject != null ? anObject.id : 0);
+public void setTarget(id target) {
+	OS.objc_msgSend(this.id, OS.sel_setTarget_, target != null ? target.id : 0);
 }
 
 public id target() {
