@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -65,6 +65,20 @@ public class Composite extends Scrollable {
 	Layout layout;
 	Control[] tabList;
 	int layoutCount, backgroundMode;
+	/**
+	 * When this field is set, it indicates that a child widget of this Composite
+	 * needs to have its clip set to its allocation. This is because on GTK3.20+
+	 * some widgets (like Combo) have their clips merged with that of their parent.
+	 */
+	long /*int*/ fixClipHandle;
+	/**
+	 * If fixClipHandle is set, fixClipArray can contain additional child widgets
+	 * that also need to have their clips adjusted.
+	 *
+	 * <p>The array <b>must</b> be ordered by widget hierarchy, as this array will be
+	 * traversed in-order to adjust the clipping of each element. See bug 500703.</p>
+	 */
+	long /*int*/ [] fixClipHandleChildren = {};
 
 	static final String NO_INPUT_METHOD = "org.eclipse.swt.internal.gtk.noInputMethod"; //$NON-NLS-1$
 
@@ -109,16 +123,14 @@ public Composite (Composite parent, int style) {
 }
 
 static int checkStyle (int style) {
-	if (OS.INIT_CAIRO) {
-		style &= ~SWT.NO_BACKGROUND;
-	}
+	style &= ~SWT.NO_BACKGROUND;
 	style &= ~SWT.TRANSPARENT;
 	return style;
 }
 
 Control [] _getChildren () {
 	long /*int*/ parentHandle = parentingHandle ();
-	long /*int*/ list = OS.gtk_container_get_children (parentHandle);
+	long /*int*/ list = GTK.gtk_container_get_children (parentHandle);
 	if (list == 0) return new Control [0];
 	int count = OS.g_list_length (list);
 	Control [] children = new Control [count];
@@ -177,35 +189,12 @@ Control [] _getTabList () {
  *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
  * </ul>
  *
+ * @deprecated use {@link Composite#layout(Control[], int)} instead
  * @since 3.1
  */
+@Deprecated
 public void changed (Control[] changed) {
-	checkWidget ();
-	if (changed == null) error (SWT.ERROR_INVALID_ARGUMENT);
-	for (int i=0; i<changed.length; i++) {
-		Control control = changed [i];
-		if (control == null) error (SWT.ERROR_INVALID_ARGUMENT);
-		if (control.isDisposed ()) error (SWT.ERROR_INVALID_ARGUMENT);
-		boolean ancestor = false;
-		Composite composite = control.parent;
-		while (composite != null) {
-			ancestor = composite == this;
-			if (ancestor) break;
-			composite = composite.parent;
-		}
-		if (!ancestor) error (SWT.ERROR_INVALID_PARENT);
-	}
-	for (int i=0; i<changed.length; i++) {
-		Control child = changed [i];
-		Composite composite = child.parent;
-		while (child != this) {
-			if (composite.layout == null || !composite.layout.flushCache (child)) {
-				composite.state |= LAYOUT_CHANGED;
-			}
-			child = composite;
-			composite = child.parent;
-		}
-	}
+	layout(changed, SWT.DEFER);
 }
 
 @Override
@@ -289,30 +278,30 @@ void createHandle (int index, boolean fixed, boolean scrolled) {
 		if (fixed) {
 			fixedHandle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 			if (fixedHandle == 0) error (SWT.ERROR_NO_HANDLES);
-			OS.gtk_widget_set_has_window (fixedHandle, true);
+			GTK.gtk_widget_set_has_window (fixedHandle, true);
 		}
-		long /*int*/ vadj = OS.gtk_adjustment_new (0, 0, 100, 1, 10, 10);
+		long /*int*/ vadj = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 10);
 		if (vadj == 0) error (SWT.ERROR_NO_HANDLES);
-		long /*int*/ hadj = OS.gtk_adjustment_new (0, 0, 100, 1, 10, 10);
+		long /*int*/ hadj = GTK.gtk_adjustment_new (0, 0, 100, 1, 10, 10);
 		if (hadj == 0) error (SWT.ERROR_NO_HANDLES);
-		scrolledHandle = OS.gtk_scrolled_window_new (hadj, vadj);
+		scrolledHandle = GTK.gtk_scrolled_window_new (hadj, vadj);
 		if (scrolledHandle == 0) error (SWT.ERROR_NO_HANDLES);
 	}
 	handle = OS.g_object_new (display.gtk_fixed_get_type (), 0);
 	if (handle == 0) error (SWT.ERROR_NO_HANDLES);
-	OS.gtk_widget_set_has_window (handle, true);
-	OS.gtk_widget_set_can_focus (handle, true);
+	GTK.gtk_widget_set_has_window (handle, true);
+	GTK.gtk_widget_set_can_focus (handle, true);
 	if ((style & SWT.EMBEDDED) == 0) {
 		if ((state & CANVAS) != 0) {
 			/* Prevent an input method context from being created for the Browser widget */
 			if (display.getData (NO_INPUT_METHOD) == null) {
-				imHandle = OS.gtk_im_multicontext_new ();
+				imHandle = GTK.gtk_im_multicontext_new ();
 				if (imHandle == 0) error (SWT.ERROR_NO_HANDLES);
 			}
 		}
 	}
 	if (scrolled) {
-		if (fixed) OS.gtk_container_add (fixedHandle, scrolledHandle);
+		if (fixed) GTK.gtk_container_add (fixedHandle, scrolledHandle);
 		/*
 		* Force the scrolledWindow to have a single child that is
 		* not scrolled automatically.  Calling gtk_container_add()
@@ -320,23 +309,30 @@ void createHandle (int index, boolean fixed, boolean scrolled) {
 		*/
 		boolean warnings = display.getWarnings ();
 		display.setWarnings (false);
-		OS.gtk_container_add (scrolledHandle, handle);
+		GTK.gtk_container_add (scrolledHandle, handle);
 		display.setWarnings (warnings);
 
-		int hsp = (style & SWT.H_SCROLL) != 0 ? OS.GTK_POLICY_ALWAYS : OS.GTK_POLICY_NEVER;
-		int vsp = (style & SWT.V_SCROLL) != 0 ? OS.GTK_POLICY_ALWAYS : OS.GTK_POLICY_NEVER;
-		OS.gtk_scrolled_window_set_policy (scrolledHandle, hsp, vsp);
+		int hsp = (style & SWT.H_SCROLL) != 0 ? GTK.GTK_POLICY_ALWAYS : GTK.GTK_POLICY_NEVER;
+		int vsp = (style & SWT.V_SCROLL) != 0 ? GTK.GTK_POLICY_ALWAYS : GTK.GTK_POLICY_NEVER;
+		GTK.gtk_scrolled_window_set_policy (scrolledHandle, hsp, vsp);
 		if (hasBorder ()) {
-			OS.gtk_scrolled_window_set_shadow_type (scrolledHandle, OS.GTK_SHADOW_ETCHED_IN);
+			GTK.gtk_scrolled_window_set_shadow_type (scrolledHandle, GTK.GTK_SHADOW_ETCHED_IN);
 		}
 	}
 	if ((style & SWT.EMBEDDED) != 0) {
-		socketHandle = OS.gtk_socket_new ();
-		if (socketHandle == 0) error (SWT.ERROR_NO_HANDLES);
-		OS.gtk_container_add (handle, socketHandle);
+		if (!OS.isX11()) {
+			if (Device.DEBUG) {
+				new SWTError(SWT.ERROR_INVALID_ARGUMENT,"SWT.EMBEDDED is currently not yet supported in Wayland. \nPlease "
+					+ "refer to https://bugs.eclipse.org/bugs/show_bug.cgi?id=514487 for development status.").printStackTrace();
+			}
+		} else {
+			socketHandle = GTK.gtk_socket_new ();
+			if (socketHandle == 0) error (SWT.ERROR_NO_HANDLES);
+			GTK.gtk_container_add (handle, socketHandle);
+		}
 	}
 	if ((style & SWT.NO_REDRAW_RESIZE) != 0 && (style & SWT.RIGHT_TO_LEFT) == 0) {
-		OS.gtk_widget_set_redraw_on_allocate (handle, false);
+		GTK.gtk_widget_set_redraw_on_allocate (handle, false);
 	}
 	/*
 	* Bug in GTK.  When a widget is double buffered and the back
@@ -348,21 +344,73 @@ void createHandle (int index, boolean fixed, boolean scrolled) {
 	* is not explicitly set.
 	*/
 	if ((style & SWT.DOUBLE_BUFFERED) == 0 && (style & SWT.NO_BACKGROUND) != 0) {
-		OS.gtk_widget_set_double_buffered (handle, false);
+		GTK.gtk_widget_set_double_buffered (handle, false);
+	}
+}
+
+/**
+ * Iterates though the array of child widgets that need to have their clips
+ * adjusted: if a child has a negative clip, adjust it. Also check if the child's
+ * allocation is negative and adjust it as necessary.
+ *
+ * <p>If the array is empty this method just returns. See bug 500703.</p>
+ */
+void fixChildClippings () {
+	if (fixClipHandleChildren == null) {
+		return;
+	} else {
+		GtkRequisition minimumSize = new GtkRequisition ();
+		GtkRequisition naturalSize = new GtkRequisition ();
+		GtkAllocation clip = new GtkAllocation ();
+		GtkAllocation allocation = new GtkAllocation ();
+		for (long /*int*/ widget : fixClipHandleChildren) {
+			GTK.gtk_widget_get_allocation(widget, allocation);
+			GTK.gtk_widget_get_clip(widget, clip);
+			/*
+			 * If the clip is negative, add the x coordinate to the width
+			 * and set the x coordinate to 0.
+			 */
+			if (clip.x < 0) {
+				clip.width = clip.width + clip.x;
+				clip.x = 0;
+				/*
+				 * Some "transient" widgets like menus get allocations of
+				 * {-1, -1, 1, 1}. Check to make sure this isn't the case
+				 * before proceeding.
+				 */
+				if (allocation.x < -1 && (allocation.width > 1 || allocation.height > 1)) {
+					// Adjust the allocation just like the clip, if it's negative
+					allocation.width = allocation.width + allocation.x;
+					allocation.x = 0;
+					// Call gtk_widget_get_preferred_size() to prevent warnings
+					GTK.gtk_widget_get_preferred_size(widget, minimumSize, naturalSize);
+					// Allocate and queue a resize event
+					GTK.gtk_widget_size_allocate(widget, allocation);
+					GTK.gtk_widget_queue_resize(widget);
+				}
+			}
+			// Adjust the clip
+			GTK.gtk_widget_set_clip(widget, allocation);
+		}
 	}
 }
 
 @Override
 long /*int*/ gtk_draw (long /*int*/ widget, long /*int*/ cairo) {
-	if (OS.GTK_VERSION >= OS.VERSION(3, 16, 0)) {
-		long /*int*/ context = OS.gtk_widget_get_style_context(widget);
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 14, 0)) {
+		long /*int*/ context = GTK.gtk_widget_get_style_context(widget);
 		GtkAllocation allocation = new GtkAllocation();
-		OS.gtk_widget_get_allocation (widget, allocation);
+		GTK.gtk_widget_get_allocation (widget, allocation);
 		int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
 		int height = (state & ZERO_HEIGHT) != 0 ? 0 : allocation.height;
 		// We specify a 0 value for x & y as we want the whole widget to be
 		// colored, not some portion of it.
-		OS.gtk_render_background(context, cairo, 0, 0, width, height);
+		GTK.gtk_render_background(context, cairo, 0, 0, width, height);
+		if (GTK.GTK_VERSION >= OS.VERSION(3, 20, 0)) {
+			// If fixClipHandle is set: iterate through the children of widget
+			// and set their clips to be that of their allocation
+			if (widget == fixClipHandle) fixChildClippings();
+		}
 	}
 	return super.gtk_draw(widget, cairo);
 }
@@ -416,68 +464,51 @@ void drawBackgroundInPixels (GC gc, int x, int y, int width, int height, int off
 	if (control != null) {
 		GCData data = gc.getGCData ();
 		long /*int*/ cairo = data.cairo;
-		if (cairo != 0) {
-			Cairo.cairo_save (cairo);
-			if (control.backgroundImage != null) {
-				Point pt = display.mapInPixels (this, control, 0, 0);
-				Cairo.cairo_translate (cairo, -pt.x - offsetX, -pt.y - offsetY);
-				x += pt.x + offsetX;
-				y += pt.y + offsetY;
-				long /*int*/ surface = control.backgroundImage.surface;
-				if (surface == 0) {
-					long /*int*/ drawable = control.backgroundImage.pixmap;
-					int [] w = new int [1], h = new int [1];
-					gdk_pixmap_get_size (drawable, w, h);
-					if (OS.isX11()) {
-						long /*int*/ xDisplay = OS.gdk_x11_display_get_xdisplay(OS.gdk_display_get_default());
-						long /*int*/ xVisual = OS.gdk_x11_visual_get_xvisual (OS.gdk_visual_get_system());
-						long /*int*/ xDrawable = OS.GDK_PIXMAP_XID (drawable);
-						surface = Cairo.cairo_xlib_surface_create (xDisplay, xDrawable, xVisual, w [0], h [0]);
-					} else {
-						surface = Cairo.cairo_image_surface_create(Cairo.CAIRO_FORMAT_ARGB32, w [0], h [0]);
-					}
-					if (surface == 0) error (SWT.ERROR_NO_HANDLES);
+		Cairo.cairo_save (cairo);
+		if (control.backgroundImage != null) {
+			Point pt = display.mapInPixels (this, control, 0, 0);
+			Cairo.cairo_translate (cairo, -pt.x - offsetX, -pt.y - offsetY);
+			x += pt.x + offsetX;
+			y += pt.y + offsetY;
+			long /*int*/ surface = control.backgroundImage.surface;
+			if (surface == 0) {
+				long /*int*/ drawable = control.backgroundImage.pixmap;
+				int [] w = new int [1], h = new int [1];
+				GDK.gdk_pixmap_get_size (drawable, w, h);
+				if (OS.isX11()) {
+					long /*int*/ xDisplay = GDK.gdk_x11_display_get_xdisplay(GDK.gdk_display_get_default());
+					long /*int*/ xVisual = GDK.gdk_x11_visual_get_xvisual (GDK.gdk_visual_get_system());
+					long /*int*/ xDrawable = GDK.GDK_PIXMAP_XID (drawable);
+					surface = Cairo.cairo_xlib_surface_create (xDisplay, xDrawable, xVisual, w [0], h [0]);
 				} else {
-					Cairo.cairo_surface_reference(surface);
+					surface = Cairo.cairo_image_surface_create(Cairo.CAIRO_FORMAT_ARGB32, w [0], h [0]);
 				}
-				long /*int*/ pattern = Cairo.cairo_pattern_create_for_surface (surface);
-				if (pattern == 0) error (SWT.ERROR_NO_HANDLES);
-				Cairo.cairo_pattern_set_extend (pattern, Cairo.CAIRO_EXTEND_REPEAT);
-				if ((data.style & SWT.MIRRORED) != 0) {
-					double[] matrix = {-1, 0, 0, 1, 0, 0};
-					Cairo.cairo_pattern_set_matrix(pattern, matrix);
-				}
-				Cairo.cairo_set_source (cairo, pattern);
-				Cairo.cairo_surface_destroy (surface);
-				Cairo.cairo_pattern_destroy (pattern);
+				if (surface == 0) error (SWT.ERROR_NO_HANDLES);
 			} else {
-				GdkColor color = control.getBackgroundColor ();
-				GdkRGBA rgba = display.toGdkRGBA (color);
-				Cairo.cairo_set_source_rgba (cairo, rgba.red, rgba.green, rgba.blue, rgba.alpha);
+				Cairo.cairo_surface_reference(surface);
 			}
-			Cairo.cairo_rectangle (cairo, x, y, width, height);
-			Cairo.cairo_fill (cairo);
-			Cairo.cairo_restore (cairo);
+			long /*int*/ pattern = Cairo.cairo_pattern_create_for_surface (surface);
+			if (pattern == 0) error (SWT.ERROR_NO_HANDLES);
+			Cairo.cairo_pattern_set_extend (pattern, Cairo.CAIRO_EXTEND_REPEAT);
+			if ((data.style & SWT.MIRRORED) != 0) {
+				double[] matrix = {-1, 0, 0, 1, 0, 0};
+				Cairo.cairo_pattern_set_matrix(pattern, matrix);
+			}
+			Cairo.cairo_set_source (cairo, pattern);
+			Cairo.cairo_surface_destroy (surface);
+			Cairo.cairo_pattern_destroy (pattern);
 		} else {
-			long /*int*/ gdkGC = gc.handle;
-			GdkGCValues values = new GdkGCValues ();
-			OS.gdk_gc_get_values (gdkGC, values);
-			if (control.backgroundImage != null) {
-				Point pt = display.mapInPixels (this, control, 0, 0);
-				OS.gdk_gc_set_fill (gdkGC, OS.GDK_TILED);
-				OS.gdk_gc_set_ts_origin (gdkGC, -pt.x - offsetX, -pt.y - offsetY);
-				OS.gdk_gc_set_tile (gdkGC, control.backgroundImage.pixmap);
-				OS.gdk_draw_rectangle (data.drawable, gdkGC, 1, x, y, width, height);
-				OS.gdk_gc_set_fill (gdkGC, values.fill);
-				OS.gdk_gc_set_ts_origin (gdkGC, values.ts_x_origin, values.ts_y_origin);
+			if (GTK.GTK3) {
+				GdkRGBA rgba = control.getBackgroundGdkRGBA ();
+				Cairo.cairo_set_source_rgba (cairo, rgba.red, rgba.green, rgba.blue, rgba.alpha);
 			} else {
-				GdkColor color = control.getBackgroundColor ();
-				OS.gdk_gc_set_foreground (gdkGC, color);
-				OS.gdk_draw_rectangle (data.drawable, gdkGC, 1, x, y, width, height);
-				color.pixel = values.foreground_pixel;
-				OS.gdk_gc_set_foreground (gdkGC, color);
+				GdkColor color = control.getBackgroundGdkColor ();
+				Cairo.cairo_set_source_rgba_compatibility (cairo, color);
 			}
 		}
+		Cairo.cairo_rectangle (cairo, x, y, width, height);
+		Cairo.cairo_fill (cairo);
+		Cairo.cairo_restore (cairo);
 	} else {
 		gc.fillRectangle(DPIUtil.autoScaleDown(new Rectangle(x, y, width, height)));
 
@@ -521,6 +552,16 @@ void fixChildren (Shell newShell, Shell oldShell, Decorations newDecorations, De
 	}
 }
 
+@Override
+void fixParentGdkWindow() {
+	assert GTK.GTK3;
+	// Changes to this method should be verified via
+	// org.eclipse.swt.tests.gtk/*/Bug510803_TabFolder_TreeEditor_Regression.java (part two)
+	for (Control child : _getChildren()) {
+		child.fixParentGdkWindow();
+	}
+}
+
 @Override
 void fixModal(long /*int*/ group, long /*int*/ modalGroup)  {
 	Control[] controls = _getChildren ();
@@ -566,15 +607,15 @@ void fixZOrder () {
 	long /*int*/ parentWindow = gtk_widget_get_window (parentHandle);
 	if (parentWindow == 0) return;
 	long /*int*/ [] userData = new long /*int*/ [1];
-	long /*int*/ windowList = OS.gdk_window_get_children (parentWindow);
+	long /*int*/ windowList = GDK.gdk_window_get_children (parentWindow);
 	if (windowList != 0) {
 		long /*int*/ windows = windowList;
 		while (windows != 0) {
 			long /*int*/ window = OS.g_list_data (windows);
 			if (window != redrawWindow) {
-				OS.gdk_window_get_user_data (window, userData);
+				GDK.gdk_window_get_user_data (window, userData);
 				if (userData [0] == 0 || OS.G_OBJECT_TYPE (userData [0]) != display.gtk_fixed_get_type ()) {
-					OS.gdk_window_lower (window);
+					GDK.gdk_window_lower (window);
 				}
 			}
 			windows = OS.g_list_next (windows);
@@ -591,9 +632,9 @@ long /*int*/ focusHandle () {
 
 @Override
 boolean forceFocus (long /*int*/ focusHandle) {
-	if (socketHandle != 0) OS.gtk_widget_set_can_focus (focusHandle, true);
+	if (socketHandle != 0) GTK.gtk_widget_set_can_focus (focusHandle, true);
 	boolean result = super.forceFocus (focusHandle);
-	if (socketHandle != 0) OS.gtk_widget_set_can_focus (focusHandle, false);
+	if (socketHandle != 0) GTK.gtk_widget_set_can_focus (focusHandle, false);
 	return result;
 }
 
@@ -651,7 +692,7 @@ int getChildrenCount () {
 	* NOTE: The current implementation will count
 	* non-registered children.
 	*/
-	long /*int*/ list = OS.gtk_container_get_children (handle);
+	long /*int*/ list = GTK.gtk_container_get_children (handle);
 	if (list == 0) return 0;
 	int count = OS.g_list_length (list);
 	OS.g_list_free (list);
@@ -668,7 +709,7 @@ Rectangle getClientAreaInPixels () {
 		forceResize ();
 		long /*int*/ clientHandle = clientHandle ();
 		GtkAllocation allocation = new GtkAllocation();
-		OS.gtk_widget_get_allocation (clientHandle, allocation);
+		GTK.gtk_widget_get_allocation (clientHandle, allocation);
 		int width = (state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
 		int height = (state & ZERO_HEIGHT) != 0 ? 0 : allocation.height;
 		return new Rectangle (0, 0, width, height);
@@ -775,21 +816,21 @@ long /*int*/ gtk_expose_event (long /*int*/ widget, long /*int*/ eventPtr) {
 	OS.memmove(gdkEvent, eventPtr, GdkEventExpose.sizeof);
 	long /*int*/ [] rectangles = new long /*int*/ [1];
 	int [] n_rectangles = new int [1];
-	OS.gdk_region_get_rectangles (gdkEvent.region, rectangles, n_rectangles);
+	GDK.gdk_region_get_rectangles (gdkEvent.region, rectangles, n_rectangles);
 	GdkRectangle rect = new GdkRectangle ();
 	for (int i=0; i<n_rectangles[0]; i++) {
 		Event event = new Event ();
 		OS.memmove (rect, rectangles [0] + i * GdkRectangle.sizeof, GdkRectangle.sizeof);
 		event.setBounds (DPIUtil.autoScaleDown (new Rectangle(rect.x, rect.y, rect.width, rect.height)));
 		if ((style & SWT.MIRRORED) != 0) event.x = DPIUtil.autoScaleDown (getClientWidth ()) - event.width - event.x;
-		long /*int*/ damageRgn = OS.gdk_region_new ();
-		OS.gdk_region_union_with_rect (damageRgn, rect);
+		long /*int*/ damageRgn = GDK.gdk_region_new ();
+		GDK.gdk_region_union_with_rect (damageRgn, rect);
 		GCData data = new GCData ();
 		data.damageRgn = damageRgn;
 		GC gc = event.gc = GC.gtk_new (this, data);
 		sendEvent (SWT.Paint, event);
 		gc.dispose ();
-		OS.gdk_region_destroy (damageRgn);
+		GDK.gdk_region_destroy (damageRgn);
 		event.gc = null;
 	}
 	OS.g_free (rectangles [0]);
@@ -811,8 +852,8 @@ long /*int*/ gtk_key_press_event (long /*int*/ widget, long /*int*/ event) {
 		OS.memmove (keyEvent, event, GdkEventKey.sizeof);
 		int key = keyEvent.keyval;
 		switch (key) {
-			case OS.GDK_Return:
-			case OS.GDK_KP_Enter: return 1;
+			case GDK.GDK_Return:
+			case GDK.GDK_KP_Enter: return 1;
 		}
 	}
 	return result;
@@ -848,15 +889,15 @@ long /*int*/ gtk_realize (long /*int*/ widget) {
 	if ((style & SWT.NO_BACKGROUND) != 0) {
 		long /*int*/ window = gtk_widget_get_window (paintHandle ());
 		if (window != 0) {
-			if (OS.GTK3) {
-				OS.gdk_window_set_background_pattern(window, 0);
+			if (GTK.GTK3) {
+				GDK.gdk_window_set_background_pattern(window, 0);
 			} else {
-				OS.gdk_window_set_back_pixmap (window, 0, false);
+				GDK.gdk_window_set_back_pixmap (window, 0, false);
 			}
 		}
 	}
 	if (socketHandle != 0) {
-		embeddedHandle = OS.gtk_socket_get_id (socketHandle);
+		embeddedHandle = GTK.gtk_socket_get_id (socketHandle);
 	}
 	return result;
 }
@@ -873,7 +914,7 @@ long /*int*/ gtk_style_set (long /*int*/ widget, long /*int*/ previousStyle) {
 	long /*int*/ result = super.gtk_style_set (widget, previousStyle);
 	if ((style & SWT.NO_BACKGROUND) != 0) {
 		long /*int*/ window = gtk_widget_get_window (paintHandle ());
-		if (window != 0) OS.gdk_window_set_back_pixmap (window, 0, false);
+		if (window != 0) GDK.gdk_window_set_back_pixmap (window, 0, false);
 	}
 	return result;
 }
@@ -886,7 +927,7 @@ boolean hasBorder () {
 void hookEvents () {
 	super.hookEvents ();
 	if ((state & CANVAS) != 0) {
-		OS.gtk_widget_add_events (handle, OS.GDK_POINTER_MOTION_HINT_MASK);
+		GTK.gtk_widget_add_events (handle, GDK.GDK_POINTER_MOTION_HINT_MASK);
 		if (scrolledHandle != 0) {
 			OS.g_signal_connect_closure (scrolledHandle, OS.scroll_child, display.getClosure (SCROLL_CHILD), false);
 		}
@@ -1230,7 +1271,7 @@ void markLayout (boolean changed, boolean all) {
 void moveAbove (long /*int*/ child, long /*int*/ sibling) {
 	if (child == sibling) return;
 	long /*int*/ parentHandle = parentingHandle ();
-	if (OS.GTK3) {
+	if (GTK.GTK3) {
 		OS.swt_fixed_restack (parentHandle, child, sibling, true);
 		return;
 	}
@@ -1242,8 +1283,8 @@ void moveAbove (long /*int*/ child, long /*int*/ sibling) {
 	long /*int*/ [] widget = new long /*int*/ [1];
 	long /*int*/ childData = 0, childLink = 0, siblingLink = 0, temp = children;
 	while (temp != 0) {
-		OS.memmove (data, temp, OS.PTR_SIZEOF);
-		OS.memmove (widget, data [0], OS.PTR_SIZEOF);
+		C.memmove (data, temp, C.PTR_SIZEOF);
+		C.memmove (widget, data [0], C.PTR_SIZEOF);
 		if (child == widget [0]) {
 			childLink = temp;
 			childData = data [0];
@@ -1275,7 +1316,7 @@ void moveBelow (long /*int*/ child, long /*int*/ sibling) {
 		moveAbove (child, scrolledHandle != 0  ? scrolledHandle : handle);
 		return;
 	}
-	if (OS.GTK3) {
+	if (GTK.GTK3) {
 		OS.swt_fixed_restack (parentHandle, child, sibling, false);
 		return;
 	}
@@ -1287,8 +1328,8 @@ void moveBelow (long /*int*/ child, long /*int*/ sibling) {
 	long /*int*/ [] widget = new long /*int*/ [1];
 	long /*int*/ childData = 0, childLink = 0, siblingLink = 0, temp = children;
 	while (temp != 0) {
-		OS.memmove (data, temp, OS.PTR_SIZEOF);
-		OS.memmove (widget, data [0], OS.PTR_SIZEOF);
+		C.memmove (data, temp, C.PTR_SIZEOF);
+		C.memmove (widget, data [0], C.PTR_SIZEOF);
 		if (child == widget [0]) {
 			childLink = temp;
 			childData = data [0];
@@ -1320,7 +1361,7 @@ void moveChildren(int oldWidth) {
 		Control child = children[i];
 		long /*int*/ topHandle = child.topHandle ();
 		GtkAllocation allocation = new GtkAllocation();
-		OS.gtk_widget_get_allocation (topHandle, allocation);
+		GTK.gtk_widget_get_allocation (topHandle, allocation);
 		int x = allocation.x;
 		int y = allocation.y;
 		int controlWidth = (child.state & ZERO_WIDTH) != 0 ? 0 : allocation.width;
@@ -1328,7 +1369,7 @@ void moveChildren(int oldWidth) {
 		int clientWidth = getClientWidth ();
 		x = clientWidth - controlWidth - x;
 		if (child.enableWindow != 0) {
-			OS.gdk_window_move (child.enableWindow, x, y);
+			GDK.gdk_window_move (child.enableWindow, x, y);
 		}
 		child.moveHandle (x, y);
 		/*
@@ -1340,7 +1381,7 @@ void moveChildren(int oldWidth) {
 		gtk_widget_size_request (topHandle, requisition);
 		allocation.x = x;
 		allocation.y = y;
-		OS.gtk_widget_size_allocate (topHandle, allocation);
+		GTK.gtk_widget_size_allocate (topHandle, allocation);
 		Control control = child.findBackgroundControl ();
 		if (control != null && control.backgroundImage != null) {
 			if (child.isVisible ()) child.redrawWidget (0, 0, 0, 0, true, true, true);
@@ -1399,6 +1440,50 @@ void printWidget (GC gc, long /*int*/ drawable, int depth, int x, int y) {
 	newClip.dispose ();
 }
 
+/**
+ * Connects this widget's fixedHandle to the "draw" signal.<br>
+ * NOTE: only the "draw" (EXPOSE) signal is connected, not EXPOSE_EVENT_INVERSE.
+ */
+void connectFixedHandleDraw () {
+	long /*int*/ paintHandle = fixedHandle;
+	int paintMask = GDK.GDK_EXPOSURE_MASK;
+	GTK.gtk_widget_add_events (paintHandle, paintMask);
+
+	OS.g_signal_connect_closure_by_id (paintHandle, display.signalIds [DRAW], 0, display.getClosure (DRAW), true);
+}
+
+/**
+ * <p>Propagates draw events from a parent container to its children using
+ * gtk_container_propagate_draw(). This method only works if the fixedHandle
+ * has been connected to the "draw" signal, and only propagates draw events
+ * to other siblings of handle (i.e. other children of fixedHandle, but not
+ * handle itself).</p>
+ *
+ * <p>It's useful to propagate draw events to other child widgets for things
+ * like Table/Tree editors, or other scenarios where a widget is a child of
+ * a non-standard container widget (i.e., not a direct child of a Composite).</p>
+ *
+ * @param container the parent container, i.e. fixedHandle
+ * @param cairo the cairo context provided by GTK
+ */
+void propagateDraw (long /*int*/ container, long /*int*/ cairo) {
+	if (container == fixedHandle && GTK.GTK3) {
+		long /*int*/ list = GTK.gtk_container_get_children (container);
+		long /*int*/ temp = list;
+		while (temp != 0) {
+			long /*int*/ child = OS.g_list_data (temp);
+			if (child != 0) {
+				Widget widget = display.getWidget (child);
+				if (widget != this) {
+					GTK.gtk_container_propagate_draw(container, child, cairo);
+				}
+			}
+			temp = OS.g_list_next (temp);
+		}
+		OS.g_list_free (list);
+	}
+}
+
 @Override
 void redrawChildren () {
 	super.redrawChildren ();
@@ -1463,10 +1548,10 @@ void reskinChildren (int flags) {
 void resizeHandle (int width, int height) {
 	super.resizeHandle (width, height);
 	if (socketHandle != 0) {
-		if (OS.GTK3) {
+		if (GTK.GTK3) {
 			OS.swt_fixed_resize (handle, socketHandle, width, height);
 		} else {
-			OS.gtk_widget_set_size_request (socketHandle, width, height);
+			GTK.gtk_widget_set_size_request (socketHandle, width, height);
 		}
 	}
 }
@@ -1517,11 +1602,11 @@ int setBounds (int x, int y, int width, int height, boolean move, boolean resize
 	 * consider moving this fix higher into Control's setBound(...) method instead.
 	 */
 	long /*int*/ topHandle = topHandle ();
-	if (OS.GTK_VERSION >= OS.VERSION (3, 8, 0)
+	if (GTK.GTK_VERSION >= OS.VERSION (3, 8, 0)
 			&& fixedHandle != 0 && handle != 0
-			&& getVisible() && !OS.gtk_widget_get_visible(topHandle) //if SWT State is not HIDDEN, but widget is hidden on GTK side.
+			&& getVisible() && !GTK.gtk_widget_get_visible(topHandle) //if SWT State is not HIDDEN, but widget is hidden on GTK side.
 			&& topHandle == fixedHandle && width > 0 && height > 0 && resize) {
-		OS.gtk_widget_show(topHandle);
+		GTK.gtk_widget_show(topHandle);
 	}
 
 	int result = super.setBounds (x, y, width, height, move, resize);
@@ -1639,10 +1724,10 @@ boolean setTabGroupFocus (boolean next) {
 boolean setTabItemFocus (boolean next) {
 	if (!super.setTabItemFocus (next)) return false;
 	if (socketHandle != 0) {
-		int direction = next ? OS.GTK_DIR_TAB_FORWARD : OS.GTK_DIR_TAB_BACKWARD;
-		OS.GTK_WIDGET_UNSET_FLAGS (socketHandle, OS.GTK_HAS_FOCUS);
-		OS.gtk_widget_child_focus (socketHandle, direction);
-		OS.GTK_WIDGET_SET_FLAGS (socketHandle, OS.GTK_HAS_FOCUS);
+		int direction = next ? GTK.GTK_DIR_TAB_FORWARD : GTK.GTK_DIR_TAB_BACKWARD;
+		GTK.GTK_WIDGET_UNSET_FLAGS (socketHandle, GTK.GTK_HAS_FOCUS);
+		GTK.gtk_widget_child_focus (socketHandle, direction);
+		GTK.GTK_WIDGET_SET_FLAGS (socketHandle, GTK.GTK_HAS_FOCUS);
 	}
 	return true;
 }
@@ -1682,8 +1767,8 @@ public void setTabList (Control [] tabList) {
 void showWidget () {
 	super.showWidget ();
 	if (socketHandle != 0) {
-		OS.gtk_widget_show (socketHandle);
-		embeddedHandle = OS.gtk_socket_get_id (socketHandle);
+		GTK.gtk_widget_show (socketHandle);
+		embeddedHandle = GTK.gtk_socket_get_id (socketHandle);
 	}
 	if (scrolledHandle == 0) fixStyle (handle);
 }
