@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -40,11 +40,16 @@ import org.eclipse.swt.internal.gtk.*;
  */
 public class Menu extends Widget {
 	int x, y;
+	/**
+	 * Only set to true on X11, as Wayland has no global
+	 * coordinates. See bug 530204.
+	 */
 	boolean hasLocation;
 	MenuItem cascade, selectedItem;
 	Decorations parent;
 	long /*int*/ imItem, imSeparator, imHandle;
 	ImageList imageList;
+	int poppedUpCount;
 
 /**
  * Constructs a new instance of this class given its parent,
@@ -193,7 +198,7 @@ static int checkStyle (int style) {
 }
 
 void _setVisible (boolean visible) {
-	if (visible == gtk_widget_get_mapped (handle)) return;
+	if (visible == GTK.gtk_widget_get_mapped (handle)) return;
 	if (visible) {
 		sendEvent (SWT.Show);
 		if (getItemCount () != 0) {
@@ -204,35 +209,95 @@ void _setVisible (boolean visible) {
 			* when it is being shown in an ON_TOP shell.
 			*/
 			if ((parent._getShell ().style & SWT.ON_TOP) != 0) {
-				OS.gtk_menu_shell_set_take_focus (handle, false);
+				GTK.gtk_menu_shell_set_take_focus (handle, false);
 			}
-			long /*int*/ address = hasLocation ? display.menuPositionProc: 0;
-			hasLocation = false;
-			long /*int*/ data = 0;
-			/*
-			* Popup-menu to the status icon should be aligned to
-			* Tray rather than to cursor position. There is a
-			* possibility (unlikely) that TrayItem might have
-			* been disposed in the listener, for which case
-			* the menu should be shown in the cursor position.
-			*/
-			TrayItem item = display.currentTrayItem;
-			if (item != null && !item.isDisposed()) {
-				 data = item.handle;
-				 address = OS.gtk_status_icon_position_menu_func ();
+			if (GTK.GTK_VERSION < OS.VERSION(3, 22, 0)) {
+				long /*int*/ address = 0;
+				hasLocation = false;
+				long /*int*/ data = 0;
+				/*
+				* Popup-menu to the status icon should be aligned to
+				* Tray rather than to cursor position. There is a
+				* possibility (unlikely) that TrayItem might have
+				* been disposed in the listener, for which case
+				* the menu should be shown in the cursor position.
+				*/
+				TrayItem item = display.currentTrayItem;
+				if (item != null && !item.isDisposed()) {
+					 data = item.handle;
+					 address = GTK.gtk_status_icon_position_menu_func ();
+				}
+				/*
+				* Bug in GTK.  The timestamp passed into gtk_menu_popup is used
+				* to perform an X pointer grab.  It cannot be zero, else the grab
+				* will fail.  The fix is to ensure that the timestamp of the last
+				* event processed is used.
+				*/
+				GTK.gtk_menu_popup (handle, 0, 0, address, data, 0, display.getLastEventTime ());
 			}
-			/*
-			* Bug in GTK.  The timestamp passed into gtk_menu_popup is used
-			* to perform an X pointer grab.  It cannot be zero, else the grab
-			* will fail.  The fix is to ensure that the timestamp of the last
-			* event processed is used.
-			*/
-			OS.gtk_menu_popup (handle, 0, 0, address, data, 0, display.getLastEventTime ());
+			else {
+				long /*int*/ eventPtr = 0;
+				if (hasLocation) {
+					// Create the GdkEvent manually as we need to control
+					// certain fields like the event window
+					eventPtr = GDK.gdk_event_new(GDK.GDK_BUTTON_PRESS);
+					GdkEventButton event = new GdkEventButton ();
+					event.type = GDK.GDK_BUTTON_PRESS;
+					event.device = GDK.gdk_get_pointer(GDK.gdk_display_get_default ());
+					// Get and (add reference to) the global GdkWindow
+					event.window = GDK.gdk_display_get_default_group(GDK.gdk_display_get_default());
+					OS.g_object_ref(event.window);
+					/*
+					 * Get the origin of the global GdkWindow to calculate the size of any offsets
+					 * such as client side decorations, or the system tray.
+					 */
+					int [] globalWindowOriginY = new int [1];
+					int [] globalWindowOriginX = new int [1];
+					GDK.gdk_window_get_origin (event.window, globalWindowOriginX, globalWindowOriginY);
+					// Set the time and save the event in memory
+					event.time = display.getLastEventTime ();
+					OS.memmove (eventPtr, event, GdkEventButton.sizeof);
+
+					// Create the rectangle relative to the parent (in this case, global) GdkWindow
+					GdkRectangle rect = new GdkRectangle();
+					rect.x = this.x - globalWindowOriginX[0];
+					rect.y = this.y - globalWindowOriginY[0];
+
+					// Popup the menu and pin it at the top left corner of the GdkRectangle relative to the global GdkWindow
+					GTK.gtk_menu_popup_at_rect(handle, event.window, rect, GDK.GDK_GRAVITY_NORTH_WEST,
+							GDK.GDK_GRAVITY_NORTH_WEST, eventPtr);
+					GDK.gdk_event_free (eventPtr);
+				} else {
+					/*
+					 *  GTK Feature: gtk_menu_popup is deprecated as of GTK3.22 and the new method gtk_menu_popup_at_pointer
+					 *  requires an event to hook on to. This requires the popup & events related to the menu be handled
+					 *  immediately and not as a post event in display, requiring the current event.
+					 */
+					eventPtr = GTK.gtk_get_current_event();
+					if (eventPtr == 0) {
+						eventPtr = GDK.gdk_event_new(GDK.GDK_BUTTON_PRESS);
+						GdkEventButton event = new GdkEventButton ();
+						event.type = GDK.GDK_BUTTON_PRESS;
+						// Only assign a window on X11, as on Wayland the window is that of the mouse pointer
+						if (OS.isX11()) {
+							event.window = OS.g_object_ref(GTK.gtk_widget_get_window (getShell().handle));
+						}
+						event.device = GDK.gdk_get_pointer(GDK.gdk_display_get_default ());
+						event.time = display.getLastEventTime ();
+						OS.memmove (eventPtr, event, GdkEventButton.sizeof);
+					}
+					adjustParentWindowWayland(eventPtr);
+					verifyMenuPosition(getItemCount());
+					GTK.gtk_menu_popup_at_pointer (handle, eventPtr);
+					GDK.gdk_event_free (eventPtr);
+				}
+			}
+			poppedUpCount = getItemCount();
 		} else {
 			sendEvent (SWT.Hide);
 		}
 	} else {
-		OS.gtk_menu_popdown (handle);
+		GTK.gtk_menu_popdown (handle);
 	}
 }
 
@@ -301,33 +366,33 @@ public void addHelpListener (HelpListener listener) {
 void createHandle (int index) {
 	state |= HANDLE;
 	if ((style & SWT.BAR) != 0) {
-		handle = OS.gtk_menu_bar_new ();
+		handle = GTK.gtk_menu_bar_new ();
 		if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 		long /*int*/ vboxHandle = parent.vboxHandle;
-		OS.gtk_container_add (vboxHandle, handle);
-		OS.gtk_box_set_child_packing (vboxHandle, handle, false, true, 0, OS.GTK_PACK_START);
+		GTK.gtk_container_add (vboxHandle, handle);
+		GTK.gtk_box_set_child_packing (vboxHandle, handle, false, true, 0, GTK.GTK_PACK_START);
 	} else {
-		handle = OS.gtk_menu_new ();
+		handle = GTK.gtk_menu_new ();
 		if (handle == 0) error (SWT.ERROR_NO_HANDLES);
 	}
 }
 
 void createIMMenu (long /*int*/ imHandle) {
 	boolean showInputMethod = false;
-	long /*int*/ settings = OS.gtk_settings_get_default ();
-	if (settings != 0 && OS.GTK_VERSION < OS.VERSION (3, 10, 0)) {
+	long /*int*/ settings = GTK.gtk_settings_get_default ();
+	if (settings != 0 && GTK.GTK_VERSION < OS.VERSION (3, 10, 0)) {
 		int [] buffer = new int [1];
-		OS.g_object_get (settings, OS.gtk_show_input_method_menu, buffer, 0);
+		OS.g_object_get (settings, GTK.gtk_show_input_method_menu, buffer, 0);
 		showInputMethod = buffer[0] != 0;
 	}
 	if (imHandle == 0 || !showInputMethod) {
 		this.imHandle = 0;
 		if (imItem != 0) {
-			OS.gtk_widget_destroy (imItem);
+			GTK.gtk_widget_destroy (imItem);
 			imItem = 0;
 		}
 		if (imSeparator != 0) {
-			OS.gtk_widget_destroy (imSeparator);
+			GTK.gtk_widget_destroy (imSeparator);
 			imSeparator = 0;
 		}
 		return;
@@ -336,53 +401,53 @@ void createIMMenu (long /*int*/ imHandle) {
 	this.imHandle = imHandle;
 
 	if (imSeparator == 0) {
-		imSeparator = OS.gtk_separator_menu_item_new ();
-		OS.gtk_widget_show (imSeparator);
-		OS.gtk_menu_shell_insert (handle, imSeparator, -1);
+		imSeparator = GTK.gtk_separator_menu_item_new ();
+		GTK.gtk_widget_show (imSeparator);
+		GTK.gtk_menu_shell_insert (handle, imSeparator, -1);
 	}
 	if (imItem == 0) {
-		byte[] buffer = Converter.wcsToMbcs (null, SWT.getMessage("SWT_InputMethods"), true);
-		if (OS.GTK3) {
-			imItem = OS.gtk_menu_item_new ();
+		byte[] buffer = Converter.wcsToMbcs (SWT.getMessage("SWT_InputMethods"), true);
+		if (GTK.GTK3) {
+			imItem = GTK.gtk_menu_item_new ();
 			if (imItem == 0) error (SWT.ERROR_NO_HANDLES);
 			long /*int*/ imageHandle = 0;
-			long /*int*/ labelHandle = OS.gtk_accel_label_new (buffer);
+			long /*int*/ labelHandle = GTK.gtk_accel_label_new (buffer);
 			if (labelHandle == 0) error (SWT.ERROR_NO_HANDLES);
-			if (OS.GTK_VERSION >= OS.VERSION (3, 16, 0)) {
-				OS.gtk_label_set_xalign (labelHandle, 0);
-				OS.gtk_widget_set_halign (labelHandle, OS.GTK_ALIGN_FILL);
+			if (GTK.GTK_VERSION >= OS.VERSION (3, 16, 0)) {
+				GTK.gtk_label_set_xalign (labelHandle, 0);
+				GTK.gtk_widget_set_halign (labelHandle, GTK.GTK_ALIGN_FILL);
 			} else {
-				OS.gtk_misc_set_alignment(labelHandle, 0, 0);
+				GTK.gtk_misc_set_alignment(labelHandle, 0, 0);
 			}
-			long /*int*/ boxHandle = gtk_box_new (OS.GTK_ORIENTATION_HORIZONTAL, false, 0);
+			long /*int*/ boxHandle = gtk_box_new (GTK.GTK_ORIENTATION_HORIZONTAL, false, 0);
 			if (boxHandle == 0) error (SWT.ERROR_NO_HANDLES);
 			if (OS.SWT_PADDED_MENU_ITEMS) {
-				imageHandle = OS.gtk_image_new();
+				imageHandle = GTK.gtk_image_new();
 				if (imageHandle == 0) error (SWT.ERROR_NO_HANDLES);
-				OS.gtk_image_set_pixel_size (imageHandle, 16);
+				GTK.gtk_image_set_pixel_size (imageHandle, 16);
 				if (boxHandle != 0) {
-					OS.gtk_container_add (boxHandle, imageHandle);
-					OS.gtk_widget_show (imageHandle);
+					GTK.gtk_container_add (boxHandle, imageHandle);
+					GTK.gtk_widget_show (imageHandle);
 				}
 			}
 			if (labelHandle != 0 && boxHandle != 0) {
-				OS.gtk_box_pack_end (boxHandle, labelHandle, true, true, 0);
-				OS.gtk_widget_show (labelHandle);
+				GTK.gtk_box_pack_end (boxHandle, labelHandle, true, true, 0);
+				GTK.gtk_widget_show (labelHandle);
 			}
 			if (boxHandle != 0) {
-				OS.gtk_container_add (imItem, boxHandle);
-				OS.gtk_widget_show (boxHandle);
+				GTK.gtk_container_add (imItem, boxHandle);
+				GTK.gtk_widget_show (boxHandle);
 			}
 		} else {
-			imItem = OS.gtk_image_menu_item_new_with_label (buffer);
+			imItem = GTK.gtk_image_menu_item_new_with_label (buffer);
 			if (imItem == 0) error (SWT.ERROR_NO_HANDLES);
 		}
-		OS.gtk_widget_show (imItem);
-		OS.gtk_menu_shell_insert (handle, imItem, -1);
+		GTK.gtk_widget_show (imItem);
+		GTK.gtk_menu_shell_insert (handle, imItem, -1);
 	}
-	long /*int*/ imSubmenu = OS.gtk_menu_new ();
-	OS.gtk_im_multicontext_append_menuitems (imHandle, imSubmenu);
-	OS.gtk_menu_item_set_submenu (imItem, imSubmenu);
+	long /*int*/ imSubmenu = GTK.gtk_menu_new ();
+	GTK.gtk_im_multicontext_append_menuitems (imHandle, imSubmenu);
+	GTK.gtk_menu_item_set_submenu (imItem, imSubmenu);
 }
 
 @Override
@@ -393,6 +458,9 @@ void createWidget (int index) {
 }
 
 void fixMenus (Decorations newParent) {
+	if (isDisposed()) {
+		return;
+	}
 	MenuItem [] items = getItems ();
 	for (int i=0; i<items.length; i++) {
 		items [i].fixMenus (newParent);
@@ -404,14 +472,14 @@ void fixMenus (Decorations newParent) {
 
 /*public*/ Rectangle getBounds () {
 	checkWidget();
-	if (!gtk_widget_get_mapped (handle)) {
+	if (!GTK.gtk_widget_get_mapped (handle)) {
 		return new Rectangle (0, 0, 0, 0);
 	}
 	long /*int*/ window = gtk_widget_get_window (handle);
 	int [] origin_x = new int [1], origin_y = new int [1];
-	OS.gdk_window_get_origin (window, origin_x, origin_y);
+	GDK.gdk_window_get_origin (window, origin_x, origin_y);
 	GtkAllocation allocation = new GtkAllocation ();
-	OS.gtk_widget_get_allocation (handle, allocation);
+	GTK.gtk_widget_get_allocation (handle, allocation);
 	int x = origin_x [0] + allocation.x;
 	int y = origin_y [0] + allocation.y;
 	int width = allocation.width;
@@ -453,7 +521,7 @@ public MenuItem getDefaultItem () {
  */
 public boolean getEnabled () {
 	checkWidget();
-	return OS.gtk_widget_get_sensitive (handle);
+	return GTK.gtk_widget_get_sensitive (handle);
 }
 
 /**
@@ -473,7 +541,7 @@ public boolean getEnabled () {
  */
 public MenuItem getItem (int index) {
 	checkWidget();
-	long /*int*/ list = OS.gtk_container_get_children (handle);
+	long /*int*/ list = GTK.gtk_container_get_children (handle);
 	if (list == 0) error (SWT.ERROR_CANNOT_GET_ITEM);
 	int count = OS.g_list_length (list);
 	if (imSeparator != 0) count--;
@@ -497,13 +565,13 @@ public MenuItem getItem (int index) {
  */
 public int getItemCount () {
 	checkWidget();
-	long /*int*/ list = OS.gtk_container_get_children (handle);
+	long /*int*/ list = GTK.gtk_container_get_children (handle);
 	if (list == 0) return 0;
 	int count = OS.g_list_length (list);
 	OS.g_list_free (list);
 	if (imSeparator != 0) count--;
 	if (imItem != 0) count--;
-	return count;
+	return Math.max (0, count);
 }
 
 /**
@@ -524,7 +592,7 @@ public int getItemCount () {
  */
 public MenuItem [] getItems () {
 	checkWidget();
-	long /*int*/ list = OS.gtk_container_get_children (handle);
+	long /*int*/ list = GTK.gtk_container_get_children (handle);
 	if (list == 0) return new MenuItem [0];
 	long /*int*/ originalList = list;
 	int count = OS.g_list_length (list);
@@ -677,7 +745,7 @@ public boolean getVisible () {
 			}
 		}
 	}
-	return gtk_widget_get_mapped (handle);
+	return GTK.gtk_widget_get_mapped (handle);
 }
 
 @Override
@@ -723,17 +791,47 @@ long /*int*/ gtk_show (long /*int*/ widget) {
 @Override
 long /*int*/ gtk_show_help (long /*int*/ widget, long /*int*/ helpType) {
 	if (sendHelpEvent (helpType)) {
-		OS.gtk_menu_shell_deactivate (handle);
+		GTK.gtk_menu_shell_deactivate (handle);
 		return 1;
 	}
 	return 0;
 }
 
+@Override
+long /*int*/ gtk_menu_popped_up (long /*int*/ widget, long /*int*/ flipped_rect, long /*int*/ final_rect, long /*int*/ flipped_x, long /*int*/ flipped_y) {
+	GdkRectangle finalRect = new GdkRectangle ();
+	OS.memmove (finalRect, final_rect, GDK.GdkRectangle_sizeof());
+	GdkRectangle flippedRect = new GdkRectangle ();
+	OS.memmove (flippedRect, flipped_rect, GDK.GdkRectangle_sizeof());
+	boolean flippedX = flipped_x == 1;
+	boolean flippedY = flipped_y == 1;
+	System.out.println("SWT_MENU_LOCATION_DEBUGGING enabled, printing positioning info for " + widget);
+	if (!OS.isX11()) System.out.println("Note: SWT is running on Wayland, coordinates will be parent-relative");
+	if (hasLocation) {
+		System.out.println("hasLocation is true and set coordinates are Point {" + this.x + ", " + this.y + "}");
+	} else {
+		System.out.println("hasLocation is not set, this is most likely a right click menu");
+	}
+	if (flippedX) System.out.println("Menu is inverted along the X-axis");
+	if (flippedY) System.out.println("Menu is inverted along the Y-axis");
+	System.out.println("Final menu position and size is Rectangle {" + finalRect.x + ", " + finalRect.y + ", " +
+			finalRect.width + ", " + finalRect.height + "}");
+	System.out.println("Flipped menu position and size is Rectangle {" + flippedRect.x + ", " + flippedRect.y + ", " +
+			flippedRect.width + ", " + flippedRect.height + "}");
+	System.out.println("");
+	return 0;
+}
+
+
 @Override
 void hookEvents () {
 	super.hookEvents ();
 	OS.g_signal_connect_closure_by_id (handle, display.signalIds [SHOW], 0, display.getClosure (SHOW), false);
 	OS.g_signal_connect_closure_by_id (handle, display.signalIds [HIDE], 0, display.getClosure (HIDE), false);
+	// Hook into the "popped-up" signal on GTK3.22+ if SWT_MENU_LOCATION_DEBUGGING has been set
+	if (GTK.GTK_VERSION >= OS.VERSION(3, 22, 0) && OS.SWT_MENU_LOCATION_DEBUGGING) {
+		OS.g_signal_connect_closure_by_id (handle, display.signalIds [POPPED_UP], 0, display.getClosure (POPPED_UP), false);
+	}
 	OS.g_signal_connect_closure_by_id (handle, display.signalIds [SHOW_HELP], 0, display.getClosure (SHOW_HELP), false);
 }
 
@@ -807,37 +905,6 @@ public boolean isVisible () {
 	return getVisible ();
 }
 
-@Override
-long /*int*/ menuPositionProc (long /*int*/ menu, long /*int*/ x, long /*int*/ y, long /*int*/ push_in, long /*int*/ user_data) {
-	/*
-	* Feature in GTK.  The menu position function sets the position of the
-	* top-left pixel of the menu.  If the menu would be off-screen, GTK will
-	* add a scroll arrow at the bottom and position the first menu entry at
-	* the specified position.  The fix is to flip the menu location to be
-	* completely inside the screen.
-	*
-	* NOTE: This code doesn't work for multiple monitors.
-	*/
-    GtkRequisition requisition = new GtkRequisition ();
-    gtk_widget_get_preferred_size (menu, requisition);
-    int screenHeight = OS.gdk_screen_height ();
-	int reqy = this.y;
-	if (reqy + requisition.height > screenHeight) {
-    	reqy = Math.max (0, reqy - requisition.height);
-	}
-    int screenWidth = OS.gdk_screen_width ();
-	int reqx = this.x;
-    if ((style & SWT.RIGHT_TO_LEFT) != 0) {
-    	if (reqx - requisition.width >= 0) reqx -= requisition.width;
-    } else {
-    	if (reqx + requisition.width > screenWidth) reqx -= requisition.width;
-    }
-	if (x != 0) OS.memmove (x, new int [] {reqx}, 4);
-	if (y != 0) OS.memmove (y, new int [] {reqy}, 4);
-	if (push_in != 0) OS.memmove (push_in, new int [] {1}, 4);
-	return 0;
-}
-
 @Override
 void releaseChildren (boolean destroy) {
 	MenuItem [] items = getItems ();
@@ -988,7 +1055,7 @@ public void setDefaultItem (MenuItem item) {
  */
 public void setEnabled (boolean enabled) {
 	checkWidget();
-	OS.gtk_widget_set_sensitive (handle, enabled);
+	GTK.gtk_widget_set_sensitive (handle, enabled);
 }
 
 /**
@@ -999,8 +1066,10 @@ public void setEnabled (boolean enabled) {
  * Note that this is different from most widgets where the
  * location of the widget is relative to the parent.
  * </p><p>
- * Note that the platform window manager ultimately has control
- * over the location of popup menus.
+ * Also note that the actual location of the menu is dependent
+ * on platform specific behavior. For example: on Linux with
+ * Wayland this operation is a hint due to lack of global
+ * coordinates.
  * </p>
  *
  * @param x the new x coordinate for the receiver
@@ -1021,7 +1090,10 @@ void setLocationInPixels (int x, int y) {
 	if ((style & (SWT.BAR | SWT.DROP_DOWN)) != 0) return;
 	this.x = x;
 	this.y = y;
-	hasLocation = true;
+	// Only set the hasLocation flag on X11.
+	if (OS.isX11()) {
+		hasLocation = true;
+	}
 }
 
 /**
@@ -1090,8 +1162,8 @@ void _setOrientation (int orientation) {
 @Override
 void setOrientation (boolean create) {
     if ((style & SWT.RIGHT_TO_LEFT) != 0 || !create) {
-    	int dir = (style & SWT.RIGHT_TO_LEFT) != 0 ? OS.GTK_TEXT_DIR_RTL : OS.GTK_TEXT_DIR_LTR;
-        if (handle != 0) OS.gtk_widget_set_direction (handle, dir);
+    	int dir = (style & SWT.RIGHT_TO_LEFT) != 0 ? GTK.GTK_TEXT_DIR_RTL : GTK.GTK_TEXT_DIR_LTR;
+        if (handle != 0) GTK.gtk_widget_set_direction (handle, dir);
         MenuItem [] items = getItems ();
         for (int i = 0; i < items.length; i++) {
             items [i].setOrientation (create);
@@ -1099,6 +1171,81 @@ void setOrientation (boolean create) {
     }
 }
 
+/**
+ * Lack of absolute coordinates make Wayland event windows inaccurate.
+ * Currently the best approach is to the use the GdkWindow of the mouse
+ * pointer. See bug 530059 and 532074.<p>
+ *
+ * @param eventPtr a pointer to the GdkEvent
+ */
+void adjustParentWindowWayland (long /*int*/ eventPtr) {
+	if (!OS.isX11()) {
+		long /*int*/ display = GDK.gdk_display_get_default ();
+		long /*int*/ pointer = GDK.gdk_get_pointer(display);
+		long /*int*/ deviceWindow = GDK.gdk_device_get_window_at_position(pointer, null, null);
+		OS.g_object_ref(deviceWindow);
+		int eventType = GDK.gdk_event_get_event_type(eventPtr);
+		switch (eventType) {
+			case GDK.GDK_BUTTON_PRESS:
+				GdkEventButton eventButton = new GdkEventButton();
+				OS.memmove (eventButton, eventPtr, GdkEventButton.sizeof);
+				eventButton.window = deviceWindow;
+				OS.memmove(eventPtr, eventButton, GdkEventButton.sizeof);
+				break;
+			case GDK.GDK_KEY_PRESS:
+				GdkEventKey eventKey = new GdkEventKey();
+				OS.memmove (eventKey, eventPtr, GdkEventKey.sizeof);
+				eventKey.window = deviceWindow;
+				OS.memmove(eventPtr, eventKey, GdkEventKey.sizeof);
+				break;
+		}
+	}
+	return;
+}
+
+/**
+ * Feature in GTK3 on X11: context menus in SWT are populated
+ * dynamically, sometimes asynchronously outside of SWT
+ * (i.e. in Platform UI). This means that items are added and
+ * removed just before the menu is shown. This method of
+ * changing the menu content can sometimes cause sizing issues
+ * internally in GTK, specifically with the height of the
+ * toplevel GdkWindow. <p>
+ *
+ * The fix is to cache the number of items popped up previously,
+ * and if the number of items in the current menu (to be popped up)
+ * is different, then:<ul>
+ *     <li>get the preferred height of the menu</li>
+ *     <li>set the toplevel GdkWindow to that height</li></ul>
+ *
+ * @param itemCount the current number of items in the menu, just
+ * before it's about to be shown/popped-up
+ */
+void verifyMenuPosition (int itemCount) {
+	if (GTK.GTK3 && OS.isX11()) {
+		if (itemCount != poppedUpCount && poppedUpCount != 0) {
+			int [] naturalHeight = new int [1];
+			/*
+			 * We need to "show" the menu before fetching the preferred height.
+			 * Note, this does not actually pop-up the menu.
+			 */
+			GTK.gtk_widget_show(handle);
+			/*
+			 * Menus are height-for-width only: use gtk_widget_get_preferred_height()
+			 * instead of gtk_widget_get_preferred_size().
+			 */
+			GTK.gtk_widget_get_preferred_height(handle, null, naturalHeight);
+			if (naturalHeight[0] > 0) {
+				long /*int*/ topLevelWidget = GTK.gtk_widget_get_toplevel(handle);
+				long /*int*/ topLevelWindow = GTK.gtk_widget_get_window(topLevelWidget);
+				int width = GDK.gdk_window_get_width(topLevelWindow);
+				GDK.gdk_window_resize(topLevelWindow, width, naturalHeight[0]);
+			}
+		}
+	}
+	return;
+}
+
 /**
  * Marks the receiver as visible if the argument is <code>true</code>,
  * and marks it invisible otherwise.
@@ -1126,3 +1273,4 @@ public void setVisible (boolean visible) {
 	}
 }
 }
+
