@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,8 +10,10 @@
  *******************************************************************************/
 package org.eclipse.swt.examples.addressbook;
 
+import static org.eclipse.swt.events.MenuListener.menuShownAdapter;
+import static org.eclipse.swt.events.SelectionListener.widgetDefaultSelectedAdapter;
+import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 
-/* Imports */
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileNotFoundException;
@@ -23,12 +25,7 @@ import java.util.Comparator;
 import java.util.ResourceBundle;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.MenuAdapter;
-import org.eclipse.swt.events.MenuEvent;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
-import org.eclipse.swt.events.ShellAdapter;
-import org.eclipse.swt.events.ShellEvent;
+import org.eclipse.swt.events.ShellListener;
 import org.eclipse.swt.graphics.Cursor;
 import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.widgets.Display;
@@ -83,12 +80,7 @@ public static void main(String[] args) {
 public Shell open(Display display) {
 	shell = new Shell(display);
 	shell.setLayout(new FillLayout());
-	shell.addShellListener(new ShellAdapter() {
-		@Override
-		public void shellClosed(ShellEvent e) {
-			e.doit = closeAddressBook();
-		}
-	});
+	shell.addShellListener(ShellListener.shellClosedAdapter(e -> e.doit = closeAddressBook()));
 
 	createMenuBar();
 
@@ -100,24 +92,16 @@ public Shell open(Display display) {
 	table = new Table(shell, SWT.SINGLE | SWT.BORDER | SWT.FULL_SELECTION);
 	table.setHeaderVisible(true);
 	table.setMenu(createPopUpMenu());
-	table.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetDefaultSelected(SelectionEvent e) {
-			TableItem[] items = table.getSelection();
-			if (items.length > 0) editEntry(items[0]);
-		}
-	});
+	table.addSelectionListener(widgetDefaultSelectedAdapter(e -> {
+		TableItem[] items = table.getSelection();
+		if (items.length > 0) editEntry(items[0]);
+	}));
 	for(int i = 0; i < columnNames.length; i++) {
 		TableColumn column = new TableColumn(table, SWT.NONE);
 		column.setText(columnNames[i]);
 		column.setWidth(150);
 		final int columnIndex = i;
-		column.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				sort(columnIndex);
-			}
-		});
+		column.addSelectionListener(widgetSelectedAdapter(e -> sort(columnIndex)));
 	}
 
 	newAddressBook();
@@ -143,8 +127,8 @@ private boolean closeAddressBook() {
 	}
 
 	TableItem[] items = table.getItems();
-	for (int i = 0; i < items.length; i ++) {
-		items[i].dispose();
+	for (TableItem item : items) {
+		item.dispose();
 	}
 
 	return true;
@@ -300,12 +284,10 @@ private void openAddressBook() {
 	Cursor waitCursor = shell.getDisplay().getSystemCursor(SWT.CURSOR_WAIT);
 	shell.setCursor(waitCursor);
 
-	FileReader fileReader = null;
-	BufferedReader bufferedReader = null;
 	String[] data = new String[0];
-	try {
-		fileReader = new FileReader(file.getAbsolutePath());
-		bufferedReader = new BufferedReader(fileReader);
+	try (FileReader fileReader = new FileReader(file.getAbsolutePath());
+			BufferedReader bufferedReader = new BufferedReader(fileReader);){
+
 		String nextLine = bufferedReader.readLine();
 		while (nextLine != null){
 			String[] newData = new String[data.length + 1];
@@ -321,23 +303,13 @@ private void openAddressBook() {
 		displayError(resAddressBook.getString("IO_error_read") + "\n" + file.getName());
 		return;
 	} finally {
-
 		shell.setCursor(null);
-
-		if(fileReader != null) {
-			try {
-				fileReader.close();
-			} catch(IOException e) {
-				displayError(resAddressBook.getString("IO_error_close") + "\n" + file.getName());
-				return;
-			}
-		}
 	}
 
 	String[][] tableInfo = new String[data.length][table.getColumnCount()];
 	int writeIndex = 0;
-	for (int i = 0; i < data.length; i++) {
-		String[] line = decodeLine(data[i]);
+	for (String element : data) {
+		String[] line = decodeLine(element);
 		if (line != null) tableInfo[writeIndex++] = line;
 	}
 	if (writeIndex != data.length) {
@@ -347,9 +319,9 @@ private void openAddressBook() {
 	}
 	Arrays.sort(tableInfo, new RowComparator(0));
 
-	for (int i = 0; i < tableInfo.length; i++) {
+	for (String[] element : tableInfo) {
 		TableItem item = new TableItem(table, SWT.NONE);
-		item.setText(tableInfo[i]);
+		item.setText(element);
 	}
 	shell.setText(resAddressBook.getString("Title_bar")+fileDialog.getFileName());
 	isModified = false;
@@ -371,11 +343,9 @@ private boolean save() {
 		lines[i] = encodeLine(itemText);
 	}
 
-	FileWriter fileWriter = null;
-	try {
-		fileWriter = new FileWriter(file.getAbsolutePath(), false);
-		for (int i = 0; i < lines.length; i++) {
-			fileWriter.write(lines[i]);
+	try (FileWriter fileWriter = new FileWriter(file.getAbsolutePath(), false);){
+		for (String line : lines) {
+			fileWriter.write(line);
 		}
 	} catch(FileNotFoundException e) {
 		displayError(resAddressBook.getString("File_not_found") + "\n" + file.getName());
@@ -385,15 +355,6 @@ private boolean save() {
 		return false;
 	} finally {
 		shell.setCursor(null);
-
-		if(fileWriter != null) {
-			try {
-				fileWriter.close();
-			} catch(IOException e) {
-				displayError(resAddressBook.getString("IO_error_close") + "\n" + file.getName());
-				return false;
-			}
-		}
 	}
 
 	shell.setText(resAddressBook.getString("Title_bar")+file.getName());
@@ -477,39 +438,28 @@ private void createFileMenu(Menu menuBar) {
 	 * Adds a listener to handle enabling and disabling
 	 * some items in the Edit submenu.
 	 */
-	menu.addMenuListener(new MenuAdapter() {
-		@Override
-		public void menuShown(MenuEvent e) {
-			Menu menu = (Menu)e.widget;
-			MenuItem[] items = menu.getItems();
-			items[1].setEnabled(table.getSelectionCount() != 0); // edit contact
-			items[5].setEnabled((file != null) && isModified); // save
-			items[6].setEnabled(table.getItemCount() != 0); // save as
-		}
-	});
+	menu.addMenuListener(menuShownAdapter(e -> {
+		Menu menu1 = (Menu) e.widget;
+		MenuItem[] items = menu1.getItems();
+		items[1].setEnabled(table.getSelectionCount() != 0); // edit contact
+		items[5].setEnabled((file != null) && isModified); // save
+		items[6].setEnabled(table.getItemCount() != 0); // save as
+	}));
 
 
 	//File -> New Contact
 	MenuItem subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("New_contact"));
 	subItem.setAccelerator(SWT.MOD1 + 'N');
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			newEntry();
-		}
-	});
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> newEntry()));
 	subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("Edit_contact"));
 	subItem.setAccelerator(SWT.MOD1 + 'E');
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			TableItem[] items = table.getSelection();
-			if (items.length == 0) return;
-			editEntry(items[0]);
-		}
-	});
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> {
+		TableItem[] items = table.getSelection();
+		if (items.length == 0) return;
+		editEntry(items[0]);
+	}));
 
 
 	new MenuItem(menu, SWT.SEPARATOR);
@@ -518,49 +468,33 @@ private void createFileMenu(Menu menuBar) {
 	subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("New_address_book"));
 	subItem.setAccelerator(SWT.MOD1 + 'B');
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			if (closeAddressBook()) {
-				newAddressBook();
-			}
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> {
+		if (closeAddressBook()) {
+			newAddressBook();
 		}
-	});
+	}));
 
 	//File -> Open
 	subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("Open_address_book"));
 	subItem.setAccelerator(SWT.MOD1 + 'O');
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			if (closeAddressBook()) {
-				openAddressBook();
-			}
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> {
+		if (closeAddressBook()) {
+			openAddressBook();
 		}
-	});
+	}));
 
 	//File -> Save.
 	subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("Save_address_book"));
 	subItem.setAccelerator(SWT.MOD1 + 'S');
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			save();
-		}
-	});
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> save()));
 
 	//File -> Save As.
 	subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("Save_book_as"));
 	subItem.setAccelerator(SWT.MOD1 + 'A');
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			saveAs();
-		}
-	});
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> saveAs()));
 
 
 	new MenuItem(menu, SWT.SEPARATOR);
@@ -568,12 +502,7 @@ private void createFileMenu(Menu menuBar) {
 	//File -> Exit.
 	subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("Exit"));
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			shell.close();
-		}
-	});
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> shell.close()));
 }
 
 /**
@@ -598,74 +527,60 @@ private MenuItem createEditMenu(Menu menuBar) {
 	 * Add a listener to handle enabling and disabling
 	 * some items in the Edit submenu.
 	 */
-	menu.addMenuListener(new MenuAdapter() {
-		@Override
-		public void menuShown(MenuEvent e) {
-			Menu menu = (Menu)e.widget;
-			MenuItem[] items = menu.getItems();
-			int count = table.getSelectionCount();
-			items[0].setEnabled(count != 0); // edit
-			items[1].setEnabled(count != 0); // copy
-			items[2].setEnabled(copyBuffer != null); // paste
-			items[3].setEnabled(count != 0); // delete
-			items[5].setEnabled(table.getItemCount() != 0); // sort
-		}
-	});
+	menu.addMenuListener(menuShownAdapter(e -> {
+		Menu menu1 = (Menu) e.widget;
+		MenuItem[] items = menu1.getItems();
+		int count = table.getSelectionCount();
+		items[0].setEnabled(count != 0); // edit
+		items[1].setEnabled(count != 0); // copy
+		items[2].setEnabled(copyBuffer != null); // paste
+		items[3].setEnabled(count != 0); // delete
+		items[5].setEnabled(table.getItemCount() != 0); // sort
+	}));
 
 	//Edit -> Edit
 	MenuItem subItem = new MenuItem(menu, SWT.PUSH);
 	subItem.setText(resAddressBook.getString("Edit"));
 	subItem.setAccelerator(SWT.MOD1 + 'E');
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			TableItem[] items = table.getSelection();
-			if (items.length == 0) return;
-			editEntry(items[0]);
-		}
-	});
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> {
+		TableItem[] items = table.getSelection();
+		if (items.length == 0) return;
+		editEntry(items[0]);
+	}));
 
 	//Edit -> Copy
 	subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("Copy"));
 	subItem.setAccelerator(SWT.MOD1 + 'C');
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			TableItem[] items = table.getSelection();
-			if (items.length == 0) return;
-			copyBuffer = new String[table.getColumnCount()];
-			for (int i = 0; i < copyBuffer.length; i++) {
-				copyBuffer[i] = items[0].getText(i);
-			}
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> {
+		TableItem[] items = table.getSelection();
+		if (items.length == 0) return;
+		copyBuffer = new String[table.getColumnCount()];
+		for (int i = 0; i < copyBuffer.length; i++) {
+			copyBuffer[i] = items[0].getText(i);
 		}
-	});
+	}));
 
 	//Edit -> Paste
 	subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("Paste"));
 	subItem.setAccelerator(SWT.MOD1 + 'V');
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			if (copyBuffer == null) return;
-			TableItem item = new TableItem(table, SWT.NONE);
-			item.setText(copyBuffer);
-			isModified = true;
-		}
-	});
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> {
+		if (copyBuffer == null) return;
+		TableItem tableItem = new TableItem(table, SWT.NONE);
+		tableItem.setText(copyBuffer);
+		isModified = true;
+	}));
 
 	//Edit -> Delete
 	subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("Delete"));
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			TableItem[] items = table.getSelection();
-			if (items.length == 0) return;
-			items[0].dispose();
-			isModified = true;		}
-	});
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> {
+		TableItem[] items = table.getSelection();
+		if (items.length == 0) return;
+		items[0].dispose();
+		isModified = true;
+	}));
 
 	new MenuItem(menu, SWT.SEPARATOR);
 
@@ -694,12 +609,7 @@ private Menu createSortMenu() {
 		subitem = new MenuItem (submenu, SWT.NONE);
 		subitem.setText(columnNames [i]);
 		final int column = i;
-		subitem.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				sort(column);
-			}
-		});
+		subitem.addSelectionListener(widgetSelectedAdapter( e -> sort(column)));
 
 	}
 
@@ -726,28 +636,20 @@ private void createSearchMenu(Menu menuBar) {
 	item = new MenuItem(searchMenu, SWT.NONE);
 	item.setText(resAddressBook.getString("Find"));
 	item.setAccelerator(SWT.MOD1 + 'F');
-	item.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			searchDialog.setMatchCase(false);
-			searchDialog.setMatchWord(false);
-			searchDialog.setSearchDown(true);
-			searchDialog.setSearchString("");
-			searchDialog.setSelectedSearchArea(0);
-			searchDialog.open();
-		}
-	});
+	item.addSelectionListener(widgetSelectedAdapter( e -> {
+		searchDialog.setMatchCase(false);
+		searchDialog.setMatchWord(false);
+		searchDialog.setSearchDown(true);
+		searchDialog.setSearchString("");
+		searchDialog.setSelectedSearchArea(0);
+		searchDialog.open();
+	}));
 
 	//Search -> Find Next
 	item = new MenuItem(searchMenu, SWT.NONE);
 	item.setText(resAddressBook.getString("Find_next"));
 	item.setAccelerator(SWT.F3);
-	item.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			searchDialog.open();
-		}
-	});
+	item.addSelectionListener(widgetSelectedAdapter( e -> searchDialog.open()));
 }
 
 /**
@@ -764,96 +666,71 @@ private Menu createPopUpMenu() {
 	 * Adds a listener to handle enabling and disabling
 	 * some items in the Edit submenu.
 	 */
-	popUpMenu.addMenuListener(new MenuAdapter() {
-		@Override
-		public void menuShown(MenuEvent e) {
-			Menu menu = (Menu)e.widget;
-			MenuItem[] items = menu.getItems();
-			int count = table.getSelectionCount();
-			items[2].setEnabled(count != 0); // edit
-			items[3].setEnabled(count != 0); // copy
-			items[4].setEnabled(copyBuffer != null); // paste
-			items[5].setEnabled(count != 0); // delete
-			items[7].setEnabled(table.getItemCount() != 0); // find
-		}
-	});
+	popUpMenu.addMenuListener(menuShownAdapter(e -> {
+		Menu menu = (Menu) e.widget;
+		MenuItem[] items = menu.getItems();
+		int count = table.getSelectionCount();
+		items[2].setEnabled(count != 0); // edit
+		items[3].setEnabled(count != 0); // copy
+		items[4].setEnabled(copyBuffer != null); // paste
+		items[5].setEnabled(count != 0); // delete
+		items[7].setEnabled(table.getItemCount() != 0); // find
+	}));
 
 	//New
 	MenuItem item = new MenuItem(popUpMenu, SWT.PUSH);
 	item.setText(resAddressBook.getString("Pop_up_new"));
-	item.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			newEntry();
-		}
-	});
+	item.addSelectionListener(widgetSelectedAdapter( e -> newEntry()));
 
 	new MenuItem(popUpMenu, SWT.SEPARATOR);
 
 	//Edit
 	item = new MenuItem(popUpMenu, SWT.PUSH);
 	item.setText(resAddressBook.getString("Pop_up_edit"));
-	item.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			TableItem[] items = table.getSelection();
-			if (items.length == 0) return;
-			editEntry(items[0]);
-		}
-	});
+	item.addSelectionListener(widgetSelectedAdapter( e -> {
+		TableItem[] items = table.getSelection();
+		if (items.length == 0) return;
+		editEntry(items[0]);
+	}));
 
 	//Copy
 	item = new MenuItem(popUpMenu, SWT.PUSH);
 	item.setText(resAddressBook.getString("Pop_up_copy"));
-	item.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			TableItem[] items = table.getSelection();
-			if (items.length == 0) return;
-			copyBuffer = new String[table.getColumnCount()];
-			for (int i = 0; i < copyBuffer.length; i++) {
-				copyBuffer[i] = items[0].getText(i);
-			}
+	item.addSelectionListener(widgetSelectedAdapter( e -> {
+		TableItem[] items = table.getSelection();
+		if (items.length == 0) return;
+		copyBuffer = new String[table.getColumnCount()];
+		for (int i = 0; i < copyBuffer.length; i++) {
+			copyBuffer[i] = items[0].getText(i);
 		}
-	});
+	}));
 
 	//Paste
 	item = new MenuItem(popUpMenu, SWT.PUSH);
 	item.setText(resAddressBook.getString("Pop_up_paste"));
-	item.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			if (copyBuffer == null) return;
-			TableItem item = new TableItem(table, SWT.NONE);
-			item.setText(copyBuffer);
-			isModified = true;
-		}
-	});
+	item.addSelectionListener(widgetSelectedAdapter( e -> {
+		if (copyBuffer == null) return;
+		TableItem tableItem = new TableItem(table, SWT.NONE);
+		tableItem.setText(copyBuffer);
+		isModified = true;
+	}));
 
 	//Delete
 	item = new MenuItem(popUpMenu, SWT.PUSH);
 	item.setText(resAddressBook.getString("Pop_up_delete"));
-	item.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			TableItem[] items = table.getSelection();
-			if (items.length == 0) return;
-			items[0].dispose();
-			isModified = true;
-		}
-	});
+	item.addSelectionListener(widgetSelectedAdapter( e -> {
+		TableItem[] items = table.getSelection();
+		if (items.length == 0) return;
+		items[0].dispose();
+		isModified = true;
+	}));
 
 	new MenuItem(popUpMenu, SWT.SEPARATOR);
 
 	//Find...
 	item = new MenuItem(popUpMenu, SWT.PUSH);
 	item.setText(resAddressBook.getString("Pop_up_find"));
-	item.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			searchDialog.open();
-		}
-	});
+	item.addSelectionListener(widgetSelectedAdapter( e -> searchDialog.open()));
 
 	return popUpMenu;
 }
@@ -878,15 +755,12 @@ private void createHelpMenu(Menu menuBar) {
 	//Help -> About Text Editor
 	MenuItem subItem = new MenuItem(menu, SWT.NONE);
 	subItem.setText(resAddressBook.getString("About"));
-	subItem.addSelectionListener(new SelectionAdapter() {
-		@Override
-		public void widgetSelected(SelectionEvent e) {
-			MessageBox box = new MessageBox(shell, SWT.NONE);
-			box.setText(resAddressBook.getString("About_1") + shell.getText());
-			box.setMessage(shell.getText() + resAddressBook.getString("About_2"));
-			box.open();
-		}
-	});
+	subItem.addSelectionListener(widgetSelectedAdapter( e -> {
+		MessageBox box = new MessageBox(shell, SWT.NONE);
+		box.setText(resAddressBook.getString("About_1") + shell.getText());
+		box.setMessage(shell.getText() + resAddressBook.getString("About_2"));
+		box.open();
+	}));
 }
 
 /**
