@@ -11,18 +11,33 @@
 package org.eclipse.swt.examples.controlexample;
 
 
-import org.eclipse.swt.*;
-import org.eclipse.swt.graphics.*;
-import org.eclipse.swt.widgets.*;
-import org.eclipse.swt.layout.*;
-import org.eclipse.swt.printing.*;
-import org.eclipse.swt.events.*;
+import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
+
+import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.events.SelectionListener;
+import org.eclipse.swt.graphics.FontData;
+import org.eclipse.swt.graphics.RGB;
+import org.eclipse.swt.layout.GridData;
+import org.eclipse.swt.layout.GridLayout;
+import org.eclipse.swt.printing.PrintDialog;
+import org.eclipse.swt.printing.PrinterData;
+import org.eclipse.swt.widgets.Button;
+import org.eclipse.swt.widgets.ColorDialog;
+import org.eclipse.swt.widgets.Combo;
+import org.eclipse.swt.widgets.DirectoryDialog;
+import org.eclipse.swt.widgets.FileDialog;
+import org.eclipse.swt.widgets.FontDialog;
+import org.eclipse.swt.widgets.Group;
+import org.eclipse.swt.widgets.MessageBox;
+import org.eclipse.swt.widgets.Text;
+import org.eclipse.swt.widgets.Widget;
 
 class DialogTab extends Tab {
 	/* Example widgets and groups that contain them */
 	Group dialogStyleGroup, resultGroup;
 	Text textWidget;
-	
+
 	/* Style widgets added to the "Style" group */
 	Combo dialogCombo;
 	Button createButton;
@@ -75,7 +90,7 @@ class DialogTab extends Tab {
 		boolean abort = abortButton.getSelection ();
 		boolean retry = retryButton.getSelection ();
 		boolean ignore = ignoreButton.getSelection ();
-		
+
 		okButton.setEnabled (!(yes || no || retry || abort || ignore));
 		cancelButton.setEnabled (!(abort || ignore || (yes != no)));
 		yesButton.setEnabled (!(ok || retry || abort || ignore || (cancel && !yes && !no)));
@@ -83,7 +98,7 @@ class DialogTab extends Tab {
 		retryButton.setEnabled (!(ok || yes || no));
 		abortButton.setEnabled (!(ok || cancel || yes || no));
 		ignoreButton.setEnabled (!(ok || cancel || yes || no));
-		
+
 		createButton.setEnabled (
 				!(ok || cancel || yes || no || retry || abort || ignore) ||
 				ok ||
@@ -92,17 +107,17 @@ class DialogTab extends Tab {
 				(yes && no && cancel) ||
 				(retry && cancel) ||
 				(abort && retry && ignore));
-		
+
 
 	}
-	
+
 	/**
 	 * Handle the create button selection event.
 	 *
 	 * @param event org.eclipse.swt.events.SelectionEvent
 	 */
 	void createButtonSelected(SelectionEvent event) {
-	
+
 		/* Compute the appropriate dialog style */
 		int style = getDefaultStyle();
 		if (okButton.getEnabled () && okButton.getSelection ()) style |= SWT.OK;
@@ -124,10 +139,10 @@ class DialogTab extends Tab {
 		if (saveButton.getEnabled () && saveButton.getSelection ()) style |= SWT.SAVE;
 		if (openButton.getEnabled () && openButton.getSelection ()) style |= SWT.OPEN;
 		if (multiButton.getEnabled () && multiButton.getSelection ()) style |= SWT.MULTI;
-	
+
 		/* Open the appropriate dialog type */
 		String name = dialogCombo.getText ();
-		
+
 		if (name.equals (ControlExample.getResourceString("ColorDialog"))) {
 			ColorDialog dialog = new ColorDialog (shell ,style);
 			if (usePreviousResultButton.getSelection()) {
@@ -137,13 +152,13 @@ class DialogTab extends Tab {
 			dialog.setText (ControlExample.getResourceString("Title"));
 			RGB result = dialog.open ();
 			textWidget.append (ControlExample.getResourceString("ColorDialog") + Text.DELIMITER);
-			textWidget.append (ControlExample.getResourceString("Result", new String [] {"" + result}) + Text.DELIMITER);
+			textWidget.append (ControlExample.getResourceString("Result", "" + result) + Text.DELIMITER);
 			textWidget.append ("getRGB() = " + dialog.getRGB() + Text.DELIMITER);
 			textWidget.append ("getRGBs() =" + Text.DELIMITER);
 			RGB[] rgbs = dialog.getRGBs();
 			if (rgbs != null) {
-				for (int i=0; i<rgbs.length; i++) {
-					textWidget.append ("\t" + rgbs [i] + Text.DELIMITER);
+				for (RGB rgbColor : rgbs) {
+					textWidget.append ("\t" + rgbColor + Text.DELIMITER);
 				}
 			}
 			textWidget.append (Text.DELIMITER);
@@ -151,7 +166,7 @@ class DialogTab extends Tab {
 			colorDialogCustomColors = rgbs;
 			return;
 		}
-		
+
 		if (name.equals (ControlExample.getResourceString("DirectoryDialog"))) {
 			DirectoryDialog dialog = new DirectoryDialog (shell, style);
 			if (usePreviousResultButton.getSelection()) {
@@ -161,11 +176,11 @@ class DialogTab extends Tab {
 			dialog.setText (ControlExample.getResourceString("Title"));
 			String result = dialog.open ();
 			textWidget.append (ControlExample.getResourceString("DirectoryDialog") + Text.DELIMITER);
-			textWidget.append (ControlExample.getResourceString("Result", new String [] {"" + result}) + Text.DELIMITER + Text.DELIMITER);
+			textWidget.append (ControlExample.getResourceString("Result", "" + result) + Text.DELIMITER + Text.DELIMITER);
 			directoryDialogResult = result;
 			return;
 		}
-		
+
 		if (name.equals (ControlExample.getResourceString("FileDialog"))) {
 			FileDialog dialog = new FileDialog (shell, style);
 			if (usePreviousResultButton.getSelection()) {
@@ -177,21 +192,21 @@ class DialogTab extends Tab {
 			dialog.setText (ControlExample.getResourceString("Title"));
 			String result = dialog.open();
 			textWidget.append (ControlExample.getResourceString("FileDialog") + Text.DELIMITER);
-			textWidget.append (ControlExample.getResourceString("Result", new String [] {"" + result}) + Text.DELIMITER);
+			textWidget.append (ControlExample.getResourceString("Result", "" + result) + Text.DELIMITER);
 			textWidget.append ("getFilterIndex() =" + dialog.getFilterIndex() + Text.DELIMITER);
 			textWidget.append ("getFilterPath() =" + dialog.getFilterPath() + Text.DELIMITER);
 			textWidget.append ("getFileName() =" + dialog.getFileName() + Text.DELIMITER);
 			textWidget.append ("getFileNames() =" + Text.DELIMITER);
 			String [] files = dialog.getFileNames ();
-			for (int i=0; i<files.length; i++) {
-				textWidget.append ("\t" + files [i] + Text.DELIMITER);
+			for (String file : files) {
+				textWidget.append ("\t" + file + Text.DELIMITER);
 			}
 			textWidget.append (Text.DELIMITER);
 			fileDialogResult = result;
 			fileDialogIndexResult = dialog.getFilterIndex();
 			return;
 		}
-		
+
 		if (name.equals (ControlExample.getResourceString("FontDialog"))) {
 			FontDialog dialog = new FontDialog (shell, style);
 			if (usePreviousResultButton.getSelection()) {
@@ -202,12 +217,12 @@ class DialogTab extends Tab {
 			dialog.setText (ControlExample.getResourceString("Title"));
 			FontData result = dialog.open ();
 			textWidget.append (ControlExample.getResourceString("FontDialog") + Text.DELIMITER);
-			textWidget.append (ControlExample.getResourceString("Result", new String [] {"" + result}) + Text.DELIMITER);
+			textWidget.append (ControlExample.getResourceString("Result", "" + result) + Text.DELIMITER);
 			textWidget.append ("getFontList() =" + Text.DELIMITER);
 			FontData [] fonts = dialog.getFontList ();
 			if (fonts != null) {
-				for (int i=0; i<fonts.length; i++) {
-					textWidget.append ("\t" + fonts [i] + Text.DELIMITER);
+				for (FontData font : fonts) {
+					textWidget.append ("\t" + font + Text.DELIMITER);
 				}
 			}
 			textWidget.append ("getEffectsVisible() = " + dialog.getEffectsVisible() + Text.DELIMITER);
@@ -216,7 +231,7 @@ class DialogTab extends Tab {
 			fontDialogColorResult = dialog.getRGB();
 			return;
 		}
-		
+
 		if (name.equals (ControlExample.getResourceString("PrintDialog"))) {
 			PrintDialog dialog = new PrintDialog (shell, style);
 			if (usePreviousResultButton.getSelection()) {
@@ -225,7 +240,7 @@ class DialogTab extends Tab {
 			dialog.setText(ControlExample.getResourceString("Title"));
 			PrinterData result = dialog.open ();
 			textWidget.append (ControlExample.getResourceString("PrintDialog") + Text.DELIMITER);
-			textWidget.append (ControlExample.getResourceString("Result", new String [] {"" + result}) + Text.DELIMITER);
+			textWidget.append (ControlExample.getResourceString("Result", "" + result) + Text.DELIMITER);
 			if (result != null) {
 				textWidget.append ("printerData.scope = " + (result.scope == PrinterData.PAGE_RANGE ? "PAGE_RANGE" : result.scope == PrinterData.SELECTION ? "SELECTION" : "ALL_PAGES") + Text.DELIMITER);
 				textWidget.append ("printerData.startPage = " + result.startPage + Text.DELIMITER);
@@ -241,7 +256,7 @@ class DialogTab extends Tab {
 			printDialogResult = result;
 			return;
 		}
-	
+
 		if (name.equals(ControlExample.getResourceString("MessageBox"))) {
 			MessageBox dialog = new MessageBox (shell, style);
 			dialog.setMessage (ControlExample.getResourceString("Example_string"));
@@ -254,36 +269,36 @@ class DialogTab extends Tab {
 			 */
 			switch (result) {
 				case SWT.OK:
-					textWidget.append (ControlExample.getResourceString("Result", new String [] {"SWT.OK"}));
+					textWidget.append (ControlExample.getResourceString("Result", "SWT.OK"));
 					break;
 				case SWT.YES:
-					textWidget.append (ControlExample.getResourceString("Result", new String [] {"SWT.YES"}));
+					textWidget.append (ControlExample.getResourceString("Result", "SWT.YES"));
 					break;
 				case SWT.NO:
-					textWidget.append (ControlExample.getResourceString("Result", new String [] {"SWT.NO"}));
+					textWidget.append (ControlExample.getResourceString("Result", "SWT.NO"));
 					break;
 				case SWT.CANCEL:
-					textWidget.append (ControlExample.getResourceString("Result", new String [] {"SWT.CANCEL"}));
+					textWidget.append (ControlExample.getResourceString("Result", "SWT.CANCEL"));
 					break;
-				case SWT.ABORT: 
-					textWidget.append (ControlExample.getResourceString("Result", new String [] {"SWT.ABORT"}));
+				case SWT.ABORT:
+					textWidget.append (ControlExample.getResourceString("Result", "SWT.ABORT"));
 					break;
 				case SWT.RETRY:
-					textWidget.append (ControlExample.getResourceString("Result", new String [] {"SWT.RETRY"}));
+					textWidget.append (ControlExample.getResourceString("Result", "SWT.RETRY"));
 					break;
 				case SWT.IGNORE:
-					textWidget.append (ControlExample.getResourceString("Result", new String [] {"SWT.IGNORE"}));
+					textWidget.append (ControlExample.getResourceString("Result", "SWT.IGNORE"));
 					break;
 				default:
-					textWidget.append(ControlExample.getResourceString("Result", new String [] {"" + result}));
+					textWidget.append(ControlExample.getResourceString("Result", "" + result));
 					break;
 			}
 			textWidget.append (Text.DELIMITER + Text.DELIMITER);
 		}
 	}
-	
+
 	/**
-	 * Creates the "Control" group. 
+	 * Creates the "Control" group.
 	 */
 	@Override
 	void createControlGroup () {
@@ -291,7 +306,7 @@ class DialogTab extends Tab {
 		 * Create the "Control" group.  This is the group on the
 		 * right half of each example tab.  It consists of the
 		 * style group, the display group and the size group.
-		 */			
+		 */
 		controlGroup = new Group (tabFolderPage, SWT.NONE);
 		GridLayout gridLayout= new GridLayout ();
 		controlGroup.setLayout(gridLayout);
@@ -299,7 +314,7 @@ class DialogTab extends Tab {
 		gridLayout.makeColumnsEqualWidth = true;
 		controlGroup.setLayoutData (new GridData (GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL));
 		controlGroup.setText (ControlExample.getResourceString("Parameters"));
-		
+
 		/*
 		 * Create a group to hold the dialog style combo box and
 		 * create dialog button.
@@ -311,16 +326,16 @@ class DialogTab extends Tab {
 		dialogStyleGroup.setLayoutData (gridData);
 		dialogStyleGroup.setText (ControlExample.getResourceString("Dialog_Type"));
 	}
-	
+
 	/**
 	 * Creates the "Control" widget children.
 	 */
 	@Override
 	void createControlWidgets () {
-	
+
 		/* Create the combo */
 		String [] strings = {
-			ControlExample.getResourceString("ColorDialog"), 
+			ControlExample.getResourceString("ColorDialog"),
 			ControlExample.getResourceString("DirectoryDialog"),
 			ControlExample.getResourceString("FileDialog"),
 			ControlExample.getResourceString("FontDialog"),
@@ -331,18 +346,18 @@ class DialogTab extends Tab {
 		dialogCombo.setItems (strings);
 		dialogCombo.setText (strings [0]);
 		dialogCombo.setVisibleItemCount(strings.length);
-	
+
 		/* Create the create dialog button */
 		createButton = new Button(dialogStyleGroup, SWT.NONE);
 		createButton.setText (ControlExample.getResourceString("Create_Dialog"));
 		createButton.setLayoutData (new GridData(GridData.HORIZONTAL_ALIGN_CENTER));
-	
+
 		/* Create a group for the various dialog button style controls */
 		Group buttonStyleGroup = new Group (controlGroup, SWT.NONE);
 		buttonStyleGroup.setLayout (new GridLayout ());
 		buttonStyleGroup.setLayoutData (new GridData (GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL));
 		buttonStyleGroup.setText (ControlExample.getResourceString("Button_Styles"));
-	
+
 		/* Create the button style buttons */
 		okButton = new Button (buttonStyleGroup, SWT.CHECK);
 		okButton.setText ("SWT.OK");
@@ -358,13 +373,13 @@ class DialogTab extends Tab {
 		abortButton.setText ("SWT.ABORT");
 		ignoreButton = new Button (buttonStyleGroup, SWT.CHECK);
 		ignoreButton.setText ("SWT.IGNORE");
-	
+
 		/* Create a group for the icon style controls */
 		Group iconStyleGroup = new Group (controlGroup, SWT.NONE);
 		iconStyleGroup.setLayout (new GridLayout ());
 		iconStyleGroup.setLayoutData (new GridData (GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL));
 		iconStyleGroup.setText (ControlExample.getResourceString("Icon_Styles"));
-	
+
 		/* Create the icon style buttons */
 		iconErrorButton = new Button (iconStyleGroup, SWT.RADIO);
 		iconErrorButton.setText ("SWT.ICON_ERROR");
@@ -378,13 +393,13 @@ class DialogTab extends Tab {
 		iconWorkingButton.setText ("SWT.ICON_WORKING");
 		noIconButton = new Button (iconStyleGroup, SWT.RADIO);
 		noIconButton.setText (ControlExample.getResourceString("No_Icon"));
-		
+
 		/* Create a group for the modal style controls */
 		Group modalStyleGroup = new Group (controlGroup, SWT.NONE);
 		modalStyleGroup.setLayout (new GridLayout ());
 		modalStyleGroup.setLayoutData (new GridData (GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL));
 		modalStyleGroup.setText (ControlExample.getResourceString("Modal_Styles"));
-	
+
 		/* Create the modal style buttons */
 		primaryModalButton = new Button (modalStyleGroup, SWT.RADIO);
 		primaryModalButton.setText ("SWT.PRIMARY_MODAL");
@@ -392,13 +407,13 @@ class DialogTab extends Tab {
 		applicationModalButton.setText ("SWT.APPLICATION_MODAL");
 		systemModalButton = new Button (modalStyleGroup, SWT.RADIO);
 		systemModalButton.setText ("SWT.SYSTEM_MODAL");
-	
+
 		/* Create a group for the file dialog style controls */
 		Group fileDialogStyleGroup = new Group (controlGroup, SWT.NONE);
 		fileDialogStyleGroup.setLayout (new GridLayout ());
 		fileDialogStyleGroup.setLayoutData (new GridData (GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL));
 		fileDialogStyleGroup.setText (ControlExample.getResourceString("File_Dialog_Styles"));
-	
+
 		/* Create the file dialog style buttons */
 		openButton = new Button(fileDialogStyleGroup, SWT.RADIO);
 		openButton.setText("SWT.OPEN");
@@ -406,18 +421,18 @@ class DialogTab extends Tab {
 		saveButton.setText ("SWT.SAVE");
 		multiButton = new Button(fileDialogStyleGroup, SWT.CHECK);
 		multiButton.setText("SWT.MULTI");
-	
+
 		/* Create the orientation group */
 		if (RTL_SUPPORT_ENABLE) {
 			createOrientationGroup();
 		}
-		
+
 		/* Create a group for other style and setting controls */
 		Group otherGroup = new Group (controlGroup, SWT.NONE);
 		otherGroup.setLayout (new GridLayout ());
 		otherGroup.setLayoutData (new GridData (GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL));
 		otherGroup.setText (ControlExample.getResourceString("Other"));
-	
+
 		/* Create the other style and setting controls */
 		sheetButton = new Button(otherGroup, SWT.CHECK);
 		sheetButton.setText("SWT.SHEET");
@@ -427,24 +442,9 @@ class DialogTab extends Tab {
 		effectsVisibleButton.setText("FontDialog.setEffectsVisible");
 
 		/* Add the listeners */
-		dialogCombo.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				dialogSelected (event);
-			}
-		});
-		createButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				createButtonSelected (event);
-			}
-		});
-		SelectionListener buttonStyleListener = new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				buttonStyleSelected (event);
-			}
-		};
+		dialogCombo.addSelectionListener (widgetSelectedAdapter(event -> dialogSelected (event)));
+		createButton.addSelectionListener (widgetSelectedAdapter(event -> createButtonSelected (event)));
+		SelectionListener buttonStyleListener = widgetSelectedAdapter(event -> buttonStyleSelected (event));
 		okButton.addSelectionListener (buttonStyleListener);
 		cancelButton.addSelectionListener (buttonStyleListener);
 		yesButton.addSelectionListener (buttonStyleListener);
@@ -452,7 +452,7 @@ class DialogTab extends Tab {
 		retryButton.addSelectionListener (buttonStyleListener);
 		abortButton.addSelectionListener (buttonStyleListener);
 		ignoreButton.addSelectionListener (buttonStyleListener);
-	
+
 		/* Set default values for style buttons */
 		okButton.setEnabled (false);
 		cancelButton.setEnabled (false);
@@ -475,7 +475,7 @@ class DialogTab extends Tab {
 		effectsVisibleButton.setEnabled(false);
 		effectsVisibleButton.setSelection(true);
 	}
-	
+
 	/**
 	 * Creates the "Example" group.
 	 */
@@ -483,7 +483,7 @@ class DialogTab extends Tab {
 	void createExampleGroup () {
 		super.createExampleGroup ();
 		exampleGroup.setLayoutData (new GridData (SWT.FILL, SWT.FILL, true, true));
-		
+
 		/*
 		 * Create a group for the text widget to display
 		 * the results returned by the example dialogs.
@@ -493,7 +493,7 @@ class DialogTab extends Tab {
 		resultGroup.setLayoutData (new GridData (SWT.FILL, SWT.FILL, true, true));
 		resultGroup.setText (ControlExample.getResourceString("Dialog_Result"));
 	}
-	
+
 	/**
 	 * Creates the "Example" widgets.
 	 */
@@ -504,9 +504,9 @@ class DialogTab extends Tab {
 		 */
 		textWidget = new Text(resultGroup, SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER);
 		GridData gridData = new GridData (GridData.FILL_BOTH);
-		textWidget.setLayoutData (gridData);	
+		textWidget.setLayoutData (gridData);
 	}
-	
+
 	/**
 	 * The platform dialogs do not have SWT listeners.
 	 */
@@ -520,7 +520,7 @@ class DialogTab extends Tab {
 	 * @param event the selection event
 	 */
 	void dialogSelected (SelectionEvent event) {
-	
+
 		/* Enable/Disable the buttons */
 		String name = dialogCombo.getText ();
 		boolean isMessageBox = name.equals (ControlExample.getResourceString("MessageBox"));
@@ -544,7 +544,7 @@ class DialogTab extends Tab {
 		multiButton.setEnabled (isFileDialog);
 		effectsVisibleButton.setEnabled (isFontDialog);
 		usePreviousResultButton.setEnabled (!isMessageBox);
-	
+
 		/* Deselect the buttons */
 		if (!isMessageBox) {
 			okButton.setSelection (false);
@@ -556,7 +556,7 @@ class DialogTab extends Tab {
 			ignoreButton.setSelection (false);
 		}
 	}
-	
+
 	/**
 	 * Gets the "Example" widget children.
 	 */
@@ -564,7 +564,7 @@ class DialogTab extends Tab {
 	Widget [] getExampleWidgets () {
 		return new Widget [0];
 	}
-	
+
 	/**
 	 * Gets the text for the tab folder item.
 	 */
@@ -572,7 +572,7 @@ class DialogTab extends Tab {
 	String getTabText () {
 		return "Dialog";
 	}
-	
+
 	/**
 	 * Recreates the "Example" widgets.
 	 */
@@ -580,6 +580,6 @@ class DialogTab extends Tab {
 	void recreateExampleWidgets () {
 		if (textWidget == null) {
 			super.recreateExampleWidgets ();
-		} 
+		}
 	}
 }
