@@ -7,10 +7,14 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 497575
  *******************************************************************************/
 package org.eclipse.swt.examples.controlexample;
 
 
+import static org.eclipse.swt.events.SelectionListener.widgetDefaultSelectedAdapter;
+import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
+
 import java.lang.reflect.Method;
 
 import org.eclipse.swt.SWT;
@@ -88,7 +92,7 @@ abstract class Tab {
 
 	/* Common control buttons */
 	Button borderButton, enabledButton, visibleButton, backgroundImageButton, popupMenuButton;
-	Button preferredButton, tooSmallButton, smallButton, largeButton, fillHButton, fillVButton;
+	Button preferredButton, tooSmallButton, smallButton, largeButton, rectangleButton, fillHButton, fillVButton;
 
 	/* Common groups and composites */
 	Composite tabFolderPage;
@@ -99,6 +103,8 @@ abstract class Tab {
 
 	/* Sizing constants for the "Size" group */
 	static final int TOO_SMALL_SIZE	= 10;
+	static final int RETANGLE_SIZE_WIDTH	= 140;
+	static final int RETANGLE_SIZE_HEIGHT	= 30;
 	static final int SMALL_SIZE		= 50;
 	static final int LARGE_SIZE		= 100;
 
@@ -310,24 +316,21 @@ abstract class Tab {
 		 * both these operations but typically only do work when a RADIO
 		 * button is selected.
 		 */
-		SelectionListener selectionListener = new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				if ((event.widget.getStyle () & SWT.RADIO) != 0) {
-					if (!((Button) event.widget).getSelection ()) return;
-				}
-				if (!handleTextDirection (event.widget)) {
-					recreateExampleWidgets ();
-					if (rtlSupport ()) {
-						/* Reflect the base direction falls back to the default (i.e. orientation). */
-						ltrDirectionButton.setSelection (false);
-						rtlDirectionButton.setSelection (false);
-						autoDirectionButton.setSelection (false);
-						defaultDirectionButton.setSelection (true);
-					}
+		SelectionListener selectionListener = widgetSelectedAdapter(event -> {
+			if ((event.widget.getStyle () & SWT.RADIO) != 0) {
+				if (!((Button) event.widget).getSelection ()) return;
+			}
+			if (!handleTextDirection (event.widget)) {
+				recreateExampleWidgets ();
+				if (rtlSupport ()) {
+					/* Reflect the base direction falls back to the default (i.e. orientation). */
+					ltrDirectionButton.setSelection (false);
+					rtlDirectionButton.setSelection (false);
+					autoDirectionButton.setSelection (false);
+					defaultDirectionButton.setSelection (true);
 				}
 			}
-		};
+		});
 		Control [] children = styleGroup.getChildren ();
 		for (Control child : children) {
 			if (child instanceof Button) {
@@ -370,20 +373,17 @@ abstract class Tab {
 			final Button setGetButton = new Button (otherGroup, SWT.PUSH);
 			setGetButton.setText (ControlExample.getResourceString ("Set_Get"));
 			setGetButton.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false));
-			setGetButton.addSelectionListener (new SelectionAdapter() {
-				@Override
-				public void widgetSelected (SelectionEvent e) {
-					if (getExampleWidgets().length >  0) {
-						if (setGetDialog == null) {
-							setGetDialog = createSetGetDialog(methodNames);
-						}
-						Point pt = setGetButton.getLocation();
-						pt = display.map(setGetButton.getParent(), null, pt);
-						setGetDialog.setLocation(pt.x, pt.y);
-						setGetDialog.open();
+			setGetButton.addSelectionListener (widgetSelectedAdapter(e -> {
+				if (getExampleWidgets().length >  0) {
+					if (setGetDialog == null) {
+						setGetDialog = createSetGetDialog(methodNames);
 					}
+					Point pt = setGetButton.getLocation();
+					pt = display.map(setGetButton.getParent(), null, pt);
+					setGetDialog.setLocation(pt.x, pt.y);
+					setGetDialog.open();
 				}
-			});
+			}));
 		}
 	}
 
@@ -426,24 +426,9 @@ abstract class Tab {
 		/* Add listeners to set/reset colors and fonts. */
 		colorDialog = new ColorDialog (shell);
 		fontDialog = new FontDialog (shell);
-		colorAndFontTable.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetDefaultSelected(SelectionEvent event) {
-				changeFontOrColor (colorAndFontTable.getSelectionIndex());
-			}
-		});
-		changeButton.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				changeFontOrColor (colorAndFontTable.getSelectionIndex());
-			}
-		});
-		defaultsButton.addSelectionListener(new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent e) {
-				resetColorsAndFonts ();
-			}
-		});
+		colorAndFontTable.addSelectionListener(widgetDefaultSelectedAdapter(event -> changeFontOrColor (colorAndFontTable.getSelectionIndex())));
+		changeButton.addSelectionListener(widgetSelectedAdapter(event -> changeFontOrColor (colorAndFontTable.getSelectionIndex())));
+		defaultsButton.addSelectionListener(widgetSelectedAdapter(e -> resetColorsAndFonts ()));
 		shell.addDisposeListener(event -> {
 			if (foregroundColor != null) foregroundColor.dispose();
 			if (backgroundColor != null) backgroundColor.dispose();
@@ -453,8 +438,8 @@ abstract class Tab {
 			font = null;
 			if (colorAndFontTable != null && !colorAndFontTable.isDisposed()) {
 				TableItem [] items = colorAndFontTable.getItems();
-				for (int i = 0; i < items.length; i++) {
-					Image image = items[i].getImage();
+				for (TableItem currentItem : items) {
+					Image image = currentItem.getImage();
 					if (image != null) image.dispose();
 				}
 			}
@@ -534,30 +519,10 @@ abstract class Tab {
 		popupMenuButton.setText(ControlExample.getResourceString("PopupMenu"));
 
 		/* Add the listeners */
-		enabledButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setExampleWidgetEnabled ();
-			}
-		});
-		visibleButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setExampleWidgetVisibility ();
-			}
-		});
-		backgroundImageButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setExampleWidgetBackgroundImage ();
-			}
-		});
-		popupMenuButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setExampleWidgetPopupMenu ();
-			}
-		});
+		enabledButton.addSelectionListener (widgetSelectedAdapter(event -> setExampleWidgetEnabled ()));
+		visibleButton.addSelectionListener (widgetSelectedAdapter(event -> setExampleWidgetVisibility ()));
+		backgroundImageButton.addSelectionListener (widgetSelectedAdapter(event -> setExampleWidgetBackgroundImage ()));
+		popupMenuButton.addSelectionListener (widgetSelectedAdapter(event -> setExampleWidgetPopupMenu ()));
 
 		/* Set the default state */
 		enabledButton.setSelection(true);
@@ -585,24 +550,9 @@ abstract class Tab {
 		backgroundModeColorButton.setText(ControlExample.getResourceString("BackgroundColor"));
 
 		/* Add the listeners */
-		backgroundModeCombo.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setExampleGroupBackgroundMode ();
-			}
-		});
-		backgroundModeImageButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setExampleGroupBackgroundImage ();
-			}
-		});
-		backgroundModeColorButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setExampleGroupBackgroundColor ();
-			}
-		});
+		backgroundModeCombo.addSelectionListener (widgetSelectedAdapter(event -> setExampleGroupBackgroundMode ()));
+		backgroundModeImageButton.addSelectionListener (widgetSelectedAdapter(event -> setExampleGroupBackgroundImage ()));
+		backgroundModeColorButton.addSelectionListener (widgetSelectedAdapter(event -> setExampleGroupBackgroundColor ()));
 
 		/* Set the default state */
 		backgroundModeCombo.setText(backgroundModeCombo.getItem(0));
@@ -615,7 +565,7 @@ abstract class Tab {
 		dialog.setLayout(new GridLayout());
 		dialog.setText(ControlExample.getResourceString ("Edit_Event"));
 		Label label = new Label (dialog, SWT.NONE);
-		label.setText (ControlExample.getResourceString ("Edit_Event_Fields", new String [] {EVENT_INFO[index].name}));
+		label.setText (ControlExample.getResourceString ("Edit_Event_Fields", EVENT_INFO[index].name));
 
 		Group group = new Group (dialog, SWT.NONE);
 		group.setLayout(new GridLayout(2, false));
@@ -632,19 +582,16 @@ abstract class Tab {
 			doitCombo.setItems ("", "true", "false");
 			if ((setFieldsMask & DOIT) != 0) doitCombo.setText(Boolean.toString(setFieldsEvent.doit));
 			doitCombo.setLayoutData (new GridData (SWT.FILL, SWT.CENTER, true, false));
-			doitCombo.addSelectionListener(new SelectionAdapter () {
-				@Override
-				public void widgetSelected(SelectionEvent e) {
-					String newValue = doitCombo.getText();
-					if (newValue.length() == 0) {
-						setFieldsMask &= ~DOIT;
-					} else {
-						setFieldsEvent.type = eventType;
-						setFieldsEvent.doit = newValue.equals("true");
-						setFieldsMask |= DOIT;
-					}
+			doitCombo.addSelectionListener(widgetSelectedAdapter(e -> {
+				String newValue = doitCombo.getText();
+				if (newValue.length() == 0) {
+					setFieldsMask &= ~DOIT;
+				} else {
+					setFieldsEvent.type = eventType;
+					setFieldsEvent.doit = newValue.equals("true");
+					setFieldsMask |= DOIT;
 				}
-			});
+			}));
 		}
 
 		if ((fields & DETAIL) != 0) {
@@ -656,24 +603,21 @@ abstract class Tab {
 			detailCombo.setVisibleItemCount(detailCombo.getItemCount());
 			if ((setFieldsMask & DETAIL) != 0) detailCombo.setText (DETAIL_CONSTANTS[detailType][setFieldsEvent.detail]);
 			detailCombo.setLayoutData (new GridData (SWT.FILL, SWT.CENTER, true, false));
-			detailCombo.addSelectionListener(new SelectionAdapter () {
-				@Override
-				public void widgetSelected(SelectionEvent e) {
-					String newValue = detailCombo.getText();
-					if (newValue.length() == 0) {
-						setFieldsMask &= ~DETAIL;
-					} else {
-						setFieldsEvent.type = eventType;
-						for (int i = 0; i < DETAIL_VALUES.length; i += 2) {
-							if (newValue.equals (DETAIL_VALUES [i])) {
-								setFieldsEvent.detail = ((Integer) DETAIL_VALUES [i + 1]).intValue();
-								break;
-							}
+			detailCombo.addSelectionListener(widgetSelectedAdapter(e -> {
+				String newValue = detailCombo.getText();
+				if (newValue.length() == 0) {
+					setFieldsMask &= ~DETAIL;
+				} else {
+					setFieldsEvent.type = eventType;
+					for (int i = 0; i < DETAIL_VALUES.length; i += 2) {
+						if (newValue.equals (DETAIL_VALUES [i])) {
+							setFieldsEvent.detail = ((Integer) DETAIL_VALUES [i + 1]).intValue();
+							break;
 						}
-						setFieldsMask |= DETAIL;
 					}
+					setFieldsMask |= DETAIL;
 				}
-			});
+			}));
 		}
 
 		if ((fields & TEXT) != 0) {
@@ -770,14 +714,11 @@ abstract class Tab {
 		GridData data = new GridData (70, SWT.DEFAULT);
 		data.horizontalAlignment = SWT.RIGHT;
 		ok.setLayoutData (data);
-		ok.addSelectionListener (new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				EVENT_INFO[index].setFields = setFieldsMask;
-				EVENT_INFO[index].event = setFieldsEvent;
-				dialog.dispose();
-			}
-		});
+		ok.addSelectionListener (widgetSelectedAdapter(e -> {
+			EVENT_INFO[index].setFields = setFieldsMask;
+			EVENT_INFO[index].event = setFieldsEvent;
+			dialog.dispose();
+		}));
 
 		dialog.setDefaultButton(ok);
 		dialog.pack();
@@ -851,47 +792,38 @@ abstract class Tab {
 		Button selectAll = new Button (dialog, SWT.PUSH);
 		selectAll.setText(ControlExample.getResourceString ("Select_All"));
 		selectAll.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_FILL));
-		selectAll.addSelectionListener (new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				TableItem [] items = table.getItems();
-				for (int i = 0; i < EVENT_INFO.length; i++) {
-					items[i].setChecked(true);
-				}
-				for (int i = 0; i < customNames.length; i++) {
-					items[EVENT_INFO.length + i].setChecked(true);
-				}
+		selectAll.addSelectionListener (widgetSelectedAdapter(e -> {
+			TableItem [] items = table.getItems();
+			for (int i = 0; i < EVENT_INFO.length; i++) {
+				items[i].setChecked(true);
 			}
-		});
+			for (int i = 0; i < customNames.length; i++) {
+				items[EVENT_INFO.length + i].setChecked(true);
+			}
+		}));
 		Button deselectAll = new Button (dialog, SWT.PUSH);
 		deselectAll.setText(ControlExample.getResourceString ("Deselect_All"));
 		deselectAll.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_FILL));
-		deselectAll.addSelectionListener (new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				TableItem [] items = table.getItems();
-				for (int i = 0; i < EVENT_INFO.length; i++) {
-					items[i].setChecked(false);
-				}
-				for (int i = 0; i < customNames.length; i++) {
-					items[EVENT_INFO.length + i].setChecked(false);
-				}
+		deselectAll.addSelectionListener (widgetSelectedAdapter(e -> {
+			TableItem [] items = table.getItems();
+			for (int i = 0; i < EVENT_INFO.length; i++) {
+				items[i].setChecked(false);
 			}
-		});
+			for (int i = 0; i < customNames.length; i++) {
+				items[EVENT_INFO.length + i].setChecked(false);
+			}
+		}));
 		final Button editEvent = new Button (dialog, SWT.PUSH);
 		editEvent.setText (ControlExample.getResourceString ("Edit_Event"));
 		editEvent.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_BEGINNING));
-		editEvent.addSelectionListener (new SelectionAdapter() {
-			@Override
-			public void widgetSelected (SelectionEvent e) {
-				Point pt = editEvent.getLocation();
-				pt = e.display.map(editEvent, null, pt);
-				int index = table.getSelectionIndex();
-				if (getExampleWidgets().length > 0 && index != -1) {
-					createEditEventDialog(dialog, pt.x, pt.y, index);
-				}
+		editEvent.addSelectionListener (widgetSelectedAdapter(e -> {
+			Point pt = editEvent.getLocation();
+			pt = e.display.map(editEvent, null, pt);
+			int index = table.getSelectionIndex();
+			if (getExampleWidgets().length > 0 && index != -1) {
+				createEditEventDialog(dialog, pt.x, pt.y, index);
 			}
-		});
+		}));
 		editEvent.setEnabled(false);
 		table.addSelectionListener(new SelectionAdapter() {
 			@Override
@@ -921,19 +853,16 @@ abstract class Tab {
 		ok.setText(ControlExample.getResourceString ("OK"));
 		dialog.setDefaultButton(ok);
 		ok.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_FILL));
-		ok.addSelectionListener (new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				TableItem [] items = table.getItems();
-				for (int i = 0; i < EVENT_INFO.length; i++) {
-					eventsFilter[i] = items[i].getChecked();
-				}
-				for (int i = 0; i < customNames.length; i++) {
-					eventsFilter[EVENT_INFO.length + i] = items[EVENT_INFO.length + i].getChecked();
-				}
-				dialog.dispose();
+		ok.addSelectionListener (widgetSelectedAdapter(e -> {
+			TableItem [] items = table.getItems();
+			for (int i = 0; i < EVENT_INFO.length; i++) {
+				eventsFilter[i] = items[i].getChecked();
 			}
-		});
+			for (int i = 0; i < customNames.length; i++) {
+				eventsFilter[EVENT_INFO.length + i] = items[EVENT_INFO.length + i].getChecked();
+			}
+			dialog.dispose();
+		}));
 		dialog.pack ();
 		/*
 		 * If the preferred size of the dialog is too tall for the display,
@@ -967,38 +896,27 @@ abstract class Tab {
 		 */
 		Button listenersButton = new Button (listenersGroup, SWT.PUSH);
 		listenersButton.setText (ControlExample.getResourceString ("Select_Listeners"));
-		listenersButton.addSelectionListener (new SelectionAdapter() {
-			@Override
-			public void widgetSelected (SelectionEvent e) {
-				createListenerSelectionDialog ();
-				recreateExampleWidgets ();
-			}
-		});
+		listenersButton.addSelectionListener (widgetSelectedAdapter(e -> {
+			createListenerSelectionDialog ();
+			recreateExampleWidgets ();
+		}));
 
 		/*
 		 * Create the checkbox to specify whether typed or untyped events are displayed in the log.
 		 */
 		final Button untypedEventsCheckbox = new Button (listenersGroup, SWT.CHECK);
 		untypedEventsCheckbox.setText (ControlExample.getResourceString ("UntypedEvents"));
-		untypedEventsCheckbox.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				untypedEvents = untypedEventsCheckbox.getSelection ();
-			}
-		});
+		untypedEventsCheckbox.addSelectionListener (widgetSelectedAdapter(e -> untypedEvents = untypedEventsCheckbox.getSelection ()));
 
 		/*
 		 * Create the checkbox to add/remove listeners to/from the example widgets.
 		 */
 		final Button listenCheckbox = new Button (listenersGroup, SWT.CHECK);
 		listenCheckbox.setText (ControlExample.getResourceString ("Listen"));
-		listenCheckbox.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				logging = listenCheckbox.getSelection ();
-				recreateExampleWidgets ();
-			}
-		});
+		listenCheckbox.addSelectionListener (widgetSelectedAdapter(e -> {
+			logging = listenCheckbox.getSelection ();
+			recreateExampleWidgets ();
+		}));
 
 		/*
 		 * Create the button to clear the text.
@@ -1006,12 +924,7 @@ abstract class Tab {
 		Button clearButton = new Button (listenersGroup, SWT.PUSH);
 		clearButton.setText (ControlExample.getResourceString ("Clear"));
 		clearButton.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_END));
-		clearButton.addSelectionListener (new SelectionAdapter() {
-			@Override
-			public void widgetSelected (SelectionEvent e) {
-				eventConsole.setText ("");
-			}
-		});
+		clearButton.addSelectionListener (widgetSelectedAdapter(e -> eventConsole.setText ("")));
 
 		/* Initialize the eventsFilter to log all events. */
 		int customEventCount = getCustomEventNames ().length;
@@ -1055,34 +968,21 @@ abstract class Tab {
 		nameCombo.setText(methodNames[0]);
 		nameCombo.setVisibleItemCount(methodNames.length);
 		nameCombo.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false));
-		nameCombo.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				resetLabels();
-			}
-		});
+		nameCombo.addSelectionListener(widgetSelectedAdapter(e -> resetLabels()));
 		returnTypeLabel = new Label(dialog, SWT.NONE);
 		returnTypeLabel.setLayoutData(new GridData(SWT.FILL, SWT.BEGINNING, false, false));
 		setButton = new Button(dialog, SWT.PUSH);
 		setButton.setLayoutData(new GridData(SWT.FILL, SWT.BEGINNING, false, false));
-		setButton.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				setValue();
-				setText.selectAll();
-				setText.setFocus();
-			}
-		});
+		setButton.addSelectionListener(widgetSelectedAdapter(e -> {
+			setValue();
+			setText.selectAll();
+			setText.setFocus();
+		}));
 		setText = new Text(dialog, SWT.SINGLE | SWT.BORDER);
 		setText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, false, false));
 		getButton = new Button(dialog, SWT.PUSH);
 		getButton.setLayoutData(new GridData(SWT.FILL, SWT.BEGINNING, false, false));
-		getButton.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				getValue();
-			}
-		});
+		getButton.addSelectionListener(widgetSelectedAdapter(e -> getValue()));
 		getText = new Text(dialog, SWT.MULTI | SWT.BORDER | SWT.READ_ONLY | SWT.H_SCROLL | SWT.V_SCROLL);
 		GridData data = new GridData(SWT.FILL, SWT.FILL, true, true);
 		data.widthHint = 240;
@@ -1181,12 +1081,12 @@ abstract class Tab {
 		String methodName = setMethodName(methodRoot);
 		String value = setText.getText();
 		Widget[] widgets = getExampleWidgets();
-		for (int i = 0; i < widgets.length; i++) {
+		for (Widget widget : widgets) {
 			try {
-				if (widgets[i] == null) {
+				if (widget == null) {
 					continue;
 				}
-				java.lang.reflect.Method method = widgets[i].getClass().getMethod(methodName, returnType);
+				java.lang.reflect.Method method = widget.getClass().getMethod(methodName, returnType);
 				String typeName = returnType.getName();
 				Object[] parameter = null;
 				if (value.equals("null")) {
@@ -1194,9 +1094,9 @@ abstract class Tab {
 				} else if (typeName.equals("int")) {
 					parameter = new Object[] {Integer.valueOf(value)};
 				} else if (typeName.equals("long")) {
-					parameter = new Object[] {new Long(value)};
+					parameter = new Object[] {Long.valueOf(value)};
 				} else if (typeName.equals("char")) {
-					parameter = new Object[] {value.length() == 1 ? new Character(value.charAt(0)) : new Character('\0')};
+					parameter = new Object[] {value.length() == 1 ? Character.valueOf(value.charAt(0)) : Character.valueOf('\0')};
 				} else if (typeName.equals("boolean")) {
 					parameter = new Object[] {Boolean.valueOf(value)};
 				} else if (typeName.equals("java.lang.String")) {
@@ -1224,9 +1124,9 @@ abstract class Tab {
 				} else if (typeName.equals("[Ljava.lang.String;")) {
 					parameter = new Object[] {split(value, ',')};
 				} else {
-					parameter = parameterForType(typeName, value, widgets[i]);
+					parameter = parameterForType(typeName, value, widget);
 				}
-				method.invoke(widgets[i], parameter);
+				method.invoke(widget, parameter);
 			} catch (Exception e) {
 				Throwable cause = e.getCause();
 				String message = e.getMessage();
@@ -1301,22 +1201,20 @@ abstract class Tab {
 		smallButton.setText (SMALL_SIZE + " X " + SMALL_SIZE);
 		largeButton = new Button (sizeGroup, SWT.RADIO);
 		largeButton.setText (LARGE_SIZE + " X " + LARGE_SIZE);
+		rectangleButton = new Button (sizeGroup, SWT.RADIO);
+		rectangleButton.setText (RETANGLE_SIZE_WIDTH + " X " + RETANGLE_SIZE_HEIGHT);
 		fillHButton = new Button (sizeGroup, SWT.CHECK);
 		fillHButton.setText (ControlExample.getResourceString("Fill_X"));
 		fillVButton = new Button (sizeGroup, SWT.CHECK);
 		fillVButton.setText (ControlExample.getResourceString("Fill_Y"));
 
 		/* Add the listeners */
-		SelectionAdapter selectionListener = new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setExampleWidgetSize ();
-			}
-		};
+		SelectionListener selectionListener = widgetSelectedAdapter(event -> setExampleWidgetSize ());
 		preferredButton.addSelectionListener(selectionListener);
 		tooSmallButton.addSelectionListener(selectionListener);
 		smallButton.addSelectionListener(selectionListener);
 		largeButton.addSelectionListener(selectionListener);
+		rectangleButton.addSelectionListener(selectionListener);
 		fillHButton.addSelectionListener(selectionListener);
 		fillVButton.addSelectionListener(selectionListener);
 
@@ -1861,6 +1759,9 @@ abstract class Tab {
 		Control [] controls = getExampleControls ();
 		for (Control control : controls) {
 			GridData gridData = new GridData(size, size);
+			if (rectangleButton.getSelection()) {
+				gridData = new GridData(RETANGLE_SIZE_WIDTH, RETANGLE_SIZE_HEIGHT);
+			}
 			gridData.grabExcessHorizontalSpace = fillHButton.getSelection();
 			gridData.grabExcessVerticalSpace = fillVButton.getSelection();
 			gridData.horizontalAlignment = fillHButton.getSelection() ? SWT.FILL : SWT.LEFT;
