@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,9 +11,9 @@
 package org.eclipse.swt.examples.controlexample;
 
 
+import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
+
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Font;
@@ -55,7 +55,9 @@ class TableTab extends ScrollableTab {
 	static final int CELL_FOREGROUND_COLOR = 6;
 	static final int CELL_BACKGROUND_COLOR = 7;
 	static final int CELL_FONT = 8;
-	Color itemForegroundColor, itemBackgroundColor, cellForegroundColor, cellBackgroundColor;
+	static final int HEADER_FOREGROUND_COLOR = 9;
+	static final int HEADER_BACKGROUND_COLOR = 10;
+	Color itemForegroundColor, itemBackgroundColor, cellForegroundColor, cellBackgroundColor, headerForegroundColor, headerBackgroundColor;
 	Font itemFont, cellFont;
 
 	static String [] columnTitles	= {ControlExample.getResourceString("TableTitle_0"),
@@ -105,6 +107,10 @@ class TableTab extends ScrollableTab {
 		item.setText(ControlExample.getResourceString ("Cell_Background_Color"));
 		item = new TableItem(colorAndFontTable, SWT.None);
 		item.setText(ControlExample.getResourceString ("Cell_Font"));
+		item = new TableItem(colorAndFontTable, SWT.None);
+		item.setText(ControlExample.getResourceString ("Header_Foreground_Color"));
+		item = new TableItem(colorAndFontTable, SWT.None);
+		item.setText(ControlExample.getResourceString ("Header_Background_Color"));
 
 		shell.addDisposeListener(event -> {
 			if (itemBackgroundColor != null) itemBackgroundColor.dispose();
@@ -113,12 +119,16 @@ class TableTab extends ScrollableTab {
 			if (cellBackgroundColor != null) cellBackgroundColor.dispose();
 			if (cellForegroundColor != null) cellForegroundColor.dispose();
 			if (cellFont != null) cellFont.dispose();
+			if (headerBackgroundColor != null) headerBackgroundColor.dispose();
+			if (headerForegroundColor != null) headerForegroundColor.dispose();
 			itemBackgroundColor = null;
 			itemForegroundColor = null;
 			itemFont = null;
 			cellBackgroundColor = null;
 			cellForegroundColor = null;
 			cellFont = null;
+			headerForegroundColor = null;
+			headerBackgroundColor = null;
 		});
 	}
 
@@ -199,6 +209,30 @@ class TableTab extends ScrollableTab {
 			if (oldFont != null) oldFont.dispose ();
 		}
 		break;
+		case HEADER_FOREGROUND_COLOR: {
+			Color oldColor = headerForegroundColor;
+			if (oldColor == null) oldColor = table1.getHeaderForeground();
+			colorDialog.setRGB(oldColor.getRGB());
+			RGB rgb = colorDialog.open();
+			if (rgb == null) return;
+			oldColor = headerForegroundColor;
+			headerForegroundColor = new Color (display, rgb);
+			setHeaderForeground ();
+			if (oldColor != null) oldColor.dispose ();
+		}
+		break;
+		case HEADER_BACKGROUND_COLOR: {
+			Color oldColor = headerBackgroundColor;
+			if (oldColor == null) oldColor = table1.getHeaderBackground();
+			colorDialog.setRGB(oldColor.getRGB());
+			RGB rgb = colorDialog.open();
+			if (rgb == null) return;
+			oldColor = headerBackgroundColor;
+			headerBackgroundColor = new Color (display, rgb);
+			setHeaderBackground ();
+			if (oldColor != null) oldColor.dispose ();
+		}
+		break;
 		default:
 			super.changeFontOrColor(index);
 	}
@@ -231,54 +265,14 @@ class TableTab extends ScrollableTab {
 		subImagesButton.setText (ControlExample.getResourceString("Sub_Images"));
 
 		/* Add the listeners */
-		linesVisibleButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setWidgetLinesVisible ();
-			}
-		});
-		multipleColumns.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				recreateExampleWidgets ();
-			}
-		});
-		headerVisibleButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setWidgetHeaderVisible ();
-			}
-		});
-		sortIndicatorButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setWidgetSortIndicator ();
-			}
-		});
-		moveableColumns.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setColumnsMoveable ();
-			}
-		});
-		resizableColumns.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setColumnsResizable ();
-			}
-		});
-		headerImagesButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				recreateExampleWidgets ();
-			}
-		});
-		subImagesButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				recreateExampleWidgets ();
-			}
-		});
+		linesVisibleButton.addSelectionListener (widgetSelectedAdapter(event -> setWidgetLinesVisible ()));
+		multipleColumns.addSelectionListener (widgetSelectedAdapter(event -> recreateExampleWidgets ()));
+		headerVisibleButton.addSelectionListener (widgetSelectedAdapter(event -> setWidgetHeaderVisible ()));
+		sortIndicatorButton.addSelectionListener (widgetSelectedAdapter(event -> setWidgetSortIndicator ()));
+		moveableColumns.addSelectionListener (widgetSelectedAdapter(event -> setColumnsMoveable ()));
+		resizableColumns.addSelectionListener (widgetSelectedAdapter(event -> setColumnsResizable ()));
+		headerImagesButton.addSelectionListener (widgetSelectedAdapter(event -> recreateExampleWidgets ()));
+		subImagesButton.addSelectionListener (widgetSelectedAdapter(event -> recreateExampleWidgets ()));
 	}
 
 	/**
@@ -321,7 +315,7 @@ class TableTab extends ScrollableTab {
 			for (int i = 0; i < columnTitles.length; i++) {
 				TableColumn tableColumn = new TableColumn(table1, SWT.NONE);
 				tableColumn.setText(columnTitles[i]);
-				tableColumn.setToolTipText(ControlExample.getResourceString("Tooltip", new String [] {columnTitles[i]}));
+				tableColumn.setToolTipText(ControlExample.getResourceString("Tooltip", columnTitles[i]));
 				if (headerImagesButton.getSelection()) tableColumn.setImage(instance.images [i % 3]);
 			}
 			table1.setSortColumn(table1.getColumn(0));
@@ -361,13 +355,10 @@ class TableTab extends ScrollableTab {
 
 		packColumnsButton = new Button (sizeGroup, SWT.PUSH);
 		packColumnsButton.setText (ControlExample.getResourceString("Pack_Columns"));
-		packColumnsButton.addSelectionListener(new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				packColumns ();
-				setExampleWidgetSize ();
-			}
-		});
+		packColumnsButton.addSelectionListener(widgetSelectedAdapter(event -> {
+			packColumns ();
+			setExampleWidgetSize ();
+		}));
 	}
 
 	/**
@@ -501,6 +492,14 @@ class TableTab extends ScrollableTab {
 		cellFont = null;
 		setCellFont ();
 		if (oldFont != null) oldFont.dispose();
+		oldColor = headerBackgroundColor;
+		headerBackgroundColor = null;
+		setHeaderBackground ();
+		if (oldColor != null) oldColor.dispose();
+		oldColor = headerForegroundColor;
+		headerForegroundColor = null;
+		setHeaderForeground ();
+		if (oldColor != null) oldColor.dispose();
 	}
 
 	/**
@@ -603,6 +602,32 @@ class TableTab extends ScrollableTab {
 		colorAndFontTable.layout ();
 	}
 
+	void setHeaderBackground () {
+		if (!instance.startup) {
+			table1.setHeaderBackground (headerBackgroundColor);
+		}
+		/* Set the header background color item's image to match the header background color. */
+		Color color = headerBackgroundColor;
+		if (color == null) color = table1.getHeaderBackground();
+		TableItem item = colorAndFontTable.getItem(HEADER_BACKGROUND_COLOR);
+		Image oldImage = item.getImage();
+		if (oldImage != null) oldImage.dispose();
+		item.setImage (colorImage(color));
+	}
+
+	void setHeaderForeground () {
+		if (!instance.startup) {
+			table1.setHeaderForeground (headerForegroundColor);
+		}
+		/* Set the header foreground color item's image to match the header foreground color. */
+		Color color = headerForegroundColor;
+		if (color == null) color = table1.getHeaderForeground();
+		TableItem item = colorAndFontTable.getItem(HEADER_FOREGROUND_COLOR);
+		Image oldImage = item.getImage();
+		if (oldImage != null) oldImage.dispose();
+		item.setImage (colorImage(color));
+	}
+
 	/**
 	 * Sets the moveable columns state of the "Example" widgets.
 	 */
@@ -636,6 +661,8 @@ class TableTab extends ScrollableTab {
 		setCellBackground ();
 		setCellForeground ();
 		setCellFont ();
+		setHeaderBackground ();
+		setHeaderForeground ();
 		if (!instance.startup) {
 			setColumnsMoveable ();
 			setColumnsResizable ();
@@ -675,22 +702,19 @@ class TableTab extends ScrollableTab {
 			for (int i = 0; i < columns.length; i++) {
 				TableColumn column = columns[i];
 				if (i == 0) table1.setSortColumn(column);
-				SelectionListener listener = new SelectionAdapter() {
-					@Override
-					public void widgetSelected(SelectionEvent e) {
-						int sortDirection = SWT.DOWN;
-						if (e.widget == table1.getSortColumn()) {
-							/* If the sort column hasn't changed, cycle down -> up -> none. */
-							switch (table1.getSortDirection ()) {
-							case SWT.DOWN: sortDirection = SWT.UP; break;
-							case SWT.UP: sortDirection = SWT.NONE; break;
-							}
-						} else {
-							table1.setSortColumn((TableColumn)e.widget);
+				SelectionListener listener = widgetSelectedAdapter(e -> {
+					int sortDirection = SWT.DOWN;
+					if (e.widget == table1.getSortColumn()) {
+						/* If the sort column hasn't changed, cycle down -> up -> none. */
+						switch (table1.getSortDirection ()) {
+						case SWT.DOWN: sortDirection = SWT.UP; break;
+						case SWT.UP: sortDirection = SWT.NONE; break;
 						}
-						table1.setSortDirection (sortDirection);
+					} else {
+						table1.setSortColumn((TableColumn)e.widget);
 					}
-				};
+					table1.setSortDirection (sortDirection);
+				});
 				column.addSelectionListener(listener);
 				column.setData("SortListener", listener);	//$NON-NLS-1$
 			}
@@ -715,12 +739,9 @@ class TableTab extends ScrollableTab {
     	MenuItem item = new MenuItem(menu, SWT.PUSH);
     	item.setText("getItem(Point) on mouse coordinates");
     	menuMouseCoords = table1.toControl(new Point(event.x, event.y));
-    	item.addSelectionListener(new SelectionAdapter() {
-    		@Override
-			public void widgetSelected(SelectionEvent e) {
-    			eventConsole.append ("getItem(Point(" + menuMouseCoords + ")) returned: " + table1.getItem(menuMouseCoords));
-    			eventConsole.append ("\n");
-    		}
-    	});
+    	item.addSelectionListener(widgetSelectedAdapter(e -> {
+			eventConsole.append ("getItem(Point(" + menuMouseCoords + ")) returned: " + table1.getItem(menuMouseCoords));
+			eventConsole.append ("\n");
+		}));
 	}
 }
