@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,9 +11,9 @@
 package org.eclipse.swt.examples.controlexample;
 
 
+import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
+
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Font;
@@ -57,7 +57,9 @@ class TreeTab extends ScrollableTab {
 	static final int CELL_FOREGROUND_COLOR = 6;
 	static final int CELL_BACKGROUND_COLOR = 7;
 	static final int CELL_FONT = 8;
-	Color itemForegroundColor, itemBackgroundColor, cellForegroundColor, cellBackgroundColor;
+	static final int HEADER_FOREGROUND_COLOR = 9;
+	static final int HEADER_BACKGROUND_COLOR = 10;
+	Color itemForegroundColor, itemBackgroundColor, cellForegroundColor, cellBackgroundColor, headerForegroundColor, headerBackgroundColor;
 	Font itemFont, cellFont;
 
 	static String [] columnTitles	= {ControlExample.getResourceString("TableTitle_0"),
@@ -107,6 +109,10 @@ class TreeTab extends ScrollableTab {
 		item.setText(ControlExample.getResourceString ("Cell_Background_Color"));
 		item = new TableItem(colorAndFontTable, SWT.None);
 		item.setText(ControlExample.getResourceString ("Cell_Font"));
+		item = new TableItem(colorAndFontTable, SWT.None);
+		item.setText(ControlExample.getResourceString ("Header_Foreground_Color"));
+		item = new TableItem(colorAndFontTable, SWT.None);
+		item.setText(ControlExample.getResourceString ("Header_Background_Color"));
 
 		shell.addDisposeListener(event -> {
 			if (itemBackgroundColor != null) itemBackgroundColor.dispose();
@@ -115,12 +121,16 @@ class TreeTab extends ScrollableTab {
 			if (cellBackgroundColor != null) cellBackgroundColor.dispose();
 			if (cellForegroundColor != null) cellForegroundColor.dispose();
 			if (cellFont != null) cellFont.dispose();
+			if (headerBackgroundColor != null) headerBackgroundColor.dispose();
+			if (headerForegroundColor != null) headerForegroundColor.dispose();
 			itemBackgroundColor = null;
 			itemForegroundColor = null;
 			itemFont = null;
 			cellBackgroundColor = null;
 			cellForegroundColor = null;
 			cellFont = null;
+			headerForegroundColor = null;
+			headerBackgroundColor = null;
 		});
 	}
 
@@ -201,6 +211,29 @@ class TreeTab extends ScrollableTab {
 			if (oldFont != null) oldFont.dispose ();
 		}
 		break;
+		case HEADER_FOREGROUND_COLOR: {
+			Color oldColor = headerForegroundColor;
+			if (oldColor == null) oldColor = tree1.getHeaderForeground();
+			colorDialog.setRGB(oldColor.getRGB());
+			RGB rgb = colorDialog.open();
+			if (rgb == null) return;
+			oldColor = headerForegroundColor;
+			headerForegroundColor = new Color (display, rgb);
+			setHeaderForeground ();
+			if (oldColor != null) oldColor.dispose ();
+		}
+		break;
+		case HEADER_BACKGROUND_COLOR: {
+			Color oldColor = headerBackgroundColor;
+			if (oldColor == null) oldColor = tree1.getHeaderBackground();
+			colorDialog.setRGB(oldColor.getRGB());
+			RGB rgb = colorDialog.open();
+			if (rgb == null) return;
+			oldColor = headerBackgroundColor;
+			headerBackgroundColor = new Color (display, rgb);
+			setHeaderBackground ();
+			if (oldColor != null) oldColor.dispose ();
+		}
 		default:
 			super.changeFontOrColor(index);
 		}
@@ -232,54 +265,14 @@ class TreeTab extends ScrollableTab {
 		subImagesButton.setText (ControlExample.getResourceString("Sub_Images"));
 
 		/* Add the listeners */
-		linesVisibleButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setWidgetLinesVisible ();
-			}
-		});
-		multipleColumns.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				recreateExampleWidgets ();
-			}
-		});
-		headerVisibleButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setWidgetHeaderVisible ();
-			}
-		});
-		sortIndicatorButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setWidgetSortIndicator ();
-			}
-		});
-		moveableColumns.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setColumnsMoveable ();
-			}
-		});
-		resizableColumns.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				setColumnsResizable ();
-			}
-		});
-		headerImagesButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				recreateExampleWidgets ();
-			}
-		});
-		subImagesButton.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				recreateExampleWidgets ();
-			}
-		});
+		linesVisibleButton.addSelectionListener (widgetSelectedAdapter(event -> setWidgetLinesVisible ()));
+		multipleColumns.addSelectionListener (widgetSelectedAdapter(event -> recreateExampleWidgets ()));
+		headerVisibleButton.addSelectionListener (widgetSelectedAdapter(event -> setWidgetHeaderVisible ()));
+		sortIndicatorButton.addSelectionListener (widgetSelectedAdapter(event -> setWidgetSortIndicator ()));
+		moveableColumns.addSelectionListener (widgetSelectedAdapter(event -> setColumnsMoveable ()));
+		resizableColumns.addSelectionListener (widgetSelectedAdapter(event -> setColumnsResizable ()));
+		headerImagesButton.addSelectionListener (widgetSelectedAdapter(event -> recreateExampleWidgets ()));
+		subImagesButton.addSelectionListener (widgetSelectedAdapter(event -> recreateExampleWidgets ()));
 	}
 
 	/**
@@ -325,7 +318,7 @@ class TreeTab extends ScrollableTab {
 			for (String columnTitle : columnTitles) {
 				TreeColumn treeColumn = new TreeColumn(tree1, SWT.NONE);
 				treeColumn.setText(columnTitle);
-				treeColumn.setToolTipText(ControlExample.getResourceString("Tooltip", new String [] {columnTitle}));
+				treeColumn.setToolTipText(ControlExample.getResourceString("Tooltip", columnTitle));
 			}
 			tree1.setSortColumn(tree1.getColumn(0));
 		}
@@ -356,7 +349,7 @@ class TreeTab extends ScrollableTab {
 			for (int i = 0; i < columnTitles.length; i++) {
 				TreeColumn treeColumn = new TreeColumn(tree2, SWT.NONE);
 				treeColumn.setText(columnTitles[i]);
-				treeColumn.setToolTipText(ControlExample.getResourceString("Tooltip", new String [] {columnTitles[i]}));
+				treeColumn.setToolTipText(ControlExample.getResourceString("Tooltip", columnTitles[i]));
 				if (headerImagesButton.getSelection()) treeColumn.setImage(instance.images [i % 3]);
 			}
 		}
@@ -426,14 +419,11 @@ class TreeTab extends ScrollableTab {
 
 		packColumnsButton = new Button (sizeGroup, SWT.PUSH);
 		packColumnsButton.setText (ControlExample.getResourceString("Pack_Columns"));
-		packColumnsButton.addSelectionListener(new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				packColumns (tree1);
-				packColumns (tree2);
-				setExampleWidgetSize ();
-			}
-		});
+		packColumnsButton.addSelectionListener(widgetSelectedAdapter(event -> {
+			packColumns (tree1);
+			packColumns (tree2);
+			setExampleWidgetSize ();
+		}));
 	}
 
 	/**
@@ -535,6 +525,36 @@ class TreeTab extends ScrollableTab {
 		}
 	}
 
+	void setHeaderBackground () {
+		if (!instance.startup) {
+			tree1.setHeaderBackground (headerBackgroundColor);
+			tree2.setHeaderBackground (headerBackgroundColor);
+		}
+		/* Set the header background color item's image to match the header background color. */
+		Color color = headerBackgroundColor;
+ 		if (color == null) color = tree1.getHeaderBackground();
+		TableItem item = colorAndFontTable.getItem(HEADER_BACKGROUND_COLOR);
+		Image oldImage1 = item.getImage();
+		if (oldImage1 != null) oldImage1.dispose();
+		item.setImage (colorImage(color));
+
+	}
+
+	void setHeaderForeground () {
+		if (!instance.startup) {
+			tree1.setHeaderForeground (headerForegroundColor);
+			tree2.setHeaderForeground (headerForegroundColor);
+		}
+		/* Set the header foreground color item's image to match the header foreground color. */
+		Color color = headerForegroundColor;
+		if (color == null) color = tree1.getHeaderForeground();
+		TableItem item =  colorAndFontTable.getItem(HEADER_FOREGROUND_COLOR);
+		Image oldImage1 = item.getImage();
+		if (oldImage1 != null) oldImage1.dispose();
+		item.setImage (colorImage(color));
+
+	}
+
 	/**
 	 * Sets the moveable columns state of the "Example" widgets.
 	 */
@@ -598,6 +618,15 @@ class TreeTab extends ScrollableTab {
 		cellFont = null;
 		setCellFont ();
 		if (oldFont != null) oldFont.dispose();
+		oldColor = headerBackgroundColor;
+		headerBackgroundColor = null;
+		setHeaderBackground ();
+		if (oldColor != null) oldColor.dispose();
+		oldColor = headerForegroundColor;
+		headerForegroundColor = null;
+		setHeaderForeground ();
+		if (oldColor != null) oldColor.dispose();
+
 	}
 
 	/**
@@ -611,6 +640,8 @@ class TreeTab extends ScrollableTab {
 		setCellBackground ();
 		setCellForeground ();
 		setCellFont ();
+		setHeaderBackground ();
+		setHeaderForeground ();
 		if (!instance.startup) {
 			setColumnsMoveable ();
 			setColumnsResizable ();
@@ -769,22 +800,19 @@ class TreeTab extends ScrollableTab {
 		for (int i = 0; i < columns.length; i++) {
 			TreeColumn column = columns[i];
 			if (i == 0) tree.setSortColumn(column);
-			SelectionListener listener = new SelectionAdapter() {
-				@Override
-				public void widgetSelected(SelectionEvent e) {
-					int sortDirection = SWT.DOWN;
-					if (e.widget == tree.getSortColumn()) {
-						/* If the sort column hasn't changed, cycle down -> up -> none. */
-						switch (tree.getSortDirection ()) {
-						case SWT.DOWN: sortDirection = SWT.UP; break;
-						case SWT.UP: sortDirection = SWT.NONE; break;
-						}
-					} else {
-						tree.setSortColumn((TreeColumn)e.widget);
+			SelectionListener listener = widgetSelectedAdapter(e -> {
+				int sortDirection = SWT.DOWN;
+				if (e.widget == tree.getSortColumn()) {
+					/* If the sort column hasn't changed, cycle down -> up -> none. */
+					switch (tree.getSortDirection ()) {
+					case SWT.DOWN: sortDirection = SWT.UP; break;
+					case SWT.UP: sortDirection = SWT.NONE; break;
 					}
-					tree.setSortDirection (sortDirection);
+				} else {
+					tree.setSortColumn((TreeColumn)e.widget);
 				}
-			};
+				tree.setSortDirection (sortDirection);
+			});
 			column.addSelectionListener(listener);
 			column.setData("SortListener", listener);	//$NON-NLS-1$
 		}
@@ -813,12 +841,9 @@ class TreeTab extends ScrollableTab {
     	item.setText("getItem(Point) on mouse coordinates");
     	final Tree t = (Tree) event.widget;
     	menuMouseCoords = t.toControl(new Point(event.x, event.y));
-    	item.addSelectionListener(new SelectionAdapter() {
-    		@Override
-			public void widgetSelected(SelectionEvent e) {
-    			eventConsole.append ("getItem(Point(" + menuMouseCoords + ")) returned: " + t.getItem(menuMouseCoords));
-    			eventConsole.append ("\n");
-    		}
-    	});
+    	item.addSelectionListener(widgetSelectedAdapter(e -> {
+			eventConsole.append ("getItem(Point(" + menuMouseCoords + ")) returned: " + t.getItem(menuMouseCoords));
+			eventConsole.append ("\n");
+		}));
 	}
 }
