@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,6 +11,8 @@
 package org.eclipse.swt.examples.fileviewer;
 
 
+import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
+
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.FileReader;
@@ -34,12 +36,10 @@ import org.eclipse.swt.dnd.DropTarget;
 import org.eclipse.swt.dnd.DropTargetAdapter;
 import org.eclipse.swt.dnd.DropTargetEvent;
 import org.eclipse.swt.dnd.FileTransfer;
-import org.eclipse.swt.dnd.Transfer;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
-import org.eclipse.swt.events.ShellAdapter;
-import org.eclipse.swt.events.ShellEvent;
+import org.eclipse.swt.events.ShellListener;
 import org.eclipse.swt.events.TreeAdapter;
 import org.eclipse.swt.events.TreeEvent;
 import org.eclipse.swt.graphics.Image;
@@ -69,23 +69,23 @@ import org.eclipse.swt.widgets.TreeItem;
 /**
  * File Viewer example
  */
-public class FileViewer { 
+public class FileViewer {
  	private static ResourceBundle resourceBundle = ResourceBundle.getBundle("examples_fileviewer");
 
 	private final static String DRIVE_A = "a:" + File.separator;
 	private final static String DRIVE_B = "b:" + File.separator;
 
-	/* UI elements */ 	
-	private Display display; 
+	/* UI elements */
+	private Display display;
 	private Shell shell;
 	private ToolBar toolBar;
 
 	private Label numObjectsLabel;
 	private Label diskSpaceLabel;
-	
+
 	private File currentDirectory = null;
 	private boolean initial = true;
-	
+
 	/* Drag and drop optimizations */
 	private boolean isDragging = false; // if this app is dragging
 	private boolean isDropping = false; // if this app is dropping
@@ -172,7 +172,7 @@ public class FileViewer {
 	/**
 	 * Opens the main program.
 	 */
-	public Shell open(Display display) {		
+	public Shell open(Display display) {
 		// Create the window
 		this.display = display;
 		iconCache.initResources(display);
@@ -190,7 +190,7 @@ public class FileViewer {
 		workerStop();
 		iconCache.freeResources();
 	}
-	
+
 	/**
 	 * Returns a string from the resource bundle.
 	 * We don't want to crash because of a missing String.
@@ -203,7 +203,7 @@ public class FileViewer {
 			return key;
 		} catch (NullPointerException e) {
 			return "!" + key + "!";
-		}			
+		}
 	}
 
 	/**
@@ -223,11 +223,11 @@ public class FileViewer {
 
 	/**
 	 * Construct the UI
-	 * 
+	 *
 	 * @param container the ShellContainer managing the Shell we are rendering inside
 	 */
 	private void createShellContents() {
-		shell.setText(getResourceString("Title", new Object[] { "" }));	
+		shell.setText(getResourceString("Title", new Object[] { "" }));
 		shell.setImage(iconCache.stockImages[iconCache.shellIcon]);
 		Menu bar = new Menu(shell, SWT.BAR);
 		shell.setMenuBar(bar);
@@ -259,16 +259,16 @@ public class FileViewer {
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_FILL);
 		gridData.widthHint = 185;
 		numObjectsLabel.setLayoutData(gridData);
-		
+
 		diskSpaceLabel = new Label(shell, SWT.BORDER);
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_FILL);
 		gridData.horizontalSpan = 2;
 		diskSpaceLabel.setLayoutData(gridData);
 	}
-	
+
 	/**
 	 * Creates the File Menu.
-	 * 
+	 *
 	 * @param parent the parent menu
 	 */
 	private void createFileMenu(Menu parent) {
@@ -280,26 +280,16 @@ public class FileViewer {
 		final MenuItem simulateItem = new MenuItem(menu, SWT.CHECK);
 		simulateItem.setText(getResourceString("menu.File.SimulateOnly.text"));
 		simulateItem.setSelection(simulateOnly);
-		simulateItem.addSelectionListener(new SelectionAdapter () {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				simulateOnly = simulateItem.getSelection();
-			}
-		});
+		simulateItem.addSelectionListener(widgetSelectedAdapter(e -> simulateOnly = simulateItem.getSelection()));
 
 		MenuItem item = new MenuItem(menu, SWT.PUSH);
 		item.setText(getResourceString("menu.File.Close.text"));
-		item.addSelectionListener(new SelectionAdapter () {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				shell.close();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(e -> shell.close()));
 	}
-	
+
 	/**
 	 * Creates the Help Menu.
-	 * 
+	 *
 	 * @param parent the parent menu
 	 */
 	private void createHelpMenu(Menu parent) {
@@ -309,22 +299,19 @@ public class FileViewer {
 		header.setMenu(menu);
 
 		MenuItem item = new MenuItem(menu, SWT.PUSH);
-		item.setText(getResourceString("menu.Help.About.text"));		
-		item.addSelectionListener(new SelectionAdapter () {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				MessageBox box = new MessageBox(shell, SWT.ICON_INFORMATION | SWT.OK);
-				box.setText(getResourceString("dialog.About.title"));
-				box.setMessage(getResourceString("dialog.About.description",
-					new Object[] { System.getProperty("os.name") }));
-				box.open();
-			}
-		});
+		item.setText(getResourceString("menu.Help.About.text"));
+		item.addSelectionListener(widgetSelectedAdapter(e -> {
+			MessageBox box = new MessageBox(shell, SWT.ICON_INFORMATION | SWT.OK);
+			box.setText(getResourceString("dialog.About.title"));
+			box.setMessage(getResourceString("dialog.About.description",
+				new Object[] { System.getProperty("os.name") }));
+			box.open();
+		}));
 	}
 
 	/**
 	 * Creates the toolbar
-	 * 
+	 *
 	 * @param shell the shell on which to attach the toolbar
 	 * @param layoutData the layout data
 	 */
@@ -335,30 +322,17 @@ public class FileViewer {
 		item = new ToolItem(toolBar, SWT.PUSH);
 		item.setImage(iconCache.stockImages[iconCache.cmdParent]);
 		item.setToolTipText(getResourceString("tool.Parent.tiptext"));
-		item.addSelectionListener(new SelectionAdapter () {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				doParent();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(e -> doParent()));
 		item = new ToolItem(toolBar, SWT.PUSH);
 		item.setImage(iconCache.stockImages[iconCache.cmdRefresh]);
 		item.setToolTipText(getResourceString("tool.Refresh.tiptext"));
-		item.addSelectionListener(new SelectionAdapter () {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				doRefresh();
-			}
+		item.addSelectionListener(widgetSelectedAdapter(e -> doRefresh()));
+		SelectionListener unimplementedListener = widgetSelectedAdapter(e -> {
+			MessageBox box = new MessageBox(shell, SWT.ICON_INFORMATION | SWT.OK);
+			box.setText(getResourceString("dialog.NotImplemented.title"));
+			box.setMessage(getResourceString("dialog.ActionNotImplemented.description"));
+			box.open();
 		});
-		SelectionAdapter unimplementedListener = new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				MessageBox box = new MessageBox(shell, SWT.ICON_INFORMATION | SWT.OK);
-				box.setText(getResourceString("dialog.NotImplemented.title"));
-				box.setMessage(getResourceString("dialog.ActionNotImplemented.description"));
-				box.open();
-			}
-		};
 
 		item = new ToolItem(toolBar, SWT.SEPARATOR);
 		item = new ToolItem(toolBar, SWT.PUSH);
@@ -397,7 +371,7 @@ public class FileViewer {
 
 	/**
 	 * Creates the combo box view.
-	 * 
+	 *
 	 * @param parent the parent control
 	 */
 	private void createComboView(Composite parent, Object layoutData) {
@@ -427,7 +401,7 @@ public class FileViewer {
 
 	/**
 	 * Creates the file tree view.
-	 * 
+	 *
 	 * @param parent the parent control
 	 */
 	private void createTreeView(Composite parent) {
@@ -452,7 +426,7 @@ public class FileViewer {
 				if (selection != null && selection.length != 0) {
 					TreeItem item = selection[0];
 					File file = (File) item.getData(TREEITEMDATA_FILE);
-				
+
 					notifySelectedDirectory(file);
 				}
 			}
@@ -487,12 +461,12 @@ public class FileViewer {
 
 	/**
 	 * Creates the Drag & Drop DragSource for items being dragged from the tree.
-	 * 
+	 *
 	 * @return the DragSource for the tree
 	 */
 	private DragSource createTreeDragSource(final Tree tree){
 		DragSource dragSource = new DragSource(tree, DND.DROP_MOVE | DND.DROP_COPY);
-		dragSource.setTransfer(new Transfer[] { FileTransfer.getInstance() });
+		dragSource.setTransfer(FileTransfer.getInstance());
 		dragSource.addDragListener(new DragSourceListener() {
 			TreeItem[] dndSelection = null;
 			String[] sourceNames = null;
@@ -517,7 +491,7 @@ public class FileViewer {
 			public void dragSetData(DragSourceEvent event){
 				if (dndSelection == null || dndSelection.length == 0) return;
 				if (! FileTransfer.getInstance().isSupportedType(event.dataType)) return;
-				
+
 				sourceNames  = new String[dndSelection.length];
 				for (int i = 0; i < dndSelection.length; i++) {
 					File file = (File) dndSelection[i].getData(TREEITEMDATA_FILE);
@@ -531,12 +505,12 @@ public class FileViewer {
 
 	/**
 	 * Creates the Drag & Drop DropTarget for items being dropped onto the tree.
-	 * 
+	 *
 	 * @return the DropTarget for the tree
 	 */
 	private DropTarget createTreeDropTarget(final Tree tree) {
 		DropTarget dropTarget = new DropTarget(tree, DND.DROP_MOVE | DND.DROP_COPY);
-		dropTarget.setTransfer(new Transfer[] { FileTransfer.getInstance() });
+		dropTarget.setTransfer(FileTransfer.getInstance());
 		dropTarget.addDropListener(new DropTargetAdapter() {
 			@Override
 			public void dragEnter(DropTargetEvent event) {
@@ -559,7 +533,7 @@ public class FileViewer {
 					dropTargetHandleDrop(event, targetFile);
 			}
 			private File getTargetFile(DropTargetEvent event) {
-				// Determine the target File for the drop 
+				// Determine the target File for the drop
 				TreeItem item = tree.getItem(tree.toControl(new Point(event.x, event.y)));
 				File targetFile = null;
 				if (item != null) {
@@ -569,12 +543,12 @@ public class FileViewer {
 				return targetFile;
 			}
 		});
-		return dropTarget;	
+		return dropTarget;
 	}
 
 	/**
 	 * Handles expand events on a tree item.
-	 * 
+	 *
 	 * @param item the TreeItem to fill in
 	 */
 	private void treeExpandItem(TreeItem item) {
@@ -583,10 +557,10 @@ public class FileViewer {
 		if (stub == null) treeRefreshItem(item, true);
 		shell.setCursor(iconCache.stockCursors[iconCache.cursorDefault]);
 	}
-	
+
 	/**
 	 * Traverse the entire tree and update only what has changed.
-	 * 
+	 *
 	 * @param roots the root directory listing
 	 */
 	private void treeRefresh(File[] masterFiles) {
@@ -626,18 +600,18 @@ public class FileViewer {
 			TreeItem newItem = new TreeItem(tree, SWT.NONE);
 			treeInitVolume(newItem, masterFile);
 			new TreeItem(newItem, SWT.NONE); // placeholder child item to get "expand" button
-		}		
+		}
 	}
-	
+
 	/**
 	 * Traverse an item in the tree and update only what has changed.
-	 * 
+	 *
 	 * @param dirItem the tree item of the directory
 	 * @param forcePopulate true iff we should populate non-expanded items as well
 	 */
 	private void treeRefreshItem(TreeItem dirItem, boolean forcePopulate) {
 		final File dir = (File) dirItem.getData(TREEITEMDATA_FILE);
-		
+
 		if (! forcePopulate && ! dirItem.getExpanded()) {
 			// Refresh non-expanded item
 			if (dirItem.getData(TREEITEMDATA_STUB) != null) {
@@ -722,7 +696,7 @@ public class FileViewer {
 
 	/**
 	 * Initializes a folder item.
-	 * 
+	 *
 	 * @param item the TreeItem to initialize
 	 * @param folder the File associated with this TreeItem
 	 */
@@ -736,7 +710,7 @@ public class FileViewer {
 
 	/**
 	 * Initializes a volume item.
-	 * 
+	 *
 	 * @param item the TreeItem to initialize
 	 * @param volume the File associated with this TreeItem
 	 */
@@ -750,7 +724,7 @@ public class FileViewer {
 
 	/**
 	 * Creates the file details table.
-	 * 
+	 *
 	 * @param parent the parent control
 	 */
 	private void createTableView(Composite parent) {
@@ -784,7 +758,7 @@ public class FileViewer {
 			private File[] getSelectedFiles() {
 				final TableItem[] items = table.getSelection();
 				final File[] files = new File[items.length];
-				
+
 				for (int i = 0; i < items.length; ++i) {
 					files[i] = (File) items[i].getData(TABLEITEMDATA_FILE);
 				}
@@ -798,12 +772,12 @@ public class FileViewer {
 
 	/**
 	 * Creates the Drag & Drop DragSource for items being dragged from the table.
-	 * 
+	 *
 	 * @return the DragSource for the table
 	 */
 	private DragSource createTableDragSource(final Table table) {
 		DragSource dragSource = new DragSource(table, DND.DROP_MOVE | DND.DROP_COPY);
-		dragSource.setTransfer(new Transfer[] { FileTransfer.getInstance() });
+		dragSource.setTransfer(FileTransfer.getInstance());
 		dragSource.addDragListener(new DragSourceListener() {
 			TableItem[] dndSelection = null;
 			String[] sourceNames = null;
@@ -826,7 +800,7 @@ public class FileViewer {
 			public void dragSetData(DragSourceEvent event){
 				if (dndSelection == null || dndSelection.length == 0) return;
 				if (! FileTransfer.getInstance().isSupportedType(event.dataType)) return;
-				
+
 				sourceNames  = new String[dndSelection.length];
 				for (int i = 0; i < dndSelection.length; i++) {
 					File file = (File) dndSelection[i].getData(TABLEITEMDATA_FILE);
@@ -840,12 +814,12 @@ public class FileViewer {
 
 	/**
 	 * Creates the Drag & Drop DropTarget for items being dropped onto the table.
-	 * 
+	 *
 	 * @return the DropTarget for the table
 	 */
 	private DropTarget createTableDropTarget(final Table table){
 		DropTarget dropTarget = new DropTarget(table, DND.DROP_MOVE | DND.DROP_COPY);
-		dropTarget.setTransfer(new Transfer[] { FileTransfer.getInstance() });
+		dropTarget.setTransfer(FileTransfer.getInstance() );
 		dropTarget.addDropListener(new DropTargetAdapter() {
 			@Override
 			public void dragEnter(DropTargetEvent event) {
@@ -868,7 +842,7 @@ public class FileViewer {
 					dropTargetHandleDrop(event, targetFile);
 			}
 			private File getTargetFile(DropTargetEvent event) {
-				// Determine the target File for the drop 
+				// Determine the target File for the drop
 				TableItem item = table.getItem(table.toControl(new Point(event.x, event.y)));
 				File targetFile = null;
 				if (item == null) {
@@ -889,7 +863,7 @@ public class FileViewer {
 
 	/**
 	 * Notifies the application components that a new current directory has been selected
-	 * 
+	 *
 	 * @param dir the directory that was selected, null is ignored
 	 */
 	void notifySelectedDirectory(File dir) {
@@ -897,7 +871,7 @@ public class FileViewer {
 		if (currentDirectory != null && dir.equals(currentDirectory)) return;
 		currentDirectory = dir;
 		notifySelectedFiles(null);
-		
+
 		/* Shell:
 		 * Sets the title to indicate the selected directory
 		 */
@@ -913,7 +887,7 @@ public class FileViewer {
 		 */
 		final File[] comboRoots = (File[]) combo.getData(COMBODATA_ROOTS);
 		int comboEntry = -1;
-		if (comboRoots != null) {		
+		if (comboRoots != null) {
 			for (int i = 0; i < comboRoots.length; ++i) {
 				if (dir.equals(comboRoots[i])) {
 					comboEntry = i;
@@ -944,8 +918,8 @@ public class FileViewer {
 			// No guarantee that the items are sorted in any recognizable fashion, so we'll
 			// just sequential scan.  There shouldn't be more than a few thousand entries.
 			TreeItem item = null;
-			for (int k = 0; k < items.length; ++k) {
-				item = items[k];
+			for (TreeItem currentItem : items) {
+				item = currentItem;
 				if (item.isDisposed()) continue;
 				final File itemFile = (File) item.getData(TREEITEMDATA_FILE);
 				if (itemFile != null && itemFile.equals(pathElement)) break;
@@ -960,10 +934,10 @@ public class FileViewer {
 		}
 		tree.setSelection((lastItem != null) ? new TreeItem[] { lastItem } : new TreeItem[0]);
 	}
-	
+
 	/**
 	 * Notifies the application components that files have been selected
-	 * 
+	 *
 	 * @param files the files that were selected, null or empty array indicates no active selection
 	 */
 	void notifySelectedFiles(File[] files) {
@@ -974,11 +948,11 @@ public class FileViewer {
 			numObjectsLabel.setText(getResourceString("details.NumberOfSelectedFiles.text",
 				new Object[] { Integer.valueOf(files.length) }));
 			long fileSize = 0L;
-			for (int i = 0; i < files.length; ++i) {
-				fileSize += files[i].length();
+			for (File file : files) {
+				fileSize += file.length();
 			}
 			diskSpaceLabel.setText(getResourceString("details.FileSize.text",
-				new Object[] { new Long(fileSize) }));
+				new Object[] { Long.valueOf(fileSize) }));
 		} else {
 			// No files selected
 			diskSpaceLabel.setText("");
@@ -994,7 +968,7 @@ public class FileViewer {
 
 	/**
 	 * Notifies the application components that files must be refreshed
-	 * 
+	 *
 	 * @param files the files that need refreshing, empty array is a no-op, null refreshes all
 	 */
 	void notifyRefreshFiles(File[] files) {
@@ -1034,8 +1008,7 @@ public class FileViewer {
 		 */
 		boolean refreshTable = false;
 		if (files != null) {
-			for (int i = 0; i < files.length; ++i) {
-				final File file = files[i];
+			for (final File file : files) {
 				if (file.equals(currentDirectory)) {
 					refreshTable = true;
 					break;
@@ -1057,7 +1030,7 @@ public class FileViewer {
 		if (files == null) {
 			boolean refreshCombo = false;
 			final File[] comboRoots = (File[]) combo.getData(COMBODATA_ROOTS);
-		
+
 			if ((comboRoots != null) && (comboRoots.length == roots.length)) {
 				for (int i = 0; i < roots.length; ++i) {
 					if (! roots[i].equals(comboRoots[i])) {
@@ -1070,8 +1043,7 @@ public class FileViewer {
 			if (refreshCombo) {
 				combo.removeAll();
 				combo.setData(COMBODATA_ROOTS, roots);
-				for (int i = 0; i < roots.length; ++i) {
-					final File file = roots[i];
+				for (final File file : roots) {
 					combo.add(file.getPath());
 				}
 			}
@@ -1081,7 +1053,7 @@ public class FileViewer {
 		 * Refreshes information about any files in the list and their children.
 		 */
 		treeRefresh(roots);
-		
+
 		// Remind everyone where we are in the filesystem
 		final File dir = currentDirectory;
 		currentDirectory = null;
@@ -1092,7 +1064,7 @@ public class FileViewer {
 
 	/**
 	 * Performs the default action on a set of files.
-	 * 
+	 *
 	 * @param files the array of files to process
 	 */
 	void doDefaultFileAction(File[] files) {
@@ -1104,7 +1076,7 @@ public class FileViewer {
 			notifySelectedDirectory(file);
 		} else {
 			final String fileName = file.getAbsolutePath();
-			if (! Program.launch(fileName)) {	
+			if (! Program.launch(fileName)) {
 				MessageBox dialog = new MessageBox(shell, SWT.ICON_ERROR | SWT.OK);
 				dialog.setMessage(getResourceString("error.FailedLaunch.message", new Object[] { fileName }));
 				dialog.setText(shell.getText ());
@@ -1121,7 +1093,7 @@ public class FileViewer {
 		File parentDirectory = currentDirectory.getParentFile();
 		notifySelectedDirectory(parentDirectory);
 	}
-	 
+
 	/**
 	 * Performs a refresh
 	 */
@@ -1247,7 +1219,7 @@ public class FileViewer {
 			sourceFiles = new File[sourceNames.length];
 			for (int i = 0; i < sourceNames.length; ++i)
 				sourceFiles[i] = new File(sourceNames[i]);
-		}	
+		}
 		if (progressDialog == null)
 			progressDialog = new ProgressDialog(shell, ProgressDialog.MOVE);
 		progressDialog.setTotalWorkUnits(sourceFiles.length);
@@ -1280,7 +1252,7 @@ public class FileViewer {
 
 	/**
 	 * Gets filesystem root entries
-	 * 
+	 *
 	 * @return an array of Files corresponding to the root directories on the platform,
 	 *         may be empty but not null
 	 */
@@ -1322,7 +1294,7 @@ public class FileViewer {
 
 	/**
 	 * Gets a directory listing
-	 * 
+	 *
 	 * @param file the directory to be listed
 	 * @return an array of files this directory contains, may be empty but not null
 	 */
@@ -1332,24 +1304,24 @@ public class FileViewer {
 		sortFiles(list);
 		return list;
 	}
-	
+
 	/**
 	 * Copies a file or entire directory structure.
-	 * 
+	 *
 	 * @param oldFile the location of the old file or directory
 	 * @param newFile the location of the new file or directory
 	 * @return true iff the operation succeeds without errors
 	 */
 	boolean copyFileStructure(File oldFile, File newFile) {
 		if (oldFile == null || newFile == null) return false;
-		
+
 		// ensure that newFile is not a child of oldFile or a dupe
 		File searchFile = newFile;
 		do {
 			if (oldFile.equals(searchFile)) return false;
 			searchFile = searchFile.getParentFile();
 		} while (searchFile != null);
-		
+
 		if (oldFile.isDirectory()) {
 			/*
 			 * Copy a directory
@@ -1368,8 +1340,8 @@ public class FileViewer {
 				if (progressDialog != null) {
 					progressDialog.addWorkUnits(subFiles.length);
 				}
-				for (int i = 0; i < subFiles.length; i++) {
-					File oldSubFile = subFiles[i];
+				for (File subFile : subFiles) {
+					File oldSubFile = subFile;
 					File newSubFile = new File(newFile, oldSubFile.getName());
 					if (! copyFileStructure(oldSubFile, newSubFile)) return false;
 					if (progressDialog != null) {
@@ -1386,25 +1358,14 @@ public class FileViewer {
 				//System.out.println(getResourceString("simulate.CopyFromTo.text",
 				//	new Object[] { oldFile.getPath(), newFile.getPath() }));
 			} else {
-				FileReader in = null;
-				FileWriter out = null;
-				try {
-					in = new FileReader(oldFile);
-					out = new FileWriter(newFile);
-			
+				try (FileReader in = new FileReader(oldFile);
+						FileWriter out = new FileWriter(newFile);){
 					int count;
 					while ((count = in.read()) != -1) out.write(count);
 				} catch (FileNotFoundException e) {
 					return false;
 				} catch (IOException e) {
 					return false;
-				} finally {
-					try {
-						if (in != null) in.close();
-						if (out != null) out.close();
-					} catch (IOException e) {
-						return false;
-					}
 				}
 			}
 		}
@@ -1413,12 +1374,12 @@ public class FileViewer {
 
 	/**
 	 * Deletes a file or entire directory structure.
-	 * 
+	 *
 	 * @param oldFile the location of the old file or directory
 	 * @return true iff the operation succeeds without errors
 	 */
 	boolean deleteFileStructure(File oldFile) {
-		if (oldFile == null) return false;		
+		if (oldFile == null) return false;
 		if (oldFile.isDirectory()) {
 			/*
 			 * Delete a directory
@@ -1431,8 +1392,8 @@ public class FileViewer {
 				if (progressDialog != null) {
 					progressDialog.addWorkUnits(subFiles.length);
 				}
-				for (int i = 0; i < subFiles.length; i++) {
-					File oldSubFile = subFiles[i];
+				for (File subFile : subFiles) {
+					File oldSubFile = subFile;
 					if (! deleteFileStructure(oldSubFile)) return false;
 					if (progressDialog != null) {
 						progressDialog.addProgress(1);
@@ -1448,10 +1409,10 @@ public class FileViewer {
 		}
 		return oldFile.delete();
 	}
-	
+
 	/**
 	 * Sorts files lexicographically by name.
-	 * 
+	 *
 	 * @param files the array of Files to be sorted
 	 */
 	static void sortFiles(File[] files) {
@@ -1464,8 +1425,8 @@ public class FileViewer {
 			for (int i = end; i > start; --i) {
 				for (int j = end; j > start; --j)  {
 					if (compareFiles(files[j - 1], files[j]) > 0) {
-					    final File temp = files[j]; 
-					    files[j] = files[j-1]; 
+					    final File temp = files[j];
+					    files[j] = files[j-1];
 					    files[j-1] = temp;
 					}
 			    }
@@ -1497,7 +1458,7 @@ public class FileViewer {
 		if (compare == 0) compare = a.getName().compareTo(b.getName());
 		return compare;
 	}
-	
+
 	/*
 	 * This worker updates the table with file information in the background.
 	 * <p>
@@ -1529,7 +1490,7 @@ public class FileViewer {
 	/**
 	 * Notifies the worker that it should update itself with new data.
 	 * Cancels any previous operation and begins a new one.
-	 * 
+	 *
 	 * @param dir the new base directory for the table, null is ignored
 	 * @param force if true causes a refresh even if the data is the same
 	 */
@@ -1571,7 +1532,7 @@ public class FileViewer {
 		// (see workerStop())
 		display.wake();
 	};
-	
+
 	/**
 	 * Updates the table's contents
 	 */
@@ -1585,13 +1546,13 @@ public class FileViewer {
 			table.setData(TABLEDATA_DIR, workerStateDir);
 		});
 		dirList = getDirectoryList(workerStateDir);
-		
+
 		for (int i = 0; (! workerCancelled) && (i < dirList.length); i++) {
 			workerAddFileDetails(dirList[i]);
 		}
 
 	}
-		
+
 	/**
 	 * Adds a file's detail information to the directory list
 	 */
@@ -1601,15 +1562,15 @@ public class FileViewer {
 		final String sizeString;
 		final String typeString;
 		final Image iconImage;
-		
+
 		if (file.isDirectory()) {
 			typeString = getResourceString("filetype.Folder");
 			sizeString = "";
 			iconImage = iconCache.stockImages[iconCache.iconClosedFolder];
 		} else {
 			sizeString = getResourceString("filesize.KB",
-				new Object[] { new Long((file.length() + 512) / 1024) });
-			
+				new Object[] { Long.valueOf((file.length() + 512) / 1024) });
+
 			int dot = nameString.lastIndexOf('.');
 			if (dot != -1) {
 				String extension = nameString.substring(dot);
@@ -1637,7 +1598,7 @@ public class FileViewer {
 			tableItem.setData(TABLEITEMDATA_FILE, file);
 		});
 	}
-	
+
 	/**
 	 * Instances of this class manage a progress dialog for file operations.
 	 */
@@ -1657,10 +1618,10 @@ public class FileViewer {
 			"Delete",
 			"Move"
 		};
-	
+
 		/**
 		 * Creates a progress dialog but does not open it immediately.
-		 * 
+		 *
 		 * @param parent the parent Shell
 		 * @param style one of COPY, MOVE
 		 */
@@ -1669,42 +1630,34 @@ public class FileViewer {
 			GridLayout gridLayout = new GridLayout();
 			shell.setLayout(gridLayout);
 			shell.setText(getResourceString("progressDialog." + operationKeyName[style] + ".title"));
-			shell.addShellListener(new ShellAdapter() {
-				@Override
-				public void shellClosed(ShellEvent e) {
-					isCancelled = true;
-				}
-			});
-			
+			shell.addShellListener(ShellListener.shellClosedAdapter(e -> isCancelled = true));
+
 			messageLabel = new Label(shell, SWT.HORIZONTAL);
 			messageLabel.setLayoutData(new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_FILL));
 			messageLabel.setText(getResourceString("progressDialog." + operationKeyName[style] + ".description"));
-			
+
 			progressBar = new ProgressBar(shell, SWT.HORIZONTAL | SWT.WRAP);
 			progressBar.setLayoutData(new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_FILL));
 			progressBar.setMinimum(0);
 			progressBar.setMaximum(0);
-			
+
 			detailLabel = new Label(shell, SWT.HORIZONTAL);
 			GridData gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_BEGINNING);
 			gridData.widthHint = 400;
 			detailLabel.setLayoutData(gridData);
-			
+
 			cancelButton = new Button(shell, SWT.PUSH);
 			cancelButton.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_END | GridData.VERTICAL_ALIGN_FILL));
 			cancelButton.setText(getResourceString("progressDialog.cancelButton.text"));
-			cancelButton.addSelectionListener(new SelectionAdapter() {
-				@Override
-				public void widgetSelected(SelectionEvent e) {
-					isCancelled = true;
-					cancelButton.setEnabled(false);
-				}
-			});
+			cancelButton.addSelectionListener(widgetSelectedAdapter(e -> {
+				isCancelled = true;
+				cancelButton.setEnabled(false);
+			}));
 		}
 		/**
 		 * Sets the detail text to show the filename along with a string
 		 * representing the operation being performed on that file.
-		 * 
+		 *
 		 * @param file the file to be detailed
 		 * @param operation one of COPY, DELETE
 		 */
@@ -1714,7 +1667,7 @@ public class FileViewer {
 		}
 		/**
 		 * Returns true if the Cancel button was been clicked.
-		 * 
+		 *
 		 * @return true if the Cancel button was clicked.
 		 */
 		public boolean isCancelled() {
@@ -1722,7 +1675,7 @@ public class FileViewer {
 		}
 		/**
 		 * Sets the total number of work units to be performed.
-		 * 
+		 *
 		 * @param work the total number of work units
 		 */
 		public void setTotalWorkUnits(int work) {
@@ -1730,7 +1683,7 @@ public class FileViewer {
 		}
 		/**
 		 * Adds to the total number of work units to be performed.
-		 * 
+		 *
 		 * @param work the number of work units to add
 		 */
 		public void addWorkUnits(int work) {
@@ -1738,7 +1691,7 @@ public class FileViewer {
 		}
 		/**
 		 * Sets the progress of completion of the total work units.
-		 * 
+		 *
 		 * @param work the total number of work units completed
 		 */
 		public void setProgress(int work) {
@@ -1747,7 +1700,7 @@ public class FileViewer {
 		}
 		/**
 		 * Adds to the progress of completion of the total work units.
-		 * 
+		 *
 		 * @param work the number of work units completed to add
 		 */
 		public void addProgress(int work) {
