@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,6 +10,7 @@
  *******************************************************************************/
 package org.eclipse.swt.examples.imageanalyzer;
 
+import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 
 import java.io.InputStream;
 import java.net.URL;
@@ -23,18 +24,14 @@ import org.eclipse.swt.SWTError;
 import org.eclipse.swt.SWTException;
 import org.eclipse.swt.custom.StyleRange;
 import org.eclipse.swt.custom.StyledText;
-import org.eclipse.swt.events.ControlAdapter;
 import org.eclipse.swt.events.ControlEvent;
+import org.eclipse.swt.events.ControlListener;
 import org.eclipse.swt.events.KeyAdapter;
 import org.eclipse.swt.events.KeyEvent;
-import org.eclipse.swt.events.MouseAdapter;
-import org.eclipse.swt.events.MouseEvent;
+import org.eclipse.swt.events.MouseListener;
 import org.eclipse.swt.events.PaintEvent;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
-import org.eclipse.swt.events.ShellAdapter;
-import org.eclipse.swt.events.ShellEvent;
+import org.eclipse.swt.events.ShellListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Cursor;
 import org.eclipse.swt.graphics.Font;
@@ -168,24 +165,16 @@ public class ImageAnalyzer {
 			data = new GridData();
 			data.widthHint = 75;
 			ok.setLayoutData(data);
-			ok.addSelectionListener(new SelectionAdapter() {
-				@Override
-				public void widgetSelected(SelectionEvent e) {
-					result = text.getText();
-					dialog.dispose();
-				}
-			});
+			ok.addSelectionListener(widgetSelectedAdapter(e -> {
+				result = text.getText();
+				dialog.dispose();
+			}));
 			Button cancel = new Button(buttons, SWT.PUSH);
 			cancel.setText(bundle.getString("Cancel"));
 			data = new GridData();
 			data.widthHint = 75;
 			cancel.setLayoutData(data);
-			cancel.addSelectionListener(new SelectionAdapter() {
-				@Override
-				public void widgetSelected(SelectionEvent e) {
-					dialog.dispose();
-				}
-			});
+			cancel.addSelectionListener(widgetSelectedAdapter(e -> dialog.dispose()));
 			dialog.setDefaultButton(ok);
 			dialog.pack();
 			dialog.open();
@@ -213,25 +202,18 @@ public class ImageAnalyzer {
 		shell.setText(bundle.getString("Image_analyzer"));
 
 		// Hook resize and dispose listeners.
-		shell.addControlListener(new ControlAdapter() {
-			@Override
-			public void controlResized(ControlEvent event) {
-				resizeShell(event);
-			}
-		});
-		shell.addShellListener(new ShellAdapter() {
-			@Override
-			public void shellClosed(ShellEvent e) {
-				animate = false; // stop any animation in progress
-				if (animateThread != null) {
-					// wait for the thread to die before disposing the shell.
-					while (animateThread.isAlive()) {
-						if (!display.readAndDispatch()) display.sleep();
-					}
+		shell.addControlListener(ControlListener.controlResizedAdapter(e-> resizeShell(e)));
+		shell.addShellListener(ShellListener.shellClosedAdapter(e -> {
+			animate = false; // stop any animation in progress
+			if (animateThread != null) {
+				// wait for the thread to die before disposing the shell.
+				while (animateThread.isAlive()) {
+					if (!display.readAndDispatch())
+						display.sleep();
 				}
-				e.doit = true;
 			}
-		});
+			e.doit = true;
+		}));
 		shell.addDisposeListener(e -> {
 			// Clean up.
 			if (image != null)
@@ -297,12 +279,7 @@ public class ImageAnalyzer {
 			bundle.getString("Green"),
 			bundle.getString("Blue"));
 		backgroundCombo.select(backgroundCombo.indexOf(bundle.getString("White")));
-		backgroundCombo.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				changeBackground();
-			}
-		});
+		backgroundCombo.addSelectionListener(widgetSelectedAdapter(event -> changeBackground()));
 
 		// Combo to change the compression ratio.
 		group = new Group(controls, SWT.NONE);
@@ -314,41 +291,38 @@ public class ImageAnalyzer {
 			imageTypeCombo.add(type);
 		}
 		imageTypeCombo.select(imageTypeCombo.indexOf("JPEG"));
-		imageTypeCombo.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				int index = imageTypeCombo.getSelectionIndex();
-				switch(index) {
-				case 0:
-					compressionCombo.setEnabled(true);
-					compressionRatioLabel.setEnabled(true);
-					if (compressionCombo.getItemCount() == 100) break;
-					compressionCombo.removeAll();
-					for (int i = 0; i < 100; i++) {
-						compressionCombo.add(String.valueOf(i + 1));
-					}
-					compressionCombo.select(compressionCombo.indexOf("75"));
-					break;
-				case 1:
-					compressionCombo.setEnabled(true);
-					compressionRatioLabel.setEnabled(true);
-					if (compressionCombo.getItemCount() == 10) break;
-					compressionCombo.removeAll();
-					for (int i = 0; i < 4; i++) {
-						compressionCombo.add(String.valueOf(i));
-					}
-					compressionCombo.select(0);
-					break;
-				case 2:
-				case 3:
-				case 4:
-				case 5:
-					compressionCombo.setEnabled(false);
-					compressionRatioLabel.setEnabled(false);
-					break;
+		imageTypeCombo.addSelectionListener(widgetSelectedAdapter(event -> {
+			int index = imageTypeCombo.getSelectionIndex();
+			switch(index) {
+			case 0:
+				compressionCombo.setEnabled(true);
+				compressionRatioLabel.setEnabled(true);
+				if (compressionCombo.getItemCount() == 100) break;
+				compressionCombo.removeAll();
+				for (int i = 0; i < 100; i++) {
+					compressionCombo.add(String.valueOf(i + 1));
 				}
+				compressionCombo.select(compressionCombo.indexOf("75"));
+				break;
+			case 1:
+				compressionCombo.setEnabled(true);
+				compressionRatioLabel.setEnabled(true);
+				if (compressionCombo.getItemCount() == 10) break;
+				compressionCombo.removeAll();
+				for (int i = 0; i < 4; i++) {
+					compressionCombo.add(String.valueOf(i));
+				}
+				compressionCombo.select(0);
+				break;
+			case 2:
+			case 3:
+			case 4:
+			case 5:
+				compressionCombo.setEnabled(false);
+				compressionRatioLabel.setEnabled(false);
+				break;
 			}
-		});
+		}));
 		imageTypeCombo.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
 		compressionRatioLabel = new Label(group, SWT.NONE);
 		compressionRatioLabel.setText(bundle.getString("Compression"));
@@ -368,32 +342,22 @@ public class ImageAnalyzer {
 		group.setLayout(new RowLayout());
 		group.setText(bundle.getString("X_scale"));
 		scaleXCombo = new Combo(group, SWT.DROP_DOWN);
-		for (int i = 0; i < values.length; i++) {
-			scaleXCombo.add(values[i]);
+		for (String value : values) {
+			scaleXCombo.add(value);
 		}
 		scaleXCombo.select(scaleXCombo.indexOf("1"));
-		scaleXCombo.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				scaleX();
-			}
-		});
+		scaleXCombo.addSelectionListener(widgetSelectedAdapter(event -> scaleX()));
 
 		// Combo to change the y scale.
 		group = new Group(controls, SWT.NONE);
 		group.setLayout(new RowLayout());
 		group.setText(bundle.getString("Y_scale"));
 		scaleYCombo = new Combo(group, SWT.DROP_DOWN);
-		for (int i = 0; i < values.length; i++) {
-			scaleYCombo.add(values[i]);
+		for (String value : values) {
+			scaleYCombo.add(value);
 		}
 		scaleYCombo.select(scaleYCombo.indexOf("1"));
-		scaleYCombo.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				scaleY();
-			}
-		});
+		scaleYCombo.addSelectionListener(widgetSelectedAdapter(event -> scaleY()));
 
 		// Combo to change the alpha value.
 		group = new Group(controls, SWT.NONE);
@@ -404,12 +368,7 @@ public class ImageAnalyzer {
 			alphaCombo.add(String.valueOf(i));
 		}
 		alphaCombo.select(alphaCombo.indexOf("255"));
-		alphaCombo.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				alpha();
-			}
-		});
+		alphaCombo.addSelectionListener(widgetSelectedAdapter(event -> alpha()));
 
 		// Check box to request incremental display.
 		group = new Group(controls, SWT.NONE);
@@ -418,51 +377,35 @@ public class ImageAnalyzer {
 		incrementalCheck = new Button(group, SWT.CHECK);
 		incrementalCheck.setText(bundle.getString("Incremental"));
 		incrementalCheck.setSelection(incremental);
-		incrementalCheck.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				incremental = ((Button)event.widget).getSelection();
-			}
-		});
+		incrementalCheck.addSelectionListener(widgetSelectedAdapter(event -> incremental = ((Button)event.widget).getSelection()));
 
 		// Check box to request transparent display.
 		transparentCheck = new Button(group, SWT.CHECK);
 		transparentCheck.setText(bundle.getString("Transparent"));
 		transparentCheck.setSelection(transparent);
-		transparentCheck.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				transparent = ((Button)event.widget).getSelection();
-				if (image != null) {
-					imageCanvas.redraw();
-				}
+		transparentCheck.addSelectionListener(widgetSelectedAdapter(event -> {
+			transparent = ((Button)event.widget).getSelection();
+			if (image != null) {
+				imageCanvas.redraw();
 			}
-		});
+		}));
 
 		// Check box to request mask display.
 		maskCheck = new Button(group, SWT.CHECK);
 		maskCheck.setText(bundle.getString("Mask"));
 		maskCheck.setSelection(showMask);
-		maskCheck.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				showMask = ((Button)event.widget).getSelection();
-				if (image != null) {
-					imageCanvas.redraw();
-				}
+		maskCheck.addSelectionListener(widgetSelectedAdapter(event -> {
+			showMask = ((Button)event.widget).getSelection();
+			if (image != null) {
+				imageCanvas.redraw();
 			}
-		});
+		}));
 
 		// Check box to request background display.
 		backgroundCheck = new Button(group, SWT.CHECK);
 		backgroundCheck.setText(bundle.getString("Background"));
 		backgroundCheck.setSelection(showBackground);
-		backgroundCheck.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				showBackground = ((Button)event.widget).getSelection();
-			}
-		});
+		backgroundCheck.addSelectionListener(widgetSelectedAdapter(event -> showBackground = ((Button)event.widget).getSelection()));
 
 		// Group the animation buttons.
 		group = new Group(controls, SWT.NONE);
@@ -473,34 +416,19 @@ public class ImageAnalyzer {
 		previousButton = new Button(group, SWT.PUSH);
 		previousButton.setText(bundle.getString("Previous"));
 		previousButton.setEnabled(false);
-		previousButton.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				previous();
-			}
-		});
+		previousButton.addSelectionListener(widgetSelectedAdapter(event -> previous()));
 
 		// Push button to display the next image in a multi-image file.
 		nextButton = new Button(group, SWT.PUSH);
 		nextButton.setText(bundle.getString("Next"));
 		nextButton.setEnabled(false);
-		nextButton.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				next();
-			}
-		});
+		nextButton.addSelectionListener(widgetSelectedAdapter(event -> next()));
 
 		// Push button to toggle animation of a multi-image file.
 		animateButton = new Button(group, SWT.PUSH);
 		animateButton.setText(bundle.getString("Animate"));
 		animateButton.setEnabled(false);
-		animateButton.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				animate();
-			}
-		});
+		animateButton.addSelectionListener(widgetSelectedAdapter(event -> animate()));
 
 		// Label to show the image file type.
 		typeLabel = new Label(shell, SWT.NONE);
@@ -537,22 +465,12 @@ public class ImageAnalyzer {
 		horizontal.setVisible(true);
 		horizontal.setMinimum(0);
 		horizontal.setEnabled(false);
-		horizontal.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				scrollHorizontally((ScrollBar)event.widget);
-			}
-		});
+		horizontal.addSelectionListener(widgetSelectedAdapter(event -> scrollHorizontally((ScrollBar)event.widget)));
 		ScrollBar vertical = imageCanvas.getVerticalBar();
 		vertical.setVisible(true);
 		vertical.setMinimum(0);
 		vertical.setEnabled(false);
-		vertical.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				scrollVertically((ScrollBar)event.widget);
-			}
-		});
+		vertical.addSelectionListener(widgetSelectedAdapter(event -> scrollVertically((ScrollBar)event.widget)));
 
 		// Label to show the image size.
 		sizeLabel = new Label(shell, SWT.NONE);
@@ -641,12 +559,7 @@ public class ImageAnalyzer {
 		vertical.setMinimum(0);
 		vertical.setIncrement(10);
 		vertical.setEnabled(false);
-		vertical.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				scrollPalette((ScrollBar)event.widget);
-			}
-		});
+		vertical.addSelectionListener(widgetSelectedAdapter(event -> scrollPalette((ScrollBar)event.widget)));
 
 		// Sash to see more of image or image data.
 		sash = new Sash(shell, SWT.HORIZONTAL);
@@ -654,32 +567,29 @@ public class ImageAnalyzer {
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
 		sash.setLayoutData(gridData);
-		sash.addSelectionListener (new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				if (event.detail != SWT.DRAG) {
-					((GridData)paletteCanvas.getLayoutData()).heightHint = SWT.DEFAULT;
-					Rectangle paletteCanvasBounds = paletteCanvas.getBounds();
-					int minY = paletteCanvasBounds.y + 20;
-					Rectangle dataLabelBounds = dataLabel.getBounds();
-					int maxY = statusLabel.getBounds().y - dataLabelBounds.height - 20;
-					if (event.y > minY && event.y < maxY) {
-						Rectangle oldSash = sash.getBounds();
-						sash.setBounds(event.x, event.y, event.width, event.height);
-						int diff = event.y - oldSash.y;
-						Rectangle bounds = imageCanvas.getBounds();
-						imageCanvas.setBounds(bounds.x, bounds.y, bounds.width, bounds.height + diff);
-						bounds = paletteCanvasBounds;
-						paletteCanvas.setBounds(bounds.x, bounds.y, bounds.width, bounds.height + diff);
-						bounds = dataLabelBounds;
-						dataLabel.setBounds(bounds.x, bounds.y + diff, bounds.width, bounds.height);
-						bounds = dataText.getBounds();
-						dataText.setBounds(bounds.x, bounds.y + diff, bounds.width, bounds.height - diff);
-						//shell.layout(true);
-					}
+		sash.addSelectionListener (widgetSelectedAdapter(event -> {
+			if (event.detail != SWT.DRAG) {
+				((GridData)paletteCanvas.getLayoutData()).heightHint = SWT.DEFAULT;
+				Rectangle paletteCanvasBounds = paletteCanvas.getBounds();
+				int minY = paletteCanvasBounds.y + 20;
+				Rectangle dataLabelBounds = dataLabel.getBounds();
+				int maxY = statusLabel.getBounds().y - dataLabelBounds.height - 20;
+				if (event.y > minY && event.y < maxY) {
+					Rectangle oldSash = sash.getBounds();
+					sash.setBounds(event.x, event.y, event.width, event.height);
+					int diff = event.y - oldSash.y;
+					Rectangle bounds = imageCanvas.getBounds();
+					imageCanvas.setBounds(bounds.x, bounds.y, bounds.width, bounds.height + diff);
+					bounds = paletteCanvasBounds;
+					paletteCanvas.setBounds(bounds.x, bounds.y, bounds.width, bounds.height + diff);
+					bounds = dataLabelBounds;
+					dataLabel.setBounds(bounds.x, bounds.y + diff, bounds.width, bounds.height);
+					bounds = dataText.getBounds();
+					dataText.setBounds(bounds.x, bounds.y + diff, bounds.width, bounds.height - diff);
+					//shell.layout(true);
 				}
 			}
-		});
+		}));
 
 		// Label to show data-specific fields.
 		dataLabel = new Label(shell, SWT.NONE);
@@ -700,14 +610,11 @@ public class ImageAnalyzer {
 		gridData.heightHint = 128;
 		gridData.grabExcessVerticalSpace = true;
 		dataText.setLayoutData(gridData);
-		dataText.addMouseListener(new MouseAdapter() {
-			@Override
-			public void mouseDown(MouseEvent event) {
-				if (image != null && event.button == 1) {
-					showColorForData();
-				}
+		dataText.addMouseListener(MouseListener.mouseDownAdapter(event -> {
+			if (image != null && event.button == 1) {
+				showColorForData();
 			}
-		});
+		}));
 		dataText.addKeyListener(new KeyAdapter() {
 			@Override
 			public void keyPressed(KeyEvent event) {
@@ -746,33 +653,18 @@ public class ImageAnalyzer {
 		item = new MenuItem(fileMenu, SWT.PUSH);
 		item.setText(bundle.getString("OpenFile"));
 		item.setAccelerator(SWT.MOD1 + 'O');
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuOpenFile();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuOpenFile()));
 
 		// File -> Open URL...
 		item = new MenuItem(fileMenu, SWT.PUSH);
 		item.setText(bundle.getString("OpenURL"));
 		item.setAccelerator(SWT.MOD1 + 'U');
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuOpenURL();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuOpenURL()));
 
 		// File -> Reopen
 		item = new MenuItem(fileMenu, SWT.PUSH);
 		item.setText(bundle.getString("Reopen"));
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuReopen();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuReopen()));
 
 		new MenuItem(fileMenu, SWT.SEPARATOR);
 
@@ -780,12 +672,7 @@ public class ImageAnalyzer {
 		item = new MenuItem(fileMenu, SWT.PUSH);
 		item.setText(bundle.getString("LoadFile"));
 		item.setAccelerator(SWT.MOD1 + 'L');
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuLoad();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuLoad()));
 
 		new MenuItem(fileMenu, SWT.SEPARATOR);
 
@@ -793,32 +680,17 @@ public class ImageAnalyzer {
 		item = new MenuItem(fileMenu, SWT.PUSH);
 		item.setText(bundle.getString("Save"));
 		item.setAccelerator(SWT.MOD1 + 'S');
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuSave();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuSave()));
 
 		// File -> Save As...
 		item = new MenuItem(fileMenu, SWT.PUSH);
 		item.setText(bundle.getString("Save_as"));
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuSaveAs();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuSaveAs()));
 
 		// File -> Save Mask As...
 		item = new MenuItem(fileMenu, SWT.PUSH);
 		item.setText(bundle.getString("Save_mask_as"));
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuSaveMaskAs();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuSaveMaskAs()));
 
 		new MenuItem(fileMenu, SWT.SEPARATOR);
 
@@ -826,24 +698,14 @@ public class ImageAnalyzer {
 		item = new MenuItem(fileMenu, SWT.PUSH);
 		item.setText(bundle.getString("Print"));
 		item.setAccelerator(SWT.MOD1 + 'P');
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuPrint();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuPrint()));
 
 		new MenuItem(fileMenu, SWT.SEPARATOR);
 
 		// File -> Exit
 		item = new MenuItem(fileMenu, SWT.PUSH);
 		item.setText(bundle.getString("Exit"));
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				shell.close();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> shell.close()));
 
 	}
 
@@ -857,32 +719,17 @@ public class ImageAnalyzer {
 		// Alpha -> K
 		item = new MenuItem(alphaMenu, SWT.PUSH);
 		item.setText("K");
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuComposeAlpha(ALPHA_CONSTANT);
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuComposeAlpha(ALPHA_CONSTANT)));
 
 		// Alpha -> (K + x) % 256
 		item = new MenuItem(alphaMenu, SWT.PUSH);
 		item.setText("(K + x) % 256");
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuComposeAlpha(ALPHA_X);
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuComposeAlpha(ALPHA_X)));
 
 		// Alpha -> (K + y) % 256
 		item = new MenuItem(alphaMenu, SWT.PUSH);
 		item.setText("(K + y) % 256");
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent event) {
-				menuComposeAlpha(ALPHA_Y);
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(event -> menuComposeAlpha(ALPHA_Y)));
 	}
 
 	void menuComposeAlpha(int alpha_op) {
@@ -1045,18 +892,18 @@ public class ImageAnalyzer {
 		ImageLoader oldLoader = loader;
 		try {
 			URL url = new URL(urlname);
-			InputStream stream = url.openStream();
-			loader = new ImageLoader();
-			if (incremental) {
-				// Prepare to handle incremental events.
-				loader.addImageLoaderListener(event -> incrementalDataLoaded(event));
-				incrementalThreadStart();
+			try (InputStream stream = url.openStream()) {
+				loader = new ImageLoader();
+				if (incremental) {
+					// Prepare to handle incremental events.
+					loader.addImageLoaderListener(event -> incrementalDataLoaded(event));
+					incrementalThreadStart();
+				}
+				// Read the new image(s) from the chosen URL.
+				long startTime = System.currentTimeMillis();
+				imageDataArray = loader.load(stream);
+				loadTime = System.currentTimeMillis() - startTime;
 			}
-			// Read the new image(s) from the chosen URL.
-			long startTime = System.currentTimeMillis();
-			imageDataArray = loader.load(stream);
-			loadTime = System.currentTimeMillis() - startTime;
-			stream.close();
 			if (imageDataArray.length > 0) {
 				currentName = urlname;
 				fileName = null;
@@ -1396,11 +1243,11 @@ public class ImageAnalyzer {
 			ImageData[] newImageData;
 			if (fileName == null) {
 				URL url = new URL(currentName);
-				InputStream stream = url.openStream();
-				long startTime = System.currentTimeMillis();
-				newImageData = loader.load(stream);
-				loadTime = System.currentTimeMillis() - startTime;
-				stream.close();
+				try (InputStream stream = url.openStream()) {
+					long startTime = System.currentTimeMillis();
+					newImageData = loader.load(stream);
+					loadTime = System.currentTimeMillis() - startTime;
+				}
 			} else {
 				long startTime = System.currentTimeMillis();
 				newImageData = loader.load(fileName);
@@ -1856,7 +1703,7 @@ public class ImageAnalyzer {
 		string = createMsg(bundle.getString("Transparent_pixel_value"), pixelInfo(imageData.transparentPixel));
 		transparentPixelLabel.setText(string);
 
-		string = createMsg(bundle.getString("Time_to_load_value"), new Long(loadTime));
+		string = createMsg(bundle.getString("Time_to_load_value"), Long.valueOf(loadTime));
 		timeToLoadLabel.setText(string);
 
 		string = createMsg(bundle.getString("Animation_size_value"),
@@ -2293,13 +2140,10 @@ public class ImageAnalyzer {
 	int showBMPDialog() {
 		final int [] bmpType = new int[1];
 		bmpType[0] = SWT.IMAGE_BMP;
-		SelectionListener radioSelected = new SelectionAdapter () {
-			@Override
-			public void widgetSelected (SelectionEvent event) {
-				Button radio = (Button) event.widget;
-				if (radio.getSelection()) bmpType[0] = ((Integer)radio.getData()).intValue();
-			}
-		};
+		SelectionListener radioSelected = widgetSelectedAdapter(event -> {
+			Button radio = (Button) event.widget;
+			if (radio.getSelection()) bmpType[0] = ((Integer)radio.getData()).intValue();
+		});
 		// need to externalize strings
 		final Shell dialog = new Shell(shell, SWT.DIALOG_TRIM);
 
@@ -2334,12 +2178,7 @@ public class ImageAnalyzer {
 		data.horizontalAlignment = SWT.CENTER;
 		data.widthHint = 75;
 		ok.setLayoutData(data);
-		ok.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				dialog.close();
-			}
-		});
+		ok.addSelectionListener(widgetSelectedAdapter(e -> dialog.close()));
 
 		dialog.pack();
 		dialog.open();
