@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -14,10 +14,8 @@ package org.eclipse.swt.examples.layoutexample;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CCombo;
 import org.eclipse.swt.custom.TableEditor;
-import org.eclipse.swt.events.MouseAdapter;
-import org.eclipse.swt.events.MouseEvent;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.events.MouseListener;
+import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.layout.FormAttachment;
@@ -47,7 +45,7 @@ class FormLayoutTab extends Tab {
 	CCombo combo;
 	Text nameText, widthText, heightText;
 	Button leftAttach, rightAttach, topAttach, bottomAttach;
-	
+
 	/* Constants */
 	final int NAME_COL = 0;
 	final int COMBO_COL = 1;
@@ -57,7 +55,7 @@ class FormLayoutTab extends Tab {
 	final int RIGHT_COL = 5;
 	final int TOP_COL = 6;
 	final int BOTTOM_COL = 7;
-	
+
 	final int MODIFY_COLS = 4;	// The number of columns with combo or text editors
 	final int TOTAL_COLS = 8;
 
@@ -67,7 +65,7 @@ class FormLayoutTab extends Tab {
 	FormLayoutTab(LayoutExample instance) {
 		super(instance);
 	}
-	
+
 	/**
 	 * Returns the constant for the alignment for an
 	 * attachment given a string.
@@ -80,7 +78,7 @@ class FormLayoutTab extends Tab {
 		if (align.equals("CENTER")) return SWT.CENTER;
 		return SWT.DEFAULT;
 	}
-	
+
 	/**
 	 * Returns a string representing the alignment for an
 	 * attachment given a constant.
@@ -95,10 +93,10 @@ class FormLayoutTab extends Tab {
 		}
 		return "DEFAULT";
 	}
-	
+
 	/**
 	 * Update the attachment field in case the type of control
-	 * has changed. 
+	 * has changed.
 	 */
 	String checkAttachment (String oldAttach, FormAttachment newAttach) {
 		String controlClass = newAttach.control.getClass().toString ();
@@ -110,7 +108,7 @@ class FormLayoutTab extends Tab {
 		String index = oldAttach.substring (i, oldAttach.indexOf (','));
 		return controlType + index + "," + newAttach.offset + ":" + alignmentString (newAttach.alignment);
 	}
-	
+
 	/**
 	 * Creates the widgets in the "child" group.
 	 */
@@ -118,13 +116,13 @@ class FormLayoutTab extends Tab {
 	void createChildWidgets () {
 		/* Add common controls */
 		super.createChildWidgets ();
-		
+
 		/* Resize the columns */
 		table.getColumn (LEFT_COL).setWidth (90);
 		table.getColumn (RIGHT_COL).setWidth (90);
 		table.getColumn (TOP_COL).setWidth (90);
 		table.getColumn (BOTTOM_COL).setWidth (90);
-				
+
 		/* Add TableEditors */
 		nameEditor = new TableEditor (table);
 		comboEditor = new TableEditor (table);
@@ -134,136 +132,124 @@ class FormLayoutTab extends Tab {
 		rightEditor = new TableEditor (table);
 		topEditor = new TableEditor (table);
 		bottomEditor = new TableEditor (table);
-		table.addMouseListener (new MouseAdapter () {
-			@Override
-			public void mouseDown(MouseEvent e) {
-				resetEditors();
-				index = table.getSelectionIndex ();
-				Point pt = new Point (e.x, e.y);
-                newItem = table.getItem (pt);
-                if (newItem == null) return;
-                TableItem oldItem = comboEditor.getItem ();
-                if (newItem == oldItem || newItem != lastSelected) {
-					lastSelected = newItem;
-					return;
-				}
-				table.showSelection ();
-				
-				combo = new CCombo (table, SWT.READ_ONLY);
-				createComboEditor (combo, comboEditor);
-				
-				nameText = new Text (table, SWT.SINGLE);
-				nameText.setText (data.get(index)[NAME_COL]);
-				createTextEditor(nameText, nameEditor, NAME_COL);
-				
-				widthText = new Text (table, SWT.SINGLE);
-				widthText.setText (data.get (index) [WIDTH_COL]);
-				createTextEditor (widthText, widthEditor, WIDTH_COL);
-				
-				heightText = new Text (table, SWT.SINGLE);
-				heightText.setText (data.get (index) [HEIGHT_COL]);
-				createTextEditor (heightText, heightEditor, HEIGHT_COL);
-				
-				leftAttach = new Button (table, SWT.PUSH);
-				leftAttach.setText (LayoutExample.getResourceString ("Attach_Edit"));
-				leftEditor.horizontalAlignment = SWT.LEFT;
-				leftEditor.grabHorizontal = true;
-				leftEditor.minimumWidth = leftAttach.computeSize (SWT.DEFAULT, SWT.DEFAULT).x;
-				leftEditor.setEditor (leftAttach, newItem, LEFT_COL);
-				leftAttach.addSelectionListener (new SelectionAdapter () {
-					@Override
-					public void widgetSelected (SelectionEvent e) {
-						Shell shell = tabFolderPage.getShell ();
-						AttachDialog dialog = new AttachDialog (shell);
-						dialog.setText (LayoutExample.getResourceString ("Left_Attachment"));
-						dialog.setColumn (LEFT_COL);
-						String attach = dialog.open ();
-						newItem.setText (LEFT_COL, attach);
-						resetEditors ();
-					}
-				});
-				
-				rightAttach = new Button (table, SWT.PUSH);
-				rightAttach.setText (LayoutExample.getResourceString ("Attach_Edit"));
-				rightEditor.horizontalAlignment = SWT.LEFT;
-				rightEditor.grabHorizontal = true;
-				rightEditor.minimumWidth = rightAttach.computeSize (SWT.DEFAULT, SWT.DEFAULT).x;
-				rightEditor.setEditor (rightAttach, newItem, RIGHT_COL);
-				rightAttach.addSelectionListener (new SelectionAdapter () {
-					@Override
-					public void widgetSelected (SelectionEvent e) {
-						Shell shell = tabFolderPage.getShell ();
-						AttachDialog dialog = new AttachDialog (shell);
-						dialog.setText (LayoutExample.getResourceString ("Right_Attachment"));
-						dialog.setColumn (RIGHT_COL);
-						String attach = dialog.open ();
-						newItem.setText (RIGHT_COL, attach);
-						if (newItem.getText (LEFT_COL).endsWith (")")) newItem.setText (LEFT_COL, "");
-						resetEditors ();
-					}
-				});
-				
-				topAttach = new Button (table, SWT.PUSH);
-				topAttach.setText (LayoutExample.getResourceString ("Attach_Edit"));
-				topEditor.horizontalAlignment = SWT.LEFT;
-				topEditor.grabHorizontal = true;
-				topEditor.minimumWidth = topAttach.computeSize (SWT.DEFAULT, SWT.DEFAULT).x;
-				topEditor.setEditor (topAttach, newItem, TOP_COL);
-				topAttach.addSelectionListener (new SelectionAdapter () {
-					@Override
-					public void widgetSelected (SelectionEvent e) {
-						Shell shell = tabFolderPage.getShell ();
-						AttachDialog dialog = new AttachDialog (shell);
-						dialog.setText (LayoutExample.getResourceString ("Top_Attachment"));
-						dialog.setColumn (TOP_COL);
-						String attach = dialog.open ();
-						newItem.setText (TOP_COL, attach);
-						resetEditors ();
-					}
-				});
-				bottomAttach = new Button (table, SWT.PUSH);
-				bottomAttach.setText (LayoutExample.getResourceString ("Attach_Edit"));
-				bottomEditor.horizontalAlignment = SWT.LEFT;
-				bottomEditor.grabHorizontal = true;
-				bottomEditor.minimumWidth = bottomAttach.computeSize (SWT.DEFAULT, SWT.DEFAULT).x;
-				bottomEditor.setEditor (bottomAttach, newItem, BOTTOM_COL);
-				bottomAttach.addSelectionListener (new SelectionAdapter () {
-					@Override
-					public void widgetSelected (SelectionEvent e) {
-						Shell shell = tabFolderPage.getShell ();
-						AttachDialog dialog = new AttachDialog (shell);
-						dialog.setText (LayoutExample.getResourceString ("Bottom_Attachment"));
-						dialog.setColumn (BOTTOM_COL);
-						String attach = dialog.open ();
-						newItem.setText (BOTTOM_COL, attach);
-						if (newItem.getText (TOP_COL).endsWith (")")) newItem.setText (TOP_COL, "");
-						resetEditors ();
-					}
-				});
-                
-                for (int i=0; i<table.getColumnCount (); i++) {
-                	Rectangle rect = newItem.getBounds (i);
-                    if (rect.contains (pt)) {
-                    	switch (i) {
-                    		case 0:
-                    			resetEditors ();
-                    			break;
-							case COMBO_COL :
-								combo.setFocus ();	
-								break;
-							case WIDTH_COL :	
-								widthText.setFocus ();
-								break;
-							case HEIGHT_COL :
-								heightText.setFocus ();
-								break;
-							default :
-								break;
-						}
-                    }
-                } 
+		table.addMouseListener(MouseListener.mouseDownAdapter(e -> {
+			resetEditors();
+			index = table.getSelectionIndex();
+			Point pt = new Point(e.x, e.y);
+			newItem = table.getItem(pt);
+			if (newItem == null)
+				return;
+			TableItem oldItem = comboEditor.getItem();
+			if (newItem == oldItem || newItem != lastSelected) {
+				lastSelected = newItem;
+				return;
 			}
-		});		
+			table.showSelection();
+
+			combo = new CCombo(table, SWT.READ_ONLY);
+			createComboEditor(combo, comboEditor);
+
+			nameText = new Text(table, SWT.SINGLE);
+			nameText.setText(data.get(index)[NAME_COL]);
+			createTextEditor(nameText, nameEditor, NAME_COL);
+
+			widthText = new Text(table, SWT.SINGLE);
+			widthText.setText(data.get(index)[WIDTH_COL]);
+			createTextEditor(widthText, widthEditor, WIDTH_COL);
+
+			heightText = new Text(table, SWT.SINGLE);
+			heightText.setText(data.get(index)[HEIGHT_COL]);
+			createTextEditor(heightText, heightEditor, HEIGHT_COL);
+
+			leftAttach = new Button(table, SWT.PUSH);
+			leftAttach.setText(LayoutExample.getResourceString("Attach_Edit"));
+			leftEditor.horizontalAlignment = SWT.LEFT;
+			leftEditor.grabHorizontal = true;
+			leftEditor.minimumWidth = leftAttach.computeSize(SWT.DEFAULT, SWT.DEFAULT).x;
+			leftEditor.setEditor(leftAttach, newItem, LEFT_COL);
+			leftAttach.addSelectionListener(SelectionListener.widgetSelectedAdapter(e1 -> {
+				Shell shell = tabFolderPage.getShell();
+				AttachDialog dialog = new AttachDialog(shell);
+				dialog.setText(LayoutExample.getResourceString("Left_Attachment"));
+				dialog.setColumn(LEFT_COL);
+				String attach = dialog.open();
+				newItem.setText(LEFT_COL, attach);
+				resetEditors();
+			}));
+
+			rightAttach = new Button(table, SWT.PUSH);
+			rightAttach.setText(LayoutExample.getResourceString("Attach_Edit"));
+			rightEditor.horizontalAlignment = SWT.LEFT;
+			rightEditor.grabHorizontal = true;
+			rightEditor.minimumWidth = rightAttach.computeSize(SWT.DEFAULT, SWT.DEFAULT).x;
+			rightEditor.setEditor(rightAttach, newItem, RIGHT_COL);
+			rightAttach.addSelectionListener(SelectionListener.widgetSelectedAdapter(e1 -> {
+				Shell shell = tabFolderPage.getShell();
+				AttachDialog dialog = new AttachDialog(shell);
+				dialog.setText(LayoutExample.getResourceString("Right_Attachment"));
+				dialog.setColumn(RIGHT_COL);
+				String attach = dialog.open();
+				newItem.setText(RIGHT_COL, attach);
+				if (newItem.getText(LEFT_COL).endsWith(")"))
+					newItem.setText(LEFT_COL, "");
+				resetEditors();
+			}));
+
+			topAttach = new Button(table, SWT.PUSH);
+			topAttach.setText(LayoutExample.getResourceString("Attach_Edit"));
+			topEditor.horizontalAlignment = SWT.LEFT;
+			topEditor.grabHorizontal = true;
+			topEditor.minimumWidth = topAttach.computeSize(SWT.DEFAULT, SWT.DEFAULT).x;
+			topEditor.setEditor(topAttach, newItem, TOP_COL);
+			topAttach.addSelectionListener(SelectionListener.widgetSelectedAdapter(e1 -> {
+				Shell shell = tabFolderPage.getShell();
+				AttachDialog dialog = new AttachDialog(shell);
+				dialog.setText(LayoutExample.getResourceString("Top_Attachment"));
+				dialog.setColumn(TOP_COL);
+				String attach = dialog.open();
+				newItem.setText(TOP_COL, attach);
+				resetEditors();
+			}));
+			bottomAttach = new Button(table, SWT.PUSH);
+			bottomAttach.setText(LayoutExample.getResourceString("Attach_Edit"));
+			bottomEditor.horizontalAlignment = SWT.LEFT;
+			bottomEditor.grabHorizontal = true;
+			bottomEditor.minimumWidth = bottomAttach.computeSize(SWT.DEFAULT, SWT.DEFAULT).x;
+			bottomEditor.setEditor(bottomAttach, newItem, BOTTOM_COL);
+			bottomAttach.addSelectionListener(SelectionListener.widgetSelectedAdapter(e1 -> {
+				Shell shell = tabFolderPage.getShell();
+				AttachDialog dialog = new AttachDialog(shell);
+				dialog.setText(LayoutExample.getResourceString("Bottom_Attachment"));
+				dialog.setColumn(BOTTOM_COL);
+				String attach = dialog.open();
+				newItem.setText(BOTTOM_COL, attach);
+				if (newItem.getText(TOP_COL).endsWith(")"))
+					newItem.setText(TOP_COL, "");
+				resetEditors();
+			}));
+
+			for (int i = 0; i < table.getColumnCount(); i++) {
+				Rectangle rect = newItem.getBounds(i);
+				if (rect.contains(pt)) {
+					switch (i) {
+					case 0:
+						resetEditors();
+						break;
+					case COMBO_COL:
+						combo.setFocus();
+						break;
+					case WIDTH_COL:
+						widthText.setFocus();
+						break;
+					case HEIGHT_COL:
+						heightText.setFocus();
+						break;
+					default:
+						break;
+					}
+				}
+			}
+		}));
 	}
 
 	/**
@@ -304,11 +290,11 @@ class FormLayoutTab extends Tab {
 		spacing = new Spinner(marginGroup, SWT.BORDER);
 		spacing.setSelection(0);
 		spacing.addSelectionListener(selectionListener);
-		
+
 		/* Add common controls */
 		super.createControlWidgets ();
 	}
-	
+
 	/**
 	 * Creates the example layout.
 	 */
@@ -317,8 +303,8 @@ class FormLayoutTab extends Tab {
 		formLayout = new FormLayout ();
 		layoutComposite.setLayout (formLayout);
 	}
-	
-	/** 
+
+	/**
 	 * Disposes the editors without placing their contents
 	 * into the table.
 	 */
@@ -337,10 +323,10 @@ class FormLayoutTab extends Tab {
 
 	/**
 	 * Generates code for the example layout.
-	 */	
+	 */
 	@Override
-	StringBuffer generateLayoutCode () {
-		StringBuffer code = new StringBuffer ();
+	StringBuilder generateLayoutCode () {
+		StringBuilder code = new StringBuilder ();
 		code.append ("\t\tFormLayout formLayout = new FormLayout ();\n");
 		if (formLayout.marginWidth != 0) {
 			code.append ("\t\tformLayout.marginWidth = " + formLayout.marginWidth + ";\n");
@@ -364,7 +350,7 @@ class FormLayoutTab extends Tab {
 			code.append ("\t\tformLayout.spacing = " + formLayout.spacing + ";\n");
 		}
 		code.append ("\t\tshell.setLayout (formLayout);\n");
-		
+
 		boolean first = true;
 		for (int i = 0; i < children.length; i++) {
 			Control control = children [i];
@@ -376,7 +362,7 @@ class FormLayoutTab extends Tab {
 					code.append ("FormData ");
 					first = false;
 				}
-				code.append ("data = new FormData ();\n");	
+				code.append ("data = new FormData ();\n");
 				if (data.width != SWT.DEFAULT) {
 					code.append ("\t\tdata.width = " + data.width + ";\n");
 				}
@@ -387,7 +373,7 @@ class FormLayoutTab extends Tab {
 					if (data.left.control != null) {
 						TableItem item = table.getItem (i);
 						String controlString = item.getText (LEFT_COL);
-						int index = new Integer (controlString.substring (controlString.indexOf (',') - 1, controlString.indexOf (','))).intValue ();
+						int index = Integer.valueOf(controlString.substring (controlString.indexOf (',') - 1, controlString.indexOf (','))).intValue ();
 						code.append ("\t\tdata.left = new FormAttachment (" + names [index] + ", " + data.left.offset + ", SWT." + alignmentString (data.left.alignment) + ");\n");
 					} else {
 						if (data.right != null || (data.left.numerator != 0 ||data.left.offset != 0)) {
@@ -399,7 +385,7 @@ class FormLayoutTab extends Tab {
 					if (data.right.control != null) {
 						TableItem item = table.getItem (i);
 						String controlString = item.getText (RIGHT_COL);
-						int index = new Integer (controlString.substring (controlString.indexOf (',') - 1, controlString.indexOf (','))).intValue ();
+						int index = Integer.valueOf (controlString.substring (controlString.indexOf (',') - 1, controlString.indexOf (',')));
 						code.append ("\t\tdata.right = new FormAttachment (" + names [index] + ", " + data.right.offset + ", SWT." + alignmentString (data.right.alignment) + ");\n");
 					} else {
 						code.append ("\t\tdata.right = new FormAttachment (" + data.right.numerator + ", " + data.right.offset + ");\n");
@@ -409,7 +395,7 @@ class FormLayoutTab extends Tab {
 					if (data.top.control != null) {
 						TableItem item = table.getItem (i);
 						String controlString = item.getText (TOP_COL);
-						int index = new Integer (controlString.substring (controlString.indexOf (',') - 1, controlString.indexOf (','))).intValue ();
+						int index = Integer.valueOf(controlString.substring (controlString.indexOf (',') - 1, controlString.indexOf (',')));
 						code.append ("\t\tdata.top = new FormAttachment (" + names [index] + ", " + data.top.offset + ", SWT." + alignmentString (data.top.alignment) + ");\n");
 					} else {
 						if (data.bottom != null || (data.top.numerator != 0 ||data.top.offset != 0)) {
@@ -421,7 +407,7 @@ class FormLayoutTab extends Tab {
 					if (data.bottom.control != null) {
 						TableItem item = table.getItem (i);
 						String controlString = item.getText (BOTTOM_COL);
-						int index = new Integer (controlString.substring (controlString.indexOf (',') - 1, controlString.indexOf (','))).intValue ();
+						int index = Integer.valueOf(controlString.substring (controlString.indexOf (',') - 1, controlString.indexOf (',')));
 						code.append ("\t\tdata.bottom = new FormAttachment (" + names [index] + ", " + data.bottom.offset + ", SWT." + alignmentString (data.bottom.alignment) + ");\n");
 					} else {
 						code.append ("\t\tdata.bottom = new FormAttachment (" + data.bottom.numerator + ", " + data.bottom.offset + ");\n");
@@ -432,14 +418,14 @@ class FormLayoutTab extends Tab {
 		}
 		return code;
 	}
-	
+
 	/**
 	 * Returns the string to insert when a new child control is added to the table.
 	 */
 	@Override
 	String[] getInsertString (String name, String controlType) {
 		return new String [] {name, controlType, "-1", "-1",
-				"0,0 (" + LayoutExample.getResourceString ("Default") + ")", "", 
+				"0,0 (" + LayoutExample.getResourceString ("Default") + ")", "",
 				"0,0 (" + LayoutExample.getResourceString ("Default") + ")", ""};
 	}
 
@@ -450,16 +436,16 @@ class FormLayoutTab extends Tab {
 	String [] getLayoutDataFieldNames() {
 		return new String [] {
 			"Control Name",
-			"Control Type", 
-			"width", 
-			"height", 
-			"left", 
-			"right", 
-			"top", 
+			"Control Type",
+			"width",
+			"height",
+			"left",
+			"right",
+			"top",
 			"bottom"
 		};
 	}
-	
+
 	/**
 	 * Gets the text for the tab folder item.
 	 */
@@ -467,7 +453,7 @@ class FormLayoutTab extends Tab {
 	String getTabText () {
 		return "FormLayout";
 	}
-	
+
 	/**
 	 * Takes information from TableEditors and stores it.
 	 */
@@ -482,12 +468,12 @@ class FormLayoutTab extends Tab {
 				nameText.setText (oldItem.getText (NAME_COL));
 			}
 			try {
-				new Integer (widthText.getText ()).intValue ();
+				Integer.parseInt(widthText.getText ());
 			} catch (NumberFormatException e) {
 				widthText.setText (oldItem.getText (WIDTH_COL));
 			}
 			try {
-				Integer.valueOf(heightText.getText()).intValue();
+				Integer.parseInt(heightText.getText());
 			} catch(NumberFormatException e) {
 				heightText.setText (oldItem.getText(HEIGHT_COL));
 			}
@@ -504,14 +490,14 @@ class FormLayoutTab extends Tab {
 		layoutComposite.layout (true);
 		layoutGroup.layout (true);
 	}
-	
+
 	/**
 	 * Return the initial weight of the layout and control groups within the SashForm.
 	 * @return the desired sash weights for the tab page
 	 */
 	@Override
 	int[] sashWeights () {
-		return new int[] {40, 60};		
+		return new int[] {40, 60};
 	}
 
 	/**
@@ -531,11 +517,11 @@ class FormLayoutTab extends Tab {
 				i++;
 			}
 			String end = control.substring (i);
-			int index = new Integer (end).intValue ();
+			int index = Integer.valueOf(end).intValue ();
 			Control attachControl = children [index];
 			int colon = attachment.indexOf (':');
 			try {
-				offset = new Integer (attachment.substring (comma + 1, colon)).intValue ();
+				offset = Integer.valueOf(attachment.substring (comma + 1, colon)).intValue ();
 			} catch (NumberFormatException e) {
 				offset = 0;
 			}
@@ -544,19 +530,19 @@ class FormLayoutTab extends Tab {
 		} else {
 			/* Case where there is a position */
 			try {
-				position = new Integer (attachment.substring (0,comma)).intValue ();
+				position = Integer.valueOf(attachment.substring (0,comma));
 			} catch (NumberFormatException e) {
 				position = 0;
 			}
 			try {
-				offset = new Integer (attachment.substring (comma + 1)).intValue ();
+				offset = Integer.valueOf(attachment.substring (comma + 1));
 			} catch (NumberFormatException e) {
 				offset = 0;
 			}
-			return new FormAttachment (position, offset);		
+			return new FormAttachment (position, offset);
 		}
 	}
-	
+
 	/**
 	 * Sets the layout data for the children of the layout.
 	 */
@@ -568,12 +554,12 @@ class FormLayoutTab extends Tab {
 		int width, height;
 		String left, right, top, bottom;
 		for (int i = 0; i < children.length; i++) {
-			width = new Integer (items [i].getText (WIDTH_COL)).intValue ();
-			height = new Integer (items [i].getText (HEIGHT_COL)).intValue ();
+			width = Integer.valueOf(items [i].getText (WIDTH_COL)).intValue ();
+			height = Integer.valueOf(items [i].getText (HEIGHT_COL)).intValue ();
 			data = new FormData ();
 			if (width > 0) data.width = width;
 			if (height > 0) data.height = height;
-			
+
 			left = items [i].getText (LEFT_COL);
 			if (left.length () > 0) {
 				data.left = setAttachment (left);
@@ -609,22 +595,22 @@ class FormLayoutTab extends Tab {
 			children [i].setLayoutData (data);
 		}
 	}
-	
+
 	/**
 	 * Sets the state of the layout.
 	 */
 	@Override
 	void setLayoutState () {
 		/* Set the margins and spacing */
-		formLayout.marginWidth = marginWidth.getSelection ();		
-		formLayout.marginHeight = marginHeight.getSelection ();		
+		formLayout.marginWidth = marginWidth.getSelection ();
+		formLayout.marginHeight = marginHeight.getSelection ();
 		formLayout.marginLeft = marginLeft.getSelection ();
 		formLayout.marginRight = marginRight.getSelection ();
 		formLayout.marginTop = marginTop.getSelection ();
 		formLayout.marginBottom = marginBottom.getSelection ();
 		formLayout.spacing = spacing.getSelection ();
-	}	
-	
+	}
+
 	/**
 	 * <code>AttachDialog</code> is the class that creates a
 	 * dialog specific for this example. It creates a dialog
@@ -634,25 +620,25 @@ class FormLayoutTab extends Tab {
 		String result = "";
 		String controlInput, positionInput, alignmentInput, offsetInput;
 		int col = 0;
-		
+
 		public AttachDialog (Shell parent, int style) {
 			super (parent, style);
 		}
-		
+
 		public AttachDialog (Shell parent) {
 			this (parent, 0);
 		}
-		
+
 		public void setColumn (int col) {
 			this.col = col;
 		}
-	 
+
 		public String open () {
 			Shell parent = getParent ();
 			final Shell shell = new Shell (parent, SWT.DIALOG_TRIM | SWT.APPLICATION_MODAL);
 			shell.setText (getText ());
 			shell.setLayout (new GridLayout (3, true));
-			
+
 			/* Find out what was previously set as an attachment */
 			TableItem newItem = leftEditor.getItem ();
 			result = newItem.getText (col);
@@ -676,18 +662,18 @@ class FormLayoutTab extends Tab {
 					}
 				}
 			}
-			
+
 			/* Add position field */
 			final Button posButton = new Button (shell, SWT.RADIO);
 			posButton.setText (LayoutExample.getResourceString ("Position"));
-			posButton.setSelection (!isControl);			
+			posButton.setSelection (!isControl);
 			final Combo position = new Combo (shell, SWT.NONE);
 			position.setItems ("0","25","33","50","67","75","100");
 			position.setVisibleItemCount (7);
 			position.setText (oldPos);
-			position.setEnabled (!isControl);			
+			position.setEnabled (!isControl);
 			position.setLayoutData (new GridData (SWT.FILL, SWT.CENTER, true, false, 2, 1));
-			
+
 			/* Add control field */
 			final Button contButton = new Button (shell, SWT.RADIO);
 			contButton.setText (LayoutExample.getResourceString ("Control"));
@@ -706,7 +692,7 @@ class FormLayoutTab extends Tab {
 			else control.select (0);
 			control.setEnabled (isControl);
 			control.setLayoutData (new GridData (SWT.FILL, SWT.CENTER, true, false, 2, 1));
-			
+
 			/* Add alignment field */
 			new Label (shell, SWT.NONE).setText (LayoutExample.getResourceString ("Alignment"));
 			final Combo alignment = new Combo (shell, SWT.NONE);
@@ -721,81 +707,66 @@ class FormLayoutTab extends Tab {
 			alignment.setText ("SWT." + oldAlign);
 			alignment.setEnabled (isControl);
 			alignment.setLayoutData (new GridData (SWT.FILL, SWT.CENTER, true, false, 2, 1));
-			
+
 			/* Add offset field */
 			new Label (shell, SWT.NONE).setText (LayoutExample.getResourceString ("Offset"));
 			final Text offset = new Text (shell, SWT.SINGLE | SWT.BORDER);
 			offset.setText (oldOffset);
 			offset.setLayoutData (new GridData (SWT.FILL, SWT.CENTER, true, false, 2, 1));
-			
+
 			/* Add listeners for choosing between position and control */
-			posButton.addSelectionListener (new SelectionAdapter () {
-				@Override
-				public void widgetSelected (SelectionEvent e) {
-					position.setEnabled (true);
-					control.setEnabled (false);
-					alignment.setEnabled (false);
-				}
-			});
-			contButton.addSelectionListener (new SelectionAdapter () {
-				@Override
-				public void widgetSelected (SelectionEvent e) {
-					position.setEnabled (false);
-					control.setEnabled (true);
-					alignment.setEnabled (true);
-				}
-			});
-			
+			posButton.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> {
+				position.setEnabled(true);
+				control.setEnabled(false);
+				alignment.setEnabled(false);
+			}));
+			contButton.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> {
+				position.setEnabled(false);
+				control.setEnabled(true);
+				alignment.setEnabled(true);
+			}));
+
 			Button clear = new Button (shell, SWT.PUSH);
 			clear.setText (LayoutExample.getResourceString ("Clear"));
 			clear.setLayoutData (new GridData (SWT.END, SWT.CENTER, false, false));
-			clear.addSelectionListener (new SelectionAdapter () {
-				@Override
-				public void widgetSelected (SelectionEvent e) {
-					result = "";
-					shell.close ();
-				}
-			});
+			clear.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> {
+				result = "";
+				shell.close();
+			}));
 			/* OK button sets data into table */
 			Button ok = new Button (shell, SWT.PUSH);
 			ok.setText (LayoutExample.getResourceString ("OK"));
 			ok.setLayoutData (new GridData (SWT.CENTER, SWT.CENTER, false, false));
-			ok.addSelectionListener (new SelectionAdapter () {
-				@Override
-				public void widgetSelected (SelectionEvent e) {
-					controlInput = control.getText ();
-					alignmentInput = alignment.getText ().substring (4);
-					positionInput = position.getText ();
-					if (positionInput.length () == 0) positionInput = "0";
-					try {
-						new Integer (positionInput).intValue ();
-					} catch (NumberFormatException except) {
-						positionInput = "0";
-					}
-					offsetInput = offset.getText ();
-					if (offsetInput.length () == 0) offsetInput = "0";
-					try {
-						new Integer (offsetInput).intValue ();
-					} catch (NumberFormatException except) {
-						offsetInput = "0";
-					}
-					if (posButton.getSelection() || controlInput.length () == 0) {
-						result = positionInput + "," + offsetInput;
-					} else {
-						result = controlInput + "," + offsetInput + ":" + alignmentInput;
-					}
-					shell.close ();
+			ok.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> {
+				controlInput = control.getText();
+				alignmentInput = alignment.getText().substring(4);
+				positionInput = position.getText();
+				if (positionInput.length() == 0)
+					positionInput = "0";
+				try {
+					Integer.parseInt(positionInput);
+				} catch (NumberFormatException except) {
+					positionInput = "0";
 				}
-			});
+				offsetInput = offset.getText();
+				if (offsetInput.length() == 0)
+					offsetInput = "0";
+				try {
+					Integer.parseInt(offsetInput);
+				} catch (NumberFormatException except) {
+					offsetInput = "0";
+				}
+				if (posButton.getSelection() || controlInput.length() == 0) {
+					result = positionInput + "," + offsetInput;
+				} else {
+					result = controlInput + "," + offsetInput + ":" + alignmentInput;
+				}
+				shell.close();
+			}));
 			Button cancel = new Button (shell, SWT.PUSH);
 			cancel.setText (LayoutExample.getResourceString ("Cancel"));
-			cancel.addSelectionListener (new SelectionAdapter () {
-				@Override
-				public void widgetSelected (SelectionEvent e) {
-					shell.close ();
-				}
-			});
-			
+			cancel.addSelectionListener(SelectionListener.widgetSelectedAdapter(e -> shell.close()));
+
 			shell.setDefaultButton (ok);
 			shell.pack ();
 			/* Center the dialog */
@@ -807,7 +778,7 @@ class FormLayoutTab extends Tab {
 			while (!shell.isDisposed ()) {
 				if (display.readAndDispatch ()) display.sleep ();
 			}
-			
+
 			return result;
 		}
 	}
