@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,7 +11,8 @@
 package org.eclipse.swt.examples.paint;
 
 
-import java.io.IOException;
+import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
+
 import java.io.InputStream;
 import java.text.MessageFormat;
 import java.util.MissingResourceException;
@@ -20,8 +21,6 @@ import java.util.ResourceBundle;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.SWTException;
 import org.eclipse.swt.accessibility.AccessibleAdapter;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.FontData;
@@ -75,11 +74,11 @@ public class PaintExample {
 	static final int Dot_linestyle = 13;
 	static final int DashDot_linestyle = 14;
 	static final int Font_options = 15;
-	
+
 	static final int Default_tool = Pencil_tool;
 	static final int Default_fill = None_fill;
 	static final int Default_linestyle = Solid_linestyle;
-	
+
 	public static final Tool[] tools = {
 		new Tool(Pencil_tool, "Pencil", "tool", SWT.RADIO),
 		new Tool(Airbrush_tool, "Airbrush", "tool", SWT.RADIO),
@@ -102,7 +101,7 @@ public class PaintExample {
 	/**
 	 * Creates an instance of a PaintExample embedded inside
 	 * the supplied parent Composite.
-	 * 
+	 *
 	 * @param parent the container of the example
 	 */
 	public PaintExample(Composite parent) {
@@ -134,7 +133,7 @@ public class PaintExample {
 		}
 		instance.dispose();
 	}
-	
+
 	/**
 	 * Creates the toolbar.
 	 * Note: Only called by standalone.
@@ -163,12 +162,7 @@ public class PaintExample {
 		item.setText (getResourceString(id + ".label"));
 		item.setToolTipText(getResourceString(id + ".tooltip"));
 		item.setImage(tool.image);
-		item.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				tool.action.run();
-			}
-		});
+		item.addSelectionListener(widgetSelectedAdapter(e -> tool.action.run()));
 		final int childID = toolbar.indexOf(item);
 		toolbar.getAccessible().addAccessibleListener(new AccessibleAdapter() {
 			@Override
@@ -199,7 +193,7 @@ public class PaintExample {
 		GridLayout gridLayout;
 		GridData gridData;
 
-		/*** Create principal GUI layout elements ***/		
+		/*** Create principal GUI layout elements ***/
 		Composite displayArea = new Composite(parent, SWT.NONE);
 		gridLayout = new GridLayout();
 		gridLayout.numColumns = 1;
@@ -211,14 +205,14 @@ public class PaintExample {
 		// instantiate all of the non-GUI application elements to satisfy referential
 		// dependencies.  It is possible to reorder the initialization to some extent, but
 		// this can be very tedious.
-		
+
 		// paint canvas
 		final Canvas paintCanvas = new Canvas(displayArea, SWT.BORDER | SWT.V_SCROLL | SWT.H_SCROLL |
 			SWT.NO_REDRAW_RESIZE | SWT.NO_BACKGROUND);
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.FILL_VERTICAL);
 		paintCanvas.setLayoutData(gridData);
 		paintCanvas.setBackground(paintColorWhite);
-		
+
 		// color selector frame
 		final Composite colorFrame = new Composite(displayArea, SWT.NONE);
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_FILL);
@@ -234,7 +228,7 @@ public class PaintExample {
 		gridData = new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_FILL);
 		statusText.setLayoutData(gridData);
 
-		/*** Create the remaining application elements inside the principal GUI layout elements ***/	
+		/*** Create the remaining application elements inside the principal GUI layout elements ***/
 		// paintSurface
 		paintSurface = new PaintSurface(paintCanvas, statusText, paintColorWhite);
 
@@ -248,7 +242,7 @@ public class PaintExample {
 		tools[Ellipse_tool].data = new EllipseTool(toolSettings, paintSurface);
 		tools[Text_tool].data = new TextTool(toolSettings, paintSurface);
 
-		// colorFrame		
+		// colorFrame
 		gridLayout = new GridLayout();
 		gridLayout.numColumns = 3;
 		gridLayout.marginHeight = 0;
@@ -277,8 +271,8 @@ public class PaintExample {
 			@Override
 			public void handleEvent(Event e) {
 				Rectangle bounds = paletteCanvas.getClientArea();
-				Color color = getColorAt(bounds, e.x, e.y);				
-					
+				Color color = getColorAt(bounds, e.x, e.y);
+
 				if (e.button == 1) setForegroundColor(color);
 				else setBackgroundColor(color);
 			}
@@ -306,7 +300,7 @@ public class PaintExample {
 		paletteCanvas.addListener(SWT.Resize, refreshListener);
 		paletteCanvas.addListener(SWT.Paint, refreshListener);
 		//paletteCanvas.redraw();
-		
+
 		// toolSettingsFrame
 		gridLayout = new GridLayout();
 		gridLayout.numColumns = 4;
@@ -322,13 +316,10 @@ public class PaintExample {
 		airbrushRadiusScale.setMaximum(50);
 		airbrushRadiusScale.setSelection(toolSettings.airbrushRadius);
 		airbrushRadiusScale.setLayoutData(new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_FILL));
-		airbrushRadiusScale.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				toolSettings.airbrushRadius = airbrushRadiusScale.getSelection();
-				updateToolSettings();
-			}
-		});
+		airbrushRadiusScale.addSelectionListener(widgetSelectedAdapter(e -> {
+			toolSettings.airbrushRadius = airbrushRadiusScale.getSelection();
+			updateToolSettings();
+		}));
 
 		label = new Label(toolSettingsFrame, SWT.NONE);
 		label.setText(getResourceString("settings.AirbrushIntensity.text"));
@@ -338,24 +329,20 @@ public class PaintExample {
 		airbrushIntensityScale.setMaximum(100);
 		airbrushIntensityScale.setSelection(toolSettings.airbrushIntensity);
 		airbrushIntensityScale.setLayoutData(new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_FILL));
-		airbrushIntensityScale.addSelectionListener(new SelectionAdapter() {
-			@Override
-			public void widgetSelected(SelectionEvent e) {
-				toolSettings.airbrushIntensity = airbrushIntensityScale.getSelection();
-				updateToolSettings();
-			}
-		});
+		airbrushIntensityScale.addSelectionListener(widgetSelectedAdapter(e -> {
+			toolSettings.airbrushIntensity = airbrushIntensityScale.getSelection();
+			updateToolSettings();
+		}));
 	}
-		
+
 	/**
 	 * Disposes of all resources associated with a particular
 	 * instance of the PaintExample.
-	 */	
+	 */
 	public void dispose() {
-		if (paintSurface != null) paintSurface.dispose();		
+		if (paintSurface != null) paintSurface.dispose();
 		if (paintColors != null) {
-			for (int i = 0; i < paintColors.length; ++i) {
-				final Color color = paintColors[i];
+			for (final Color color : paintColors) {
 				if (color != null) color.dispose();
 			}
 		}
@@ -369,23 +356,22 @@ public class PaintExample {
 	 * Frees the resource bundle resources.
 	 */
 	public void freeResources() {
-		for (int i = 0; i < tools.length; ++i) {
-			Tool tool = tools[i];
+		for (Tool tool : tools) {
 			final Image image = tool.image;
 			if (image != null) image.dispose();
 			tool.image = null;
 		}
 	}
-	
+
 	/**
 	 * Returns the Display.
-	 * 
+	 *
 	 * @return the display we're using
 	 */
 	public Display getDisplay() {
 		return mainComposite.getDisplay();
 	}
-	
+
 	/**
 	 * Gets a string from the resource bundle.
 	 * We don't want to crash because of a missing String.
@@ -398,7 +384,7 @@ public class PaintExample {
 			return key;
 		} catch (NullPointerException e) {
 			return "!" + key + "!";
-		}			
+		}
 	}
 
 	/**
@@ -421,10 +407,10 @@ public class PaintExample {
 	 */
 	private void init() {
 		Display display = mainComposite.getDisplay();
-		
+
 		paintColorWhite = new Color(display, 255, 255, 255);
 		paintColorBlack = new Color(display, 0, 0, 0);
-		
+
 		paintDefaultFont = display.getSystemFont();
 
 		paintColors = new Color[numPaletteCols * numPaletteRows];
@@ -445,8 +431,8 @@ public class PaintExample {
 	 * Sets the action field of the tools
 	 */
 	private void initActions() {
-		for (int i = 0; i < tools.length; ++i) {
-			final Tool tool = tools[i];
+		for (Tool tool2 : tools) {
+			final Tool tool = tool2;
 			String group = tool.group;
 			if (group.equals("tool")) {
 				tool.action = () -> setPaintTool(tool.id);
@@ -486,17 +472,13 @@ public class PaintExample {
 		final Class<PaintExample> clazz = PaintExample.class;
 		if (resourceBundle != null) {
 			try {
-				for (int i = 0; i < tools.length; ++i) {
-					Tool tool = tools[i];
+				for (Tool tool2 : tools) {
+					Tool tool = tool2;
 					String id = tool.group + '.' + tool.name;
-					InputStream sourceStream = clazz.getResourceAsStream(getResourceString(id + ".image"));
-					ImageData source = new ImageData(sourceStream);
-					ImageData mask = source.getTransparencyMask();
-					tool.image = new Image(null, source, mask);
-					try {
-						sourceStream.close();
-					} catch (IOException e) {
-						e.printStackTrace();
+					try (InputStream sourceStream = clazz.getResourceAsStream(getResourceString(id + ".image"))) {
+						ImageData source = new ImageData(sourceStream);
+						ImageData mask = source.getTransparencyMask();
+						tool.image = new Image(null, source, mask);
 					}
 				}
 				return;
@@ -516,10 +498,10 @@ public class PaintExample {
 	public void setFocus() {
 		mainComposite.setFocus();
 	}
-	
+
 	/**
 	 * Sets the tool foreground color.
-	 * 
+	 *
 	 * @param color the new color to use
 	 */
 	public void setForegroundColor(Color color) {
@@ -531,7 +513,7 @@ public class PaintExample {
 
 	/**
 	 * Set the tool background color.
-	 * 
+	 *
 	 * @param color the new color to use
 	 */
 	public void setBackgroundColor(Color color) {
@@ -549,14 +531,14 @@ public class PaintExample {
 		paintSurface.setPaintSession(paintTool);
 		updateToolSettings();
 	}
-	
+
 	/**
 	 * Selects a filltype given its ID.
 	 */
 	public void setFillType(int id) {
 		Integer fillType = (Integer) tools[id].data;
 		toolSettings.commonFillType = fillType.intValue();
-		updateToolSettings();		
+		updateToolSettings();
 	}
 
 	/**
@@ -565,7 +547,7 @@ public class PaintExample {
 	public void setLineStyle(int id) {
 		Integer lineType = (Integer) tools[id].data;
 		toolSettings.commonLineStyle = lineType.intValue();
-		updateToolSettings();		
+		updateToolSettings();
 	}
 
 	/**
@@ -587,7 +569,7 @@ public class PaintExample {
 	private void updateToolSettings() {
 		final PaintTool activePaintTool = paintSurface.getPaintTool();
 		if (activePaintTool == null) return;
-		
+
 		activePaintTool.endSession();
 		activePaintTool.set(toolSettings);
 		activePaintTool.beginSession();
