@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -16,14 +16,14 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeTrue;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
-import org.eclipse.swt.events.SegmentEvent;
 import org.eclipse.swt.events.SegmentListener;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
+import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.widgets.Combo;
@@ -106,7 +106,7 @@ public void test_addLjava_lang_StringI() {
 	catch (IllegalArgumentException e) {
 	}
 	combo.removeAll();
-	
+
 	combo.add("fred", 0);
 	assertArrayEquals("fred", new String[]{"fred"}, combo.getItems());
 	combo.add("fred", 0);
@@ -114,7 +114,7 @@ public void test_addLjava_lang_StringI() {
 	combo.add("fred");
 	assertArrayEquals("fred fred fred", new String[]{"fred", "fred", "fred"}, combo.getItems());
 	combo.removeAll();
-	
+
 	int number = 3;
 	for (int i = 0; i < number; i++)
 		combo.add("fred" + i);
@@ -136,12 +136,7 @@ public void test_addLjava_lang_StringI() {
 @Test
 public void test_addModifyListenerLorg_eclipse_swt_events_ModifyListener() {
 	boolean exceptionThrown = false;
-	ModifyListener listener = new ModifyListener() {
-		@Override
-		public void modifyText(ModifyEvent event) {
-			listenerCalled = true;
-		}
-	};
+	ModifyListener listener = event -> listenerCalled = true;
 	try {
 		combo.addModifyListener(null);
 	}
@@ -150,11 +145,11 @@ public void test_addModifyListenerLorg_eclipse_swt_events_ModifyListener() {
 	}
 	assertTrue("Expected exception not thrown", exceptionThrown);
 	exceptionThrown = false;
-	
-	// test whether all content modifying API methods send a Modify event	
+
+	// test whether all content modifying API methods send a Modify event
 	combo.addModifyListener(listener);
 	listenerCalled = false;
-	combo.setText("new text");	
+	combo.setText("new text");
 	assertTrue("setText does not send event", listenerCalled);
 
 	if (SwtTestUtil.isCocoa) {
@@ -180,12 +175,12 @@ public void test_addModifyListenerLorg_eclipse_swt_events_ModifyListener() {
 		combo.remove(0, 1);
 		assertTrue("remove(int start, int end) for all items:", listenerCalled);
 	}
-	
-	listenerCalled = false;	
+
+	listenerCalled = false;
 	combo.removeModifyListener(listener);
-	// cause to call the listener. 
-	combo.setText("line");	
-	assertTrue("Listener not removed", listenerCalled == false);
+	// cause to call the listener.
+	combo.setText("line");
+	assertFalse("Listener not removed", listenerCalled);
 	try {
 		combo.removeModifyListener(null);
 	}
@@ -218,7 +213,7 @@ public void test_addSelectionListenerLorg_eclipse_swt_events_SelectionListener()
 	exceptionThrown = false;
 	combo.addSelectionListener(listener);
 	combo.select(0);
-	assertTrue(":a:", listenerCalled == false);
+	assertFalse(":a:", listenerCalled);
 	combo.removeSelectionListener(listener);
 	try {
 		combo.removeSelectionListener(null);
@@ -229,6 +224,21 @@ public void test_addSelectionListenerLorg_eclipse_swt_events_SelectionListener()
 	assertTrue("Expected exception not thrown", exceptionThrown);
 }
 
+@Test
+public void test_addSelectionListenerWidgetSelectedAdapterLorg_eclipse_swt_events_SelectionListener() {
+	listenerCalled = false;
+	SelectionListener listener = SelectionListener.widgetSelectedAdapter(e-> listenerCalled = true);
+
+	combo.addSelectionListener(listener);
+	combo.select(0);
+	assertFalse(":a:", listenerCalled);
+
+	combo.removeSelectionListener(listener);
+	listenerCalled = false;
+	combo.select(0);
+	assertFalse(listenerCalled);
+}
+
 @Test
 public void test_clearSelection() {
 	int number = 5;
@@ -304,7 +314,7 @@ public void test_deselectI() {
 	combo.deselect(10);
 	assertEquals(1, combo.getSelectionIndex());
 	combo.removeAll();
-	
+
 	combo.deselect(2);
 
 	int number = 10;
@@ -455,7 +465,7 @@ public void test_indexOfLjava_lang_String() {
 	catch (IllegalArgumentException e) {
 	}
 	combo.removeAll();
-	
+
 	int number = 5;
 	for (int i = 0; i < number; i++)
 		combo.add("fred" + i);
@@ -499,7 +509,7 @@ public void test_indexOfLjava_lang_StringI() {
 	}
 	assertEquals(-1, combo.indexOf("string0", -1));
 	combo.removeAll();
-	
+
 	int number = 5;
 	for (int i = 0; i < number; i++)
 		combo.add("fred" + i);
@@ -720,13 +730,13 @@ public void test_removeLjava_lang_String() {
 	combo.removeAll();
 	for (int i = 0; i < number; i++)
 		combo.add("fred" + i);
-	try {	
+	try {
 		combo.remove("fred");
 		fail("No exception thrown for item not found");
 	}
 	catch (IllegalArgumentException e) {
 	}
-	
+
 	assertEquals(number, combo.getItemCount());
 }
 
@@ -737,12 +747,180 @@ public void test_selectI() {
 	combo.add("789");
 	combo.select(1);
 	assertTrue(":a:", combo.getSelectionIndex()== 1);
-	
+
 	// indices out of range are ignored
 	combo.select(10);
 	assertEquals(1, combo.getSelectionIndex());
 }
 
+@Test
+public void test_setBackgroundDropDownCombo() {
+	Combo dropDown = new Combo(shell, SWT.DROP_DOWN);
+	Color color = new Color(dropDown.getDisplay(), 255, 0, 0);
+	dropDown.setBackground(color);
+	assertEquals("getBackground not equal after setBackground for SWT.DROP_DOWN Combo",
+			color, dropDown.getBackground());
+	dropDown.setBackground(null);
+	assertTrue("getBackground unchanged after setBackground(null) for SWT.DROP_DOWN Combo",
+			!dropDown.getBackground().equals(color));
+	color.dispose();
+	color = new Color(dropDown.getDisplay(), 255, 0, 0, 0);
+	dropDown.setBackground(color);
+	assertEquals("getBackground not equal after setBackground with 0 alpha for SWT.DROP_DOWN Combo",
+			color, dropDown.getBackground());
+	dropDown.setBackground(null);
+	assertTrue("getBackground unchanged after setBackground(null) with 0 alpha for SWT.DROP_DOWN Combo",
+			!dropDown.getBackground().equals(color));
+	if ("gtk".equals(SWT.getPlatform ())) {
+		Color fg = new Color(dropDown.getDisplay(), 0, 255, 0);
+		dropDown.setBackground(color);
+		dropDown.setForeground(fg);
+		assertEquals("Setting a foreground disrupted the background color for SWT.DROP_DOWN Combo",
+				color, dropDown.getBackground());
+		assertEquals("Setting a foreground onto an SWT.DROP_DOWN Combo with a background failed",
+				fg, dropDown.getForeground());
+		fg.dispose();
+	}
+	color.dispose();
+	dropDown.dispose();
+}
+
+@Test
+public void test_setBackgroundAlphaDropDownCombo() {
+	Combo dropDown = new Combo(shell, SWT.DROP_DOWN);
+	Color color = new Color (dropDown.getDisplay(), 255, 0, 0, 0);
+	dropDown.setBackground(color);
+	assertEquals(color, dropDown.getBackground());
+	Color fg = new Color(dropDown.getDisplay(), 0, 255, 0, 0);
+	dropDown.setForeground(fg);
+	assertEquals(color, dropDown.getBackground());
+	color.dispose();
+	fg.dispose();
+	dropDown.dispose();
+}
+
+@Test
+public void test_setBackgroundSimpleCombo() {
+	Combo simple = new Combo(shell, SWT.SIMPLE);
+	Color color = new Color(simple.getDisplay(), 255, 0, 0);
+	simple.setBackground(color);
+	assertEquals("getBackground not equal after setBackground for SWT.SIMPLE Combo",
+			color, simple.getBackground());
+	simple.setBackground(null);
+	assertTrue("getBackground unchanged after setBackground(null) for SWT.SIMPLE Combo",
+			!simple.getBackground().equals(color));
+	color.dispose();
+	color = new Color(simple.getDisplay(), 255, 0, 0, 0);
+	simple.setBackground(color);
+	assertEquals("getBackground not equal after setBackground with 0 alpha for SWT.SIMPLE Combo",
+			color, simple.getBackground());
+	simple.setBackground(null);
+	assertTrue("getBackground unchanged after setBackground(null) with 0 alpha for SWT.SIMPLE Combo",
+			!simple.getBackground().equals(color));
+	if ("gtk".equals(SWT.getPlatform ())) {
+		Color fg = new Color(simple.getDisplay(), 0, 255, 0);
+		simple.setBackground(color);
+		simple.setForeground(fg);
+		assertEquals("Setting a foreground disrupted the background color for SWT.SIMPLE Combo",
+				color, simple.getBackground());
+		assertEquals("Setting a foreground onto an SWT.SIMPLE Combo with a background failed",
+				fg, simple.getForeground());
+		fg.dispose();
+	}
+	color.dispose();
+	simple.dispose();
+}
+
+@Test
+public void test_setBackgroundAlphaSimpleCombo() {
+	Combo simple = new Combo(shell, SWT.SIMPLE);
+	Color color = new Color (simple.getDisplay(), 255, 0, 0, 0);
+	simple.setBackground(color);
+	assertEquals(color, simple.getBackground());
+	Color fg = new Color(simple.getDisplay(), 0, 255, 0, 0);
+	simple.setForeground(fg);
+	assertEquals(color, simple.getBackground());
+	color.dispose();
+	fg.dispose();
+	simple.dispose();
+}
+
+@Test
+public void test_setForegroundDropDownCombo() {
+	Combo dropDown = new Combo(shell, SWT.DROP_DOWN);
+	Color color = new Color(dropDown.getDisplay(), 255, 0, 0);
+	dropDown.setForeground(color);
+	assertEquals(color, dropDown.getForeground());
+	dropDown.setForeground(null);
+	assertFalse(dropDown.getForeground().equals(color));
+	if ("gtk".equals(SWT.getPlatform ())) {
+		Color bg = new Color(dropDown.getDisplay(), 0, 255, 0);
+		dropDown.setForeground(color);
+		dropDown.setBackground(bg);
+		assertEquals("Setting a background disrupted the foreground color for SWT.DROP_DOWN Combo",
+				color, dropDown.getForeground());
+		assertEquals("Setting a background onto an SWT.DROP_DOWN Combo with a foreground failed",
+				bg, dropDown.getBackground());
+		bg.dispose();
+	}
+	color.dispose();
+	dropDown.dispose();
+}
+
+@Test
+public void test_setForegroundAlphaDropDownCombo() {
+	Combo dropDown = new Combo(shell, SWT.DROP_DOWN);
+	assumeTrue("Alpha support for foreground colors does not exist on GTK2 or Win32",
+			SwtTestUtil.isCocoa || SwtTestUtil.isGTK3());
+	Color color = new Color (dropDown.getDisplay(), 255, 0, 0, 0);
+	dropDown.setForeground(color);
+	assertEquals(color, dropDown.getForeground());
+	Color bg = new Color(dropDown.getDisplay(), 0, 255, 0, 0);
+	dropDown.setBackground(bg);
+	assertEquals(color, dropDown.getForeground());
+	color.dispose();
+	bg.dispose();
+	dropDown.dispose();
+}
+
+@Test
+public void test_setForegroundSimpleCombo() {
+	Combo simple = new Combo(shell, SWT.SIMPLE);
+	Color color = new Color(simple.getDisplay(), 255, 0, 0);
+	simple.setForeground(color);
+	assertEquals(color, simple.getForeground());
+	simple.setForeground(null);
+	assertFalse(simple.getForeground().equals(color));
+	if ("gtk".equals(SWT.getPlatform ())) {
+		Color bg = new Color(simple.getDisplay(), 0, 255, 0);
+		simple.setForeground(color);
+		simple.setBackground(bg);
+		assertEquals("Setting a background disrupted the foreground color for SWT.SIMPLE Combo",
+				color, simple.getForeground());
+		assertEquals("Setting a background onto an SWT.SIMPLE Combo with a foreground failed",
+				bg, simple.getBackground());
+		bg.dispose();
+	}
+	color.dispose();
+	simple.dispose();
+}
+
+@Test
+public void test_setForegroundAlphaSimpleCombo() {
+	Combo simple = new Combo(shell, SWT.SIMPLE);
+	assumeTrue("Alpha support for foreground colors does not exist on GTK2 or Win32",
+			SwtTestUtil.isCocoa || SwtTestUtil.isGTK3());
+	Color color = new Color (simple.getDisplay(), 255, 0, 0, 0);
+	simple.setForeground(color);
+	assertEquals(color, simple.getForeground());
+	Color bg = new Color(simple.getDisplay(), 0, 255, 0, 0);
+	simple.setBackground(bg);
+	assertEquals(color, simple.getForeground());
+	color.dispose();
+	bg.dispose();
+	simple.dispose();
+}
+
 @Test
 public void test_setItemILjava_lang_String() {
 	try {
@@ -765,7 +943,7 @@ public void test_setItemILjava_lang_String() {
 	}
 	catch (IllegalArgumentException e) {
 	}
-	
+
 	combo.add("string0");
 	try {
 		combo.setItem(0, null);
@@ -780,9 +958,9 @@ public void test_setItemILjava_lang_String() {
 	}
 	catch (IllegalArgumentException e) {
 	}
-	
+
 	combo.add("joe");
-	combo.setItem(0, "fred");	
+	combo.setItem(0, "fred");
 	assertTrue("fred", combo.getItem(0).equals("fred"));
 
 	try {
@@ -835,7 +1013,7 @@ public void test_setSelectionLorg_eclipse_swt_graphics_Point() {
 	}
 	catch (IllegalArgumentException e) {
 	}
-	
+
 	int number = 5;
 	for (int i = 0; i < number; i++)
 		combo.add("fred" + i);
@@ -867,7 +1045,7 @@ public void test_setTextLjava_lang_String() {
 	}
 	catch (IllegalArgumentException e) {
 	}
-	
+
 	String[] cases = {"", "fred", "fred0"};
 	for (int i = 0; i < cases.length; i++) {
 		combo.setText(cases[i]);
@@ -950,7 +1128,7 @@ private void add() {
 public void test_consistency_MouseSelection () {
     add();
     consistencyPrePackShell();
-    consistencyEvent(combo.getSize().x-10, 5, 30, combo.getItemHeight()*2, 
+    consistencyEvent(combo.getSize().x-10, 5, 30, combo.getItemHeight()*2,
             		 ConsistencyUtility.SELECTION);
 }
 
@@ -992,18 +1170,15 @@ public void test_consistency_Segments () {
 		}
 		return;
 	}
-	final SegmentListener sl1 = new SegmentListener() {
-		@Override
-		public void getSegments(SegmentEvent event) {
-			if ((event.lineText.length() & 1) == 1) {
-				event.segments = new int [] {1, event.lineText.length()};
-				event.segmentsChars = null;
-			} else {
-				event.segments = new int [] {0, 0, event.lineText.length()};
-				event.segmentsChars = new char [] {':', '<', '>'};
-			}
-			listenerCalled = true;
+	final SegmentListener sl1 = event -> {
+		if ((event.lineText.length() & 1) == 1) {
+			event.segments = new int [] {1, event.lineText.length()};
+			event.segmentsChars = null;
+		} else {
+			event.segments = new int [] {0, 0, event.lineText.length()};
+			event.segmentsChars = new char [] {':', '<', '>'};
 		}
+		listenerCalled = true;
 	};
 	try {
 		combo.addSegmentListener(null);
@@ -1013,13 +1188,13 @@ public void test_consistency_Segments () {
 	}
 	combo.addSegmentListener(sl1);
 	doSegmentsTest(true);
-	
+
 	combo.addSegmentListener(sl1);
 	doSegmentsTest(true);
-	
+
 	combo.removeSegmentListener(sl1);
 	doSegmentsTest(true);
-	
+
 	combo.removeSegmentListener(sl1);
 	combo.setText(combo.getText());
 	doSegmentsTest(false);
@@ -1088,7 +1263,7 @@ private void doSegmentsTest (boolean isListening) {
 	combo.remove(1);
 	assertEquals(limit, combo.getTextLimit());
 	assertTrue(combo.getItemCount() == --count);
-	
+
 	combo.add(items[1], 1);
 	assertEquals(limit, combo.getTextLimit());
 	assertTrue(combo.getItemCount() == ++count);
@@ -1104,11 +1279,11 @@ private void doSegmentsTest (boolean isListening) {
 	combo.removeAll();
 	assertEquals(limit, combo.getTextLimit());
 	assertTrue(combo.getItemCount() == 0);
-	
+
 	combo.setItems(items);
 	count = items.length;
 	assertEquals(limit, combo.getTextLimit());
-	
+
 	combo.setTextLimit(Combo.LIMIT);
 	combo.setText(string);
 	assertEquals(string, combo.getText());
@@ -1122,7 +1297,7 @@ private void doSegmentsTest (boolean isListening) {
 	assertTrue(combo.getItemCount() == count);
 
 	combo.select(1);
-	
+
 	// Test remove item by name
 	combo.remove(items[1]);
 	assertEquals(--count, combo.getItemCount());
@@ -1151,7 +1326,7 @@ private void doSegmentsTest (boolean isListening) {
 	combo.paste();
 	assertEquals(isListening, listenerCalled);
 	listenerCalled = false;
-	
+
 	assertEquals(string.substring(0, pt.x) + substr + string.substring(pt.y), combo.getText());
 	pt.x = pt.y = pt.x + substr.length();
 	assertEquals(pt, combo.getSelection());
