@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,13 +12,16 @@ package org.eclipse.swt.tests.junit;
 
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeTrue;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.function.Consumer;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.accessibility.Accessible;
@@ -26,7 +29,6 @@ import org.eclipse.swt.events.ControlEvent;
 import org.eclipse.swt.events.ControlListener;
 import org.eclipse.swt.events.FocusEvent;
 import org.eclipse.swt.events.FocusListener;
-import org.eclipse.swt.events.HelpEvent;
 import org.eclipse.swt.events.HelpListener;
 import org.eclipse.swt.events.KeyEvent;
 import org.eclipse.swt.events.KeyListener;
@@ -34,9 +36,7 @@ import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.events.MouseListener;
 import org.eclipse.swt.events.MouseMoveListener;
 import org.eclipse.swt.events.MouseTrackListener;
-import org.eclipse.swt.events.PaintEvent;
 import org.eclipse.swt.events.PaintListener;
-import org.eclipse.swt.events.TraverseEvent;
 import org.eclipse.swt.events.TraverseListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Cursor;
@@ -89,6 +89,54 @@ public void test_addControlListenerLorg_eclipse_swt_events_ControlListener() {
 	control.removeControlListener(listener);
 }
 
+@Test
+public void test_addControlListenerControlMovedAdapterLorg_eclipse_swt_events_ControlListener() {
+	ControlListener listener = ControlListener.controlMovedAdapter(e -> eventOccurred = true);
+	control.addControlListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.Move, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.Resize, new Event());
+	assertFalse(eventOccurred);
+
+	control.removeControlListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.Move, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.Resize, new Event());
+	assertFalse(eventOccurred);
+}
+
+@Test
+public void test_addControlListenerControlResizedAdapterLorg_eclipse_swt_events_ControlListener() {
+	ControlListener listener = ControlListener.controlResizedAdapter(e -> eventOccurred = true);
+	control.addControlListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.Resize, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.Move, new Event());
+	assertFalse(eventOccurred);
+
+	control.removeControlListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.Resize, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.Move, new Event());
+	assertFalse(eventOccurred);
+}
+
 @Test
 public void test_addFocusListenerLorg_eclipse_swt_events_FocusListener() {
 	FocusListener listener = new FocusListener() {
@@ -111,14 +159,57 @@ public void test_addFocusListenerLorg_eclipse_swt_events_FocusListener() {
 	control.removeFocusListener(listener);
 }
 
+@Test
+public void test_addFocusListenerFocusGainedAdapterLorg_eclipse_swt_events_FocusListener() {
+	FocusListener listener = FocusListener.focusGainedAdapter(e -> eventOccurred = true);
+	control.addFocusListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.FocusIn, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.FocusOut, new Event());
+	assertFalse(eventOccurred);
+
+	control.removeFocusListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.FocusIn, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.FocusOut, new Event());
+	assertFalse(eventOccurred);
+}
+
+@Test
+public void test_addFocusListenerFocusLostAdapterLorg_eclipse_swt_events_FocusListener() {
+	FocusListener listener = FocusListener.focusLostAdapter(e -> eventOccurred = true);
+	control.addFocusListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.FocusOut, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.FocusIn, new Event());
+	assertFalse(eventOccurred);
+
+	control.removeFocusListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.FocusIn, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.FocusOut, new Event());
+	assertFalse(eventOccurred);
+}
+
 @Test
 public void test_addHelpListenerLorg_eclipse_swt_events_HelpListener() {
-	HelpListener listener = new HelpListener() {
-		@Override
-		public void helpRequested(HelpEvent e) {
-			eventOccurred = true;
-		}
-	};
+	HelpListener listener = e -> eventOccurred = true;
 	control.addHelpListener(listener);
 	eventOccurred = false;
 	control.notifyListeners(SWT.Help, new Event());
@@ -147,7 +238,36 @@ public void test_addKeyListenerLorg_eclipse_swt_events_KeyListener() {
 	assertTrue(eventOccurred);
 	control.removeKeyListener(listener);
 }
+@Test
+public void test_addKeyListenerKeyPressedAdapterLorg_eclipse_swt_events_KeyListener() {
+	KeyListener listener = KeyListener.keyPressedAdapter(event -> eventOccurred = true);
+	control.addKeyListener(listener);
+	eventOccurred = false;
 
+	control.notifyListeners(SWT.KeyDown, new Event());
+	assertTrue(eventOccurred);
+
+	control.removeKeyListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.KeyDown, new Event());
+	assertFalse(eventOccurred);
+}
+@Test
+public void test_addKeyListenerKeyReleasedAdapterLorg_eclipse_swt_events_KeyListener() {
+	KeyListener listener = KeyListener.keyReleasedAdapter(event -> eventOccurred = true);
+	control.addKeyListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.KeyUp, new Event());
+	assertTrue(eventOccurred);
+
+	control.removeKeyListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.KeyUp, new Event());
+	assertFalse(eventOccurred);
+}
 @Test
 public void test_addMouseListenerLorg_eclipse_swt_events_MouseListener() {
 	MouseListener listener = new MouseListener() {
@@ -179,12 +299,7 @@ public void test_addMouseListenerLorg_eclipse_swt_events_MouseListener() {
 
 @Test
 public void test_addMouseMoveListenerLorg_eclipse_swt_events_MouseMoveListener() {
-	MouseMoveListener listener = new MouseMoveListener() {
-		@Override
-		public void mouseMove(MouseEvent e) {
-			eventOccurred = true;
-		}
-	};
+	MouseMoveListener listener = e -> eventOccurred = true;
 	control.addMouseMoveListener(listener);
 	eventOccurred = false;
 	control.notifyListeners(SWT.MouseMove, new Event());
@@ -220,18 +335,110 @@ public void test_addMouseTrackListenerLorg_eclipse_swt_events_MouseTrackListener
 	assertTrue(eventOccurred);
 	control.removeMouseTrackListener(listener);
 }
+
+@Test
+public void test_addMouseTrackListenerMouseEnterAdapterLorg_eclipse_swt_events_MouseTrackListener() {
+	MouseTrackListener listener = MouseTrackListener.mouseEnterAdapter(e -> eventOccurred = true);
+	control.addMouseTrackListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseEnter, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseExit, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseHover, new Event());
+	assertFalse(eventOccurred);
+
+	control.removeMouseTrackListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseEnter, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.MouseExit, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.MouseHover, new Event());
+	assertFalse(eventOccurred);
+}
+
+@Test
+public void test_addMouseTrackListenerMouseExitAdapterLorg_eclipse_swt_events_MouseTrackListener() {
+	MouseTrackListener listener = MouseTrackListener.mouseExitAdapter(e -> eventOccurred = true);
+	control.addMouseTrackListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseExit, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseEnter, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseHover, new Event());
+	assertFalse(eventOccurred);
+
+	control.removeMouseTrackListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseExit, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.MouseEnter, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.MouseHover, new Event());
+	assertFalse(eventOccurred);
+}
+
+@Test
+public void test_addMouseTrackListenerMouseHoverAdapterLorg_eclipse_swt_events_MouseTrackListener() {
+	MouseTrackListener listener = MouseTrackListener.mouseHoverAdapter(e -> eventOccurred = true);
+	control.addMouseTrackListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseHover, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseEnter, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseExit, new Event());
+	assertFalse(eventOccurred);
+
+	control.removeMouseTrackListener(listener);
+	eventOccurred = false;
+
+	control.notifyListeners(SWT.MouseHover, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.MouseEnter, new Event());
+	assertFalse(eventOccurred);
+
+	control.notifyListeners(SWT.MouseExit, new Event());
+	assertFalse(eventOccurred);
+}
+
 @Test
 public void test_addPaintListenerLorg_eclipse_swt_events_PaintListener() {
-	PaintListener listener = new PaintListener() {
-		@Override
-		public void paintControl(PaintEvent e) {
-			eventOccurred = true;
-		}
-	};
+	PaintListener listener = e -> eventOccurred = true;
 	control.addPaintListener(listener);
 	eventOccurred = false;
 	Event event = new Event();
-	GC gc = event.gc = new GC(control);	
+	GC gc = event.gc = new GC(control);
 	control.notifyListeners(SWT.Paint, event);
 	gc.dispose();
 	assertTrue(eventOccurred);
@@ -239,12 +446,7 @@ public void test_addPaintListenerLorg_eclipse_swt_events_PaintListener() {
 }
 @Test
 public void test_addTraverseListenerLorg_eclipse_swt_events_TraverseListener() {
-	TraverseListener listener = new TraverseListener() {
-		@Override
-		public void keyTraversed(TraverseEvent e) {
-			eventOccurred = true;
-		}
-	};
+	TraverseListener listener = e -> eventOccurred = true;
 	control.addTraverseListener(listener);
 	eventOccurred = false;
 	control.notifyListeners(SWT.Traverse, new Event());
@@ -271,7 +473,7 @@ public void test_computeSizeIIZ() {
 @Test
 public void test_getAccessible() {
 	Accessible accessible = control.getAccessible();
-	assertTrue(":a:", accessible != null);
+	assertNotNull(":a:", accessible);
 }
 @Test
 public void test_getBorderWidth() {
@@ -312,11 +514,11 @@ public void test_isEnabled() {
 	assertTrue(control.isEnabled());
 
 	control.setEnabled(false);
-	assertTrue(!control.isEnabled());
+	assertFalse(control.isEnabled());
 }
 @Test
 public void test_isFocusControl() {
-	assertTrue(!control.isFocusControl());
+	assertFalse(control.isFocusControl());
 }
 @Test
 public void test_isReparentable() {
@@ -325,17 +527,17 @@ public void test_isReparentable() {
 @Test
 public void test_isVisible() {
 	control.setVisible(true);
-	assertTrue(!control.isVisible());  //because the shell is not visible
+	assertFalse(control.isVisible());  //because the shell is not visible
 
 	control.setVisible(false);
-	assertTrue(!control.isVisible());
+	assertFalse(control.isVisible());
 
 	if (!SwtTestUtil.isAIX) {
 		control.setVisible(true);
 		shell.setVisible(true);
 		assertTrue("Window should be visible", control.isVisible());
 		shell.setVisible(false);
-		assertTrue("Window should not be visible", !control.isVisible());
+		assertFalse("Window should not be visible", control.isVisible());
 	}
 }
 @Test
@@ -393,20 +595,36 @@ public void test_requestLayoutL() {
 public void test_setBackgroundLorg_eclipse_swt_graphics_Color() {
 	Color color = new Color(control.getDisplay(), 255, 0, 0);
 	control.setBackground(color);
-	assertEquals("getBackground not equal color after setBackground(color)", color, control.getBackground());
+	assertEquals("getBackground not equal color after setBackground(color) for " + control, color, control.getBackground());
 	control.setBackground(null);
-	assertTrue("getBackground unchanged after setBackground(null)", !control.getBackground().equals(color));
+	assertTrue("getBackground unchanged after setBackground(null) for " + control, !control.getBackground().equals(color));
 	color.dispose();
-	// Skipping test run for GTK, already failing on GTK3. May be related to bug 421836
-	if (!"gtk".equals(SWT.getPlatform ())) {
-		// With alpha zero
-		color = new Color(control.getDisplay(), 255, 0, 0, 0);
+	color = new Color(control.getDisplay(), 255, 0, 0, 0);
+	control.setBackground(color);
+	assertEquals("getBackground not equal color after setBackground(color) with 0 alpha for " + control + " " + control.getBackground(), color, control.getBackground());
+	control.setBackground(null);
+	assertTrue("getBackground unchanged after setBackground(null) alpha for " + control + " " + control.getBackground() + " " + control, !control.getBackground().equals(color));
+	if ("gtk".equals(SWT.getPlatform ())) {
+		Color fg = new Color(control.getDisplay(), 0, 255, 0);
 		control.setBackground(color);
-		assertEquals("getBackground not equal color after setBackground(color) with 0 alpha", color, control.getBackground());
-		control.setBackground(null);
-		assertTrue("getBackground unchanged after setBackground(null)", !control.getBackground().equals(color));
-		color.dispose();
+		control.setForeground(fg);
+		assertEquals("Setting a foreground disrupted the background color for " + control,
+				color, control.getBackground());
+		assertEquals("Setting a foreground onto a widget with a background failed for " + control,
+				fg, control.getForeground());
 	}
+	color.dispose();
+}
+@Test
+public void test_setBackgroundAlphaLorg_eclipse_swt_graphics_Color() {
+	Color color = new Color (control.getDisplay(), 255, 0, 0, 0);
+	control.setBackground(color);
+	assertEquals(color, control.getBackground());
+	Color fg = new Color(control.getDisplay(), 0, 255, 0, 0);
+	control.setForeground(fg);
+	assertEquals(color, control.getBackground());
+	color.dispose();
+	fg.dispose();
 }
 @Test
 public void test_setBoundsIIII() {
@@ -455,7 +673,7 @@ public void test_setEnabledZ() {
 	assertTrue(control.getEnabled());
 
 	control.setEnabled(false);
-	assertTrue(!control.getEnabled());
+	assertFalse(control.getEnabled());
 }
 @Test
 public void test_setTextDirection() {
@@ -489,7 +707,7 @@ public void test_setFontLorg_eclipse_swt_graphics_Font() {
 	Font font = control.getFont();
 	control.setFont(font);
 	assertEquals(font, control.getFont());
-	
+
 	font = new Font(control.getDisplay(), SwtTestUtil.testFontName, 10, SWT.NORMAL);
 	control.setFont(font);
 	assertEquals(font, control.getFont());
@@ -509,9 +727,32 @@ public void test_setForegroundLorg_eclipse_swt_graphics_Color() {
 	control.setForeground(color);
 	assertEquals(color, control.getForeground());
 	control.setForeground(null);
-	assertTrue(!control.getForeground().equals(color));
+	assertFalse(control.getForeground().equals(color));
+	if ("gtk".equals(SWT.getPlatform ())) {
+		Color bg = new Color(control.getDisplay(), 0, 255, 0);
+		control.setForeground(color);
+		control.setBackground(bg);
+		assertEquals("Setting a background disrupted the foreground color for " + control,
+				color, control.getForeground());
+		assertEquals("Setting a background onto a widget with a foreground failed for " + control,
+				bg, control.getBackground());
+	}
 	color.dispose();
 }
+@Test
+public void test_setForegroundAlphaLorg_eclipse_swt_graphics_Color() {
+	assumeTrue("Alpha support for foreground colors does not exist on GTK2 or Win32",
+			SwtTestUtil.isCocoa || SwtTestUtil.isGTK3());
+	Color color = new Color (control.getDisplay(), 255, 0, 0, 0);
+	control.setForeground(color);
+	assertEquals(color, control.getForeground());
+	Color bg = new Color(control.getDisplay(), 0, 255, 0, 0);
+	control.setBackground(bg);
+	assertEquals(color, control.getForeground());
+	color.dispose();
+	bg.dispose();
+}
+
 @Test
 public void test_setLayoutDataLjava_lang_Object() {
 	control.setLayoutData(this);
@@ -578,7 +819,7 @@ public void test_setParentLorg_eclipse_swt_widgets_Composite() {
 		Button b = new Button(originalParent, SWT.PUSH);
 		b.setParent(newParent);
 		originalParent.dispose();
-		assertTrue(!b.isDisposed());
+		assertFalse(b.isDisposed());
 		newParent.dispose();
 	}
 }
@@ -599,7 +840,7 @@ public void test_setSizeII() {
 	assertEquals(new Point(32, 43), control.getSize());
 
 	control.setSize(0, 0);
-	
+
 	control.setSize(10, 10);
 
 	control.setSize(10000, 10000);
@@ -619,7 +860,7 @@ public void test_setSizeLorg_eclipse_swt_graphics_Point() {
 	}
 
 	control.setSize(new Point(0, 0));
-	
+
 	control.setSize(new Point(10, 10));
 
 	control.setSize(new Point(10000, 10000));
@@ -640,7 +881,7 @@ public void test_setVisibleZ() {
 	assertTrue(control.getVisible());
 
 	control.setVisible(false);
-	assertTrue(!control.getVisible());
+	assertFalse(control.getVisible());
 }
 @Test
 public void test_toControlII() {
@@ -698,10 +939,10 @@ protected void setWidget(Widget w) {
 	super.setWidget(w);
 }
 
-/* a different method in ConsistencyUtility is invoked depending on what method 
+/* a different method in ConsistencyUtility is invoked depending on what method
  * equals
  * ConsistencyUtility.MOUSE_CLICK:
- * 			paramA is the x coordinate offset from control 				  
+ * 			paramA is the x coordinate offset from control
  * 			paramB is the y coordinate offset from control
  * 			paramC is the mouse button to click.
  * 			paramD if it equals ConsistencyUtility.ESCAPE_MENU, then another click
@@ -709,7 +950,7 @@ protected void setWidget(Widget w) {
  * 			(ie right clicking in a text widget)
  * 			invokes ConsistencyUtility.postClick(Display, Point, int)
  * ConsistencyUtility.MOUSE_DOUBLECLICK
- * 			paramA is the x coordinate offset from control 				  
+ * 			paramA is the x coordinate offset from control
  * 			paramB is the y coordinate offset from control
  * 			paramC is the mouse button to click.
  * 			invokes ConsistencyUtility.postDoubleClick(Display, Point, int)
@@ -719,16 +960,16 @@ protected void setWidget(Widget w) {
  * 			paramC is the x coordinate offset from control of the destination of drag
  * 			paramD is the y coordinate offset from control of the destination of drag
  * 			invokes ConsistencyUtility.postDrag(Display, Point, Point)
- * ConsistencyUtility.KEY_PRESS:  
+ * ConsistencyUtility.KEY_PRESS:
  * 		 	paramA is the character to press
- * 			paramB is the keyCode 
+ * 			paramB is the keyCode
  * 			invokes ConsistencyUtility.postKeyPress(Display, int, int)
- * ConsistencyUtility.DOUBLE_KEY_PRESS:  
+ * ConsistencyUtility.DOUBLE_KEY_PRESS:
  * 		 	paramA is the character to press and hold
- * 			paramB is the keyCode 
+ * 			paramB is the keyCode
  * 			paramC is the second key to press while the first one is held (ie ctrl-a)
  * 			paramD is the second keycode
- * 			invokes ConsistencyUtility.postDoubleKeyPress(Display, int, int, int, int) 
+ * 			invokes ConsistencyUtility.postDoubleKeyPress(Display, int, int, int, int)
  * ConsistencyUtility.SELECTION:
  * 			paramA is the x coordinate offset from control of the first click
  * 			paramB is the y coordinate offset from control of the first click
@@ -739,15 +980,15 @@ protected void setWidget(Widget w) {
  * 			paramA is the button to click with
  * 			invokes ConsistencyUtility.postShellIconify(Display, Point, int)
  */
-protected void consistencyEvent(final int paramA, final int paramB, 
+protected void consistencyEvent(final int paramA, final int paramB,
         						final int paramC, final int paramD,
         						final int method, List<String> events, boolean focus) {
     if(SwtTestUtil.fTestConsistency) {
         final Display display = shell.getDisplay();
-        if(events == null) 
+        if(events == null)
             events = new ArrayList<>();
         final String test = getTestName();
-        
+
         shell.setLayout(new org.eclipse.swt.layout.FillLayout());
         shell.setText("Parent");
 
@@ -767,19 +1008,19 @@ protected void consistencyEvent(final int paramA, final int paramB,
                 display.wake();
                 switch(method) {
                 	case ConsistencyUtility.MOUSE_CLICK:
-                		Assert.assertTrue(test, 
+                		Assert.assertTrue(test,
                             ConsistencyUtility.postClick(display, pt[0], paramC));
                 		if(paramD == ConsistencyUtility.ESCAPE_MENU) {
-                		    Assert.assertTrue(test, 
+                		    Assert.assertTrue(test,
 	                            ConsistencyUtility.postClick(display, pt[1], 1));
-                		}  
+                		}
                 		break;
                     case ConsistencyUtility.MOUSE_DOUBLECLICK:
-                        Assert.assertTrue(test, 
+                        Assert.assertTrue(test,
                                 ConsistencyUtility.postDoubleClick(display, pt[0], paramC));
                     	break;
                     case ConsistencyUtility.KEY_PRESS:
-                        Assert.assertTrue(test, 
+                        Assert.assertTrue(test,
                             ConsistencyUtility.postKeyPress(display, paramA, paramB));
                     	break;
                     case ConsistencyUtility.DOUBLE_KEY_PRESS:
@@ -787,14 +1028,14 @@ protected void consistencyEvent(final int paramA, final int paramB,
                             ConsistencyUtility.postDoubleKeyPress(display, paramA, paramB, paramC, paramD));
                     	break;
                     case ConsistencyUtility.MOUSE_DRAG:
-                        Assert.assertTrue(test, 
-                            ConsistencyUtility.postDrag(display, 
+                        Assert.assertTrue(test,
+                            ConsistencyUtility.postDrag(display,
                                     pt[0], pt[1]));
                         break;
                     case ConsistencyUtility.SELECTION:
 
-                        Assert.assertTrue(test, 
-                            ConsistencyUtility.postSelection(display, 
+                        Assert.assertTrue(test,
+                            ConsistencyUtility.postSelection(display,
                                     pt[0], pt[1]));
                         break;
                     case ConsistencyUtility.SHELL_ICONIFY:
@@ -822,20 +1063,20 @@ protected void consistencyEvent(final int paramA, final int paramB,
         while(!shell.isDisposed()) {
             if(!display.readAndDispatch()) display.sleep();
         }
-        setUp();        
+        setUp();
         String[] results = new String[events.size()];
         results = events.toArray(results);
         assertArrayEquals(test + " event ordering", expectedEvents, results);
     }
 }
 
-protected void consistencyEvent(int paramA, int paramB, 
+protected void consistencyEvent(int paramA, int paramB,
 								int paramC, int paramD,
 								int method, List<String> events) {
     consistencyEvent(paramA, paramB, paramC, paramD, method, events, true);
 }
 
-protected void consistencyEvent(int paramA, int paramB, 
+protected void consistencyEvent(int paramA, int paramB,
 								int paramC, int paramD,
 								int method) {
     consistencyEvent(paramA, paramB, paramC, paramD, method, null, true);
@@ -857,7 +1098,7 @@ protected Point[] determineLocations(int paramA, int paramB,
     Point[] array = new Point[2];
     if(method >= ConsistencyUtility.MOUSE_CLICK)
         array[0] = control.toDisplay(paramA, paramB);
-    if(method >= ConsistencyUtility.MOUSE_DRAG) 
+    if(method >= ConsistencyUtility.MOUSE_DRAG)
         array[1] = control.toDisplay(paramC, paramD);
     if(method == ConsistencyUtility.MOUSE_CLICK && paramD == ConsistencyUtility.ESCAPE_MENU)
         array[1] = shell.toDisplay(25, -10);
@@ -868,4 +1109,43 @@ protected Point[] determineLocations(int paramA, int paramB,
     return array;
 }
 
+@Test
+public void test_ExceptionsThrownInDisposeListenerDontPreventDisposal () {
+	disposedIntentionally = true;
+	Consumer<RuntimeException> oldHandler = Display.getCurrent ().getRuntimeExceptionHandler ();
+	try {
+		final List<RuntimeException> handledExceptions = new ArrayList<> ();
+		// Register an exception handler similar to the one used by the workbench, which doesn't
+		// propogate exceptions
+		Display.getCurrent ().setRuntimeExceptionHandler (exception -> {
+				handledExceptions.add(exception);
+		});
+		final int[] listenerInvocations = new int[1];
+
+		control.addDisposeListener (e -> {
+				listenerInvocations[0]++;
+		});
+
+		control.addDisposeListener (e -> {
+				throw new RuntimeException("Test exception handling");
+		});
+
+		control.addDisposeListener (e -> {
+				listenerInvocations[0]++;
+		});
+
+		try {
+			control.dispose ();
+		} catch (RuntimeException e) {
+			fail("The exception in the listener should have been logged, not passed along to the caller");
+		}
+
+		assertTrue (control.isDisposed ());
+		assertEquals (2, listenerInvocations[0]);
+		assertEquals (1, handledExceptions.size ());
+	} finally {
+		Display.getCurrent ().setRuntimeExceptionHandler (oldHandler);
+	}
+}
+
 }
