@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -20,6 +20,8 @@ import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
+import java.util.concurrent.atomic.AtomicBoolean;
+
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.DeviceData;
 import org.eclipse.swt.graphics.Font;
@@ -34,7 +36,10 @@ import org.eclipse.swt.widgets.Listener;
 import org.eclipse.swt.widgets.Monitor;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Synchronizer;
+import org.eclipse.test.Screenshots;
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.TestName;
 
 /**
  * Automated Test Suite for class org.eclipse.swt.widgets.Display
@@ -43,7 +48,14 @@ import org.junit.Test;
  */
 public class Test_org_eclipse_swt_widgets_Display {
 
-private static final boolean BUG_492569 = SwtTestUtil.isCocoa || SwtTestUtil.isGTK;
+private static boolean isRunningOnEclipseOrgHudson =
+		"hudsonbuild".equalsIgnoreCase(System.getProperty("user.name"))
+		|| "genie.platform".equalsIgnoreCase(System.getProperty("user.name"));
+
+private static final boolean BUG_492569 = SwtTestUtil.isWindows && isRunningOnEclipseOrgHudson;
+
+@Rule
+public TestName testName = new TestName();
 
 @Test
 public void test_Constructor() {
@@ -60,7 +72,7 @@ public void test_ConstructorLorg_eclipse_swt_graphics_DeviceData() {
 	Display disp;
 	disp = new Display(null);
 	disp.dispose();
-	
+
 	disp = new Display(new DeviceData());
 	disp.dispose();
 }
@@ -70,17 +82,14 @@ public void test_addFilterILorg_eclipse_swt_widgets_Listener() {
 	final int CLOSE_CALLBACK = 0;
 	final int DISPOSE_CALLBACK = 1;
 	final boolean[] callbackReceived = new boolean[] {false, false};
-	
-	Listener listener = new Listener() {
-		@Override
-		public void handleEvent(Event e) {
-			if (e.type == SWT.Close)
-				callbackReceived[CLOSE_CALLBACK] = true;
-			else if (e.type == SWT.Dispose)
-				callbackReceived[DISPOSE_CALLBACK] = true;
-		}
+
+	Listener listener = e -> {
+		if (e.type == SWT.Close)
+			callbackReceived[CLOSE_CALLBACK] = true;
+		else if (e.type == SWT.Dispose)
+			callbackReceived[DISPOSE_CALLBACK] = true;
 	};
-	
+
 	Display display = new Display();
 	try {
 		try {
@@ -89,7 +98,7 @@ public void test_addFilterILorg_eclipse_swt_widgets_Listener() {
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for addFilter with null argument", SWT.ERROR_NULL_ARGUMENT, e);
 		}
-		
+
 		display.addFilter(SWT.Close, listener);
 	} finally {
 		display.close();
@@ -103,17 +112,14 @@ public void test_addListenerILorg_eclipse_swt_widgets_Listener() {
 	final int CLOSE_CALLBACK = 0;
 	final int DISPOSE_CALLBACK = 1;
 	final boolean[] callbackReceived = new boolean[] {false, false};
-	
-	Listener listener = new Listener() {
-		@Override
-		public void handleEvent(Event e) {
-			if (e.type == SWT.Close)
-				callbackReceived[CLOSE_CALLBACK] = true;
-			else if (e.type == SWT.Dispose)
-				callbackReceived[DISPOSE_CALLBACK] = true;
-		}
+
+	Listener listener = e -> {
+		if (e.type == SWT.Close)
+			callbackReceived[CLOSE_CALLBACK] = true;
+		else if (e.type == SWT.Dispose)
+			callbackReceived[DISPOSE_CALLBACK] = true;
 	};
-	
+
 	Display display = new Display();
 	try {
 		try {
@@ -122,7 +128,7 @@ public void test_addListenerILorg_eclipse_swt_widgets_Listener() {
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for addListener with null argument", SWT.ERROR_NULL_ARGUMENT, e);
 		}
-		
+
 		display.addListener(SWT.Dispose, listener);
 	} finally {
 		display.close();
@@ -143,12 +149,7 @@ public void test_addListenerILorg_eclipse_swt_widgets_Listener() {
 public void test_asyncExecLjava_lang_Runnable() {
 	final Display display = new Display();
 	try {
-		display.asyncExec(new Runnable() {
-			@Override
-			public void run() {
-				display.beep();
-			}
-		});
+		display.asyncExec(() -> display.beep());
 	} finally {
 		display.dispose();
 	}
@@ -159,12 +160,9 @@ public void test_asyncExecLjava_lang_Runnable_dispose() {
 	final Display display = new Display();
 	try {
 		disposeExecRan = false;
-		display.asyncExec(new Runnable() {
-			@Override
-			public void run() {
-				display.dispose();
-				disposeExecRan = true;
-			}
+		display.asyncExec(() -> {
+			display.dispose();
+			disposeExecRan = true;
 		});
 	} finally {
 		while (!disposeExecRan) {
@@ -195,12 +193,7 @@ public void test_disposeExecLjava_lang_Runnable() {
 	// Also tests dispose and isDisposed
 	Display testDisplay = new Display();
 	disposeExecRan = false;
-	testDisplay.disposeExec(new Runnable() {
-		@Override
-		public void run() {
-			disposeExecRan = true;
-		}
-	});
+	testDisplay.disposeExec(() -> disposeExecRan = true);
 	assertEquals("Display should not be disposed", false, testDisplay.isDisposed());
 	testDisplay.dispose();
 	assertTrue("Display should be disposed", testDisplay.isDisposed());
@@ -210,7 +203,7 @@ public void test_disposeExecLjava_lang_Runnable() {
 @Test
 public void test_findDisplayLjava_lang_Thread() {
 	assertNull(Display.findDisplay(new Thread()));
-	
+
 	Display display = new Display();
 	try {
 		assertEquals(display, Display.findDisplay(Thread.currentThread()));
@@ -221,18 +214,12 @@ public void test_findDisplayLjava_lang_Thread() {
 
 @Test
 public void test_getActiveShell() {
-	if (SwtTestUtil.isGTK) {
-		//TODO Fix GTK failure.
-		if (SwtTestUtil.verbose) {
-			System.out.println("Excluded test_getActiveShell(org.eclipse.swt.tests.junit.Test_org_eclipse_swt_widgets_Display)");
-		}
-		return;
-	}
 	Display display = new Display();
 	try {
 		Shell shell = new Shell(display);
 		shell.setText("test_getActiveShell");
 		shell.open();
+		drainEventQueue(display, 150); // workaround for https://bugs.eclipse.org/506680
 		assertSame(shell, display.getActiveShell());
 		shell.dispose();
 	} finally {
@@ -240,6 +227,24 @@ public void test_getActiveShell() {
 	}
 }
 
+private static void drainEventQueue(Display display, int millis) {
+	if (millis == 0) {
+		while (!display.isDisposed() && display.readAndDispatch()) {
+		}
+		return;
+	}
+	long end = System.currentTimeMillis() + millis;
+	while (!display.isDisposed() && System.currentTimeMillis() < end) {
+		if (!display.readAndDispatch ()) {
+			try {
+				Thread.sleep(10);
+			} catch (InterruptedException e) {
+				e.printStackTrace();
+			}
+		}
+	}
+}
+
 @Test
 public void test_getBounds() {
 	Display display = new Display();
@@ -356,7 +361,7 @@ public void test_getMonitors() {
 	assertNotNull(monitors);
 	assertTrue("at least one monitor should be returned", monitors.length >= 1);
 	for (int i = 0; i < monitors.length; i++)
-		assertTrue("monitor at index "+i+" should not be null", monitors[i] != null);
+		assertNotNull("monitor at index "+i+" should not be null", monitors[i]);
 	display.dispose();
 }
 
@@ -400,45 +405,34 @@ public void test_getSyncThread() {
 	final Display display = new Display();
 	try {
 		final boolean[] threadRan = new boolean[] {false};
-		Thread nonUIThread = new Thread(new Runnable() {
-			@Override
-			public void run() {
-				// Assume no syncExec runnable is currently being invoked.
+		Thread nonUIThread = new Thread(() -> {
+			// Assume no syncExec runnable is currently being invoked.
+			assertNull(display.getSyncThread());
+
+			// Create a runnable and invoke with syncExec to verify that
+			// the invoking thread is the syncThread.
+			final Thread invokingThread = Thread.currentThread();
+			display.syncExec(() -> assertEquals(invokingThread, display.getSyncThread()));
+
+			// Create a runnable and invoke with asyncExec to verify that
+			// the syncThread is null while it's running.
+			AtomicBoolean asyncExecRan = new AtomicBoolean(false);
+			display.asyncExec(() -> {
 				assertNull(display.getSyncThread());
-				
-				// Create a runnable and invoke with syncExec to verify that
-				// the invoking thread is the syncThread.
-				final Thread invokingThread = Thread.currentThread();
-				display.syncExec(new Runnable() {
-					@Override
-					public void run() {
-						assertEquals(invokingThread, display.getSyncThread());
-					}
-				});
-				
-				// Create a runnable and invoke with asyncExec to verify that
-				// the syncThread is null while it's running.
-				final boolean[] asyncExecRan = new boolean[] {false};
-				display.asyncExec(new Runnable() {
-					@Override
-					public void run() {
-						assertNull(display.getSyncThread());
-						asyncExecRan[0] = true;
-					}
-				});
-				
-				try {
-					while (!asyncExecRan[0]) {
-						Thread.sleep(100);
-					}
-				} catch (InterruptedException ex) {
+				asyncExecRan.set(true);
+			});
+
+			try {
+				while (!asyncExecRan.get()) {
+					Thread.sleep(100);
 				}
-				threadRan[0] = true;
-				display.wake();
+			} catch (InterruptedException ex) {
 			}
+			threadRan[0] = true;
+			display.wake();
 		});
 		nonUIThread.start();
-		
+
 		while (!threadRan[0]) {
 			if (!display.readAndDispatch()) display.sleep ();
 		}
@@ -499,31 +493,31 @@ public void test_mapLorg_eclipse_swt_widgets_ControlLorg_eclipse_swt_widgets_Con
 		button2.setBounds(200,100,100,100);
 		shell.setBounds(0,0,400,400);
 		shell.open();
-		
+
 		Point shellOffset = shell.getLocation();
 		Point result;
-		
+
 		result = display.map(button1, button2, 0, 0);
 		assertEquals(new Point(-200,-100), result);
 		result = display.map(button1, button2, -10, -20);
 		assertEquals(new Point(-210,-120), result);
 		result = display.map(button1, button2, 30, 40);
 		assertEquals(new Point(-170,-60), result);
-		
+
 		result = display.map(button2, button1, 0, 0);
 		assertEquals(new Point(200,100), result);
 		result = display.map(button2, button1, -5, -15);
 		assertEquals(new Point(195,85), result);
 		result = display.map(button2, button1, 25, 35);
 		assertEquals(new Point(225,135), result);
-		
+
 		result = display.map(null, button2, 0, 0);
 		assertEquals(new Point(-200 - shellOffset.x,-100 - shellOffset.y), result);
 		result = display.map(null, button2, -2, -4);
 		assertEquals(new Point(-202 - shellOffset.x,-104 - shellOffset.y), result);
 		result = display.map(null, button2, 6, 8);
 		assertEquals(new Point(-194 - shellOffset.x,-92 - shellOffset.y), result);
-		
+
 		result = display.map(button2, null, 0, 0);
 		assertEquals(new Point(shellOffset.x + 200,shellOffset.y + 100), result);
 		result = display.map(button2, null, -3, -6);
@@ -628,31 +622,31 @@ public void test_mapLorg_eclipse_swt_widgets_ControlLorg_eclipse_swt_widgets_Con
 		button2.setBounds(200,100,100,100);
 		shell.setBounds(0,0,400,400);
 		shell.open();
-		
+
 		Point shellOffset = shell.getLocation();
 		Rectangle result;
-		
+
 		result = display.map(button1, button2, 0, 0, 100, 100);
 		assertEquals(new Rectangle(-200,-100,100,100), result);
 		result = display.map(button1, button2, -10, -20, 130, 140);
 		assertEquals(new Rectangle(-210,-120,130,140), result);
 		result = display.map(button1, button2, 50, 60, 170, 180);
 		assertEquals(new Rectangle(-150,-40,170,180), result);
-		
+
 		result = display.map(button2, button1, 0, 0, 100, 100);
 		assertEquals(new Rectangle(200,100,100,100), result);
 		result = display.map(button2, button1, -5, -15, 125, 135);
 		assertEquals(new Rectangle(195,85,125,135), result);
 		result = display.map(button2, button1, 45, 55, 165, 175);
 		assertEquals(new Rectangle(245,155,165,175), result);
-		
+
 		result = display.map(null, button2, 0, 0, 100, 100);
 		assertEquals(new Rectangle(-200 - shellOffset.x,-100 - shellOffset.y,100,100), result);
 		result = display.map(null, button2, -2, -4, 106, 108);
 		assertEquals(new Rectangle(-202 - shellOffset.x,-104 - shellOffset.y,106,108), result);
 		result = display.map(null, button2, 10, 12, 114, 116);
 		assertEquals(new Rectangle(-190 - shellOffset.x,-88 - shellOffset.y,114,116), result);
-		
+
 		result = display.map(button2, null, 0, 0, 100, 100);
 		assertEquals(new Rectangle(shellOffset.x + 200,shellOffset.y + 100,100,100), result);
 		result = display.map(button2, null, -3, -6, 109, 112);
@@ -757,33 +751,33 @@ public void test_mapLorg_eclipse_swt_widgets_ControlLorg_eclipse_swt_widgets_Con
 		button2.setBounds(200,100,100,100);
 		shell.setBounds(0,0,400,400);
 		shell.open();
-		
+
 		Point result;
 		Point point = new Point(0,0);
 		Point shellOffset = shell.getLocation();
 
-		
+
 		result = display.map(button1, button2, point);
 		assertEquals(new Point(-200,-100), result);
 		result = display.map(button1, button2, new Point(-10,-20));
 		assertEquals(new Point(-210,-120), result);
 		result = display.map(button1, button2, new Point(30,40));
 		assertEquals(new Point(-170,-60), result);
-		
+
 		result = display.map(button2, button1, point);
 		assertEquals(new Point(200,100), result);
 		result = display.map(button2, button1, new Point(-5,-15));
 		assertEquals(new Point(195,85), result);
 		result = display.map(button2, button1, new Point(25,35));
 		assertEquals(new Point(225,135), result);
-		
+
 		result = display.map(null, button2, point);
 		assertEquals(new Point(-200 - shellOffset.x,-100 - shellOffset.y), result);
 		result = display.map(null, button2, new Point(-2,-4));
 		assertEquals(new Point(-202 - shellOffset.x,-104 - shellOffset.y), result);
 		result = display.map(null, button2, new Point(6,8));
 		assertEquals(new Point(-194 - shellOffset.x,-92 - shellOffset.y), result);
-		
+
 		result = display.map(button2, null, point);
 		assertEquals(new Point(shellOffset.x + 200,shellOffset.y + 100), result);
 		result = display.map(button2, null, new Point(-3,-6));
@@ -870,7 +864,7 @@ public void test_mapLorg_eclipse_swt_widgets_ControlLorg_eclipse_swt_widgets_Con
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for map to control being disposed", SWT.ERROR_INVALID_ARGUMENT, e);
 		}
-		
+
 		try {
 			result = display.map(button2, button1, (Point) null);
 			fail("No exception thrown for null point");
@@ -895,32 +889,32 @@ public void test_mapLorg_eclipse_swt_widgets_ControlLorg_eclipse_swt_widgets_Con
 		button2.setBounds(200,100,100,100);
 		shell.setBounds(0,0,400,400);
 		shell.open();
-		
+
 		Rectangle result;
 		Rectangle rect = new Rectangle(0,0,100,100);
 		Point shellOffset = shell.getLocation();
-		
+
 		result = display.map(button1, button2, rect);
 		assertEquals(new Rectangle(-200,-100,100,100), result);
 		result = display.map(button1, button2, new Rectangle(-10, -20, 130, 140));
 		assertEquals(new Rectangle(-210,-120,130,140), result);
 		result = display.map(button1, button2, new Rectangle(50, 60, 170, 180));
 		assertEquals(new Rectangle(-150,-40,170,180), result);
-		
+
 		result = display.map(button2, button1, rect);
 		assertEquals(new Rectangle(200,100,100,100), result);
 		result = display.map(button2, button1, new Rectangle(-5, -15, 125, 135));
 		assertEquals(new Rectangle(195,85,125,135), result);
 		result = display.map(button2, button1, new Rectangle(45, 55, 165, 175));
 		assertEquals(new Rectangle(245,155,165,175), result);
-		
+
 		result = display.map(null, button2, rect);
 		assertEquals(new Rectangle(-200 - shellOffset.x,-100 - shellOffset.y,100,100), result);
 		result = display.map(null, button2, new Rectangle(-2, -4, 106, 108));
 		assertEquals(new Rectangle(-202 - shellOffset.x,-104 - shellOffset.y,106,108), result);
 		result = display.map(null, button2, new Rectangle(10, 12, 114, 116));
 		assertEquals(new Rectangle(-190 - shellOffset.x,-88 - shellOffset.y,114,116), result);
-		
+
 		result = display.map(button2, null, rect);
 		assertEquals(new Rectangle(shellOffset.x + 200,shellOffset.y + 100,100,100), result);
 		result = display.map(button2, null, new Rectangle(-3, -6, 109, 112));
@@ -1007,7 +1001,7 @@ public void test_mapLorg_eclipse_swt_widgets_ControlLorg_eclipse_swt_widgets_Con
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for map to control being disposed", SWT.ERROR_INVALID_ARGUMENT, e);
 		}
-		
+
 		try {
 			result = display.map(button2, button1, (Rectangle) null);
 			fail("No exception thrown for null point");
@@ -1030,9 +1024,9 @@ public void test_postLorg_eclipse_swt_widgets_Event() {
 		}
 		return;
 	}
-	
+
 	final int KEYCODE = SWT.SHIFT;
-	
+
 	Display display = new Display();
 	try {
 		try {
@@ -1041,21 +1035,21 @@ public void test_postLorg_eclipse_swt_widgets_Event() {
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for post with null argument", SWT.ERROR_NULL_ARGUMENT, e);
 		}
-		
+
 		Shell shell = new Shell(display, SWT.NO_TRIM);
 		shell.setBounds(display.getBounds());
 		shell.open();
 
 		Event event;
-		
+
 		// Test key events (down/up)
 		event = new Event();
 		event.type = SWT.KeyDown;
 		event.keyCode = -1;  // bogus key code; default 0 character
 		assertTrue("Display#post failed, probably because screen is not rendered (bug 407862)", display.post(event));  //$NON-NLS-1$
-		// don't test KeyDown/KeyUp with a character to avoid sending to 
+		// don't test KeyDown/KeyUp with a character to avoid sending to
 		// random window if test shell looses focus
-		
+
 		event = new Event();
 		event.type = SWT.KeyUp;
 		assertTrue(display.post(event));
@@ -1067,7 +1061,7 @@ public void test_postLorg_eclipse_swt_widgets_Event() {
 		event.type = SWT.KeyUp;
 		shell.setFocus();
 		assertTrue(display.post(event));
-		
+
 		// Test mouse events (down/up/move)
 		event = new Event();
 		event.type = SWT.MouseMove;
@@ -1076,32 +1070,35 @@ public void test_postLorg_eclipse_swt_widgets_Event() {
 		event.y = bounds.y + bounds.height/2;
 		shell.setFocus();
 		assertTrue(display.post(event));
-		
+
 		event = new Event();
 		event.type = SWT.MouseDown;
 		assertFalse(display.post(event));  // missing button
 		event.button = 1;
 		shell.setFocus();
 		assertTrue(display.post(event));
-		
+
 		event = new Event();
 		event.type = SWT.MouseUp;
 		assertFalse(display.post(event));  // missing button
 		event.button = 1;
 		shell.setFocus();
 		assertTrue(display.post(event));
-		
+
 		// Test unsupported event
 		event = new Event();
 		event.type = SWT.MouseDoubleClick;
 		assertFalse(display.post(event));
-		
+
+		drainEventQueue(display, 500); // attempt to work around https://bugs.eclipse.org/492569
+
 		shell.dispose();
-		
+
+		//TODO: Verify the events. The following comment is wrong:
 		// can't verify that the events were actually sent to a listener.
-		// the test shell won't receive any events if it has lost focus, 
-		// e.g., due to user intervention or another process popping up 
-		// a window. 
+		// the test shell won't receive any events if it has lost focus,
+		// e.g., due to user intervention or another process popping up
+		// a window.
 	} finally {
 		display.dispose();
 	}
@@ -1120,17 +1117,14 @@ public void test_removeFilterILorg_eclipse_swt_widgets_Listener() {
 	final int CLOSE_CALLBACK = 0;
 	final int DISPOSE_CALLBACK = 1;
 	final boolean[] callbackReceived = new boolean[] {false, false};
-	
-	Listener listener = new Listener() {
-		@Override
-		public void handleEvent(Event e) {
-			if (e.type == SWT.Close)
-				callbackReceived[CLOSE_CALLBACK] = true;
-			else if (e.type == SWT.Dispose)
-				callbackReceived[DISPOSE_CALLBACK] = true;
-		}
+
+	Listener listener = e -> {
+		if (e.type == SWT.Close)
+			callbackReceived[CLOSE_CALLBACK] = true;
+		else if (e.type == SWT.Dispose)
+			callbackReceived[DISPOSE_CALLBACK] = true;
 	};
-	
+
 	Display display = new Display();
 	try {
 		try {
@@ -1139,7 +1133,7 @@ public void test_removeFilterILorg_eclipse_swt_widgets_Listener() {
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for removeFilter with null argument", SWT.ERROR_NULL_ARGUMENT, e);
 		}
-		
+
 		display.addFilter(SWT.Close, listener);
 		display.removeFilter(SWT.Close, listener);
 	} finally {
@@ -1154,17 +1148,14 @@ public void test_removeListenerILorg_eclipse_swt_widgets_Listener() {
 	final int CLOSE_CALLBACK = 0;
 	final int DISPOSE_CALLBACK = 1;
 	final boolean[] callbackReceived = new boolean[] {false, false};
-	
-	Listener listener = new Listener() {
-		@Override
-		public void handleEvent(Event e) {
-			if (e.type == SWT.Close)
-				callbackReceived[CLOSE_CALLBACK] = true;
-			else if (e.type == SWT.Dispose)
-				callbackReceived[DISPOSE_CALLBACK] = true;
-		}
+
+	Listener listener = e -> {
+		if (e.type == SWT.Close)
+			callbackReceived[CLOSE_CALLBACK] = true;
+		else if (e.type == SWT.Dispose)
+			callbackReceived[DISPOSE_CALLBACK] = true;
 	};
-	
+
 	Display display = new Display();
 	try {
 		try {
@@ -1173,7 +1164,7 @@ public void test_removeListenerILorg_eclipse_swt_widgets_Listener() {
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for removeListener with null argument", SWT.ERROR_NULL_ARGUMENT, e);
 		}
-		
+
 		display.addListener(SWT.Dispose, listener);
 		display.removeListener(SWT.Dispose, listener);
 	} finally {
@@ -1192,12 +1183,23 @@ public void test_setAppNameLjava_lang_String() {
 public void test_setCursorLocationII() {
 	Display display = new Display();
 	try {
+		// Move mouse back to original location, to prevent mouse being jerked around.
+		Point originalLocation = display.getCursorLocation();
+		display.addListener(SWT.Dispose, e -> display.setCursorLocation(originalLocation));
+
 		Point location = new Point(100, 100);
 		display.setCursorLocation(location.x, location.y); // don't put cursor into a corner, since that could trigger special platform events
+		drainEventQueue(display, 150); // workaround for https://bugs.eclipse.org/492569
 		Point actual = display.getCursorLocation();
-		if (!BUG_492569) {
-			assertEquals(location, actual);
+		if (!BUG_492569 && SwtTestUtil.isX11) {
+			if (!location.equals(actual)) {
+				Screenshots.takeScreenshot(getClass(), testName.getMethodName()); // Bug 528968 This call causes crash on Wayland.
+				fail("\nExpected:"+location.toString()+"  Actual:"+actual.toString());
+			}
+		} else {
+			System.out.println(getClass().getName() + "#" + testName.getMethodName() + ": actual == " + actual);
 		}
+
 	} finally {
 		display.dispose();
 	}
@@ -1207,6 +1209,10 @@ public void test_setCursorLocationII() {
 public void test_setCursorLocationLorg_eclipse_swt_graphics_Point() {
 	Display display = new Display();
 	try {
+		// Move mouse back to original location, to prevent mouse being jerked around.
+		Point originalLocation = display.getCursorLocation();
+		display.addListener(SWT.Dispose, e -> display.setCursorLocation(originalLocation));
+
 		Point location = new Point(100, 50);
 		display.setCursorLocation(location); // don't put cursor into a corner, since that could trigger special platform events
 		try {
@@ -1215,9 +1221,15 @@ public void test_setCursorLocationLorg_eclipse_swt_graphics_Point() {
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for setCursorLocation with null argument", SWT.ERROR_NULL_ARGUMENT, e);
 		}
+		drainEventQueue(display, 150); // workaround for https://bugs.eclipse.org/492569
 		Point actual = display.getCursorLocation();
-		if (!BUG_492569) {
-			assertEquals(location, actual);
+		if (!BUG_492569 && SwtTestUtil.isX11) {
+			if (!location.equals(actual)) {
+				Screenshots.takeScreenshot(getClass(), testName.getMethodName()); // Bug 528968 This call causes crash on Wayland.
+				fail("\nExpected:"+location.toString()+"  Actual:"+actual.toString());
+			}
+		} else {
+			System.out.println(getClass().getName() + "#" + testName.getMethodName() + ": actual == " + actual);
 		}
 	} finally {
 		display.dispose();
@@ -1259,7 +1271,7 @@ public void test_setSynchronizerLorg_eclipse_swt_widgets_Synchronizer() {
 	final Display display = new Display();
 	final boolean[] asyncExec0Ran = new boolean[] {false};
 	final boolean[] asyncExec1Ran = new boolean[] {false};
-	
+
 	try {
 		try {
 			display.setSynchronizer(null);
@@ -1267,7 +1279,7 @@ public void test_setSynchronizerLorg_eclipse_swt_widgets_Synchronizer() {
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for set synchronizer with null argument", SWT.ERROR_NULL_ARGUMENT, e);
 		}
-		
+
 		class MySynchronizer extends Synchronizer {
 			boolean invoked = false;
 			MySynchronizer(Display d) {
@@ -1279,21 +1291,11 @@ public void test_setSynchronizerLorg_eclipse_swt_widgets_Synchronizer() {
 				super.asyncExec(runnable);
 			}
 		}
-		
+
 		MySynchronizer mySynchronizer = new MySynchronizer(display);
-		display.asyncExec(new Runnable() {
-			@Override
-			public void run() {
-				asyncExec0Ran[0] = true;
-			}
-		});
+		display.asyncExec(() -> asyncExec0Ran[0] = true);
 		display.setSynchronizer(mySynchronizer);
-		display.asyncExec(new Runnable() {
-			@Override
-			public void run() {
-				asyncExec1Ran[0] = true;
-			}
-		});
+		display.asyncExec(() -> asyncExec1Ran[0] = true);
 		assertFalse(asyncExec0Ran[0]);
 		assertFalse(asyncExec1Ran[0]);
 		while (display.readAndDispatch()) {}
@@ -1311,7 +1313,7 @@ public void test_sleep() {
 	try {
 		Thread thread;
 		boolean eventQueued;
-		
+
 		// Ensure event queue is empty, otherwise sleep() will just return.
 		while(display.readAndDispatch()) {}
 		thread = new Thread() {
@@ -1328,9 +1330,9 @@ public void test_sleep() {
 		};
 		thread.start();
 		// Note that sleep seems to always return true, at least
-		// on Windows, since wake() uses a null event. 
+		// on Windows, since wake() uses a null event.
 		eventQueued = display.sleep();
-		
+
 		// Ensure event queue is empty, otherwise sleep() will just return.
 		while(display.readAndDispatch()) {}
 		thread = new Thread() {
@@ -1342,13 +1344,10 @@ public void test_sleep() {
 				} catch (InterruptedException ex) {
 				}
 				// Cause OS to generate an event to revive from sleep().
-				display.syncExec(new Runnable() {
-					@Override
-					public void run() {
-						Shell s = new Shell(display);
-						s.open();
-						s.dispose();
-					}
+				display.syncExec(() -> {
+					Shell s = new Shell(display);
+					s.open();
+					s.dispose();
 				});
 			}
 		};
@@ -1364,12 +1363,7 @@ public void test_sleep() {
 public void test_syncExecLjava_lang_Runnable() {
 	final Display display = new Display();
 	try {
-		display.syncExec(new Runnable() {
-			@Override
-			public void run() {
-				display.beep();
-			}
-		});
+		display.syncExec(() -> display.beep());
 	} finally {
 		display.dispose();
 	}
@@ -1379,12 +1373,7 @@ public void test_syncExecLjava_lang_Runnable() {
 public void test_syncExecLjava_lang_Runnable_dispose() {
 	final Display display = new Display();
 	try {
-		display.syncExec(new Runnable() {
-			@Override
-			public void run() {
-				display.dispose();
-			}
-		});
+		display.syncExec(() -> display.dispose());
 	} finally {
 		assertTrue(display.isDisposed());
 	}
@@ -1396,41 +1385,33 @@ public void test_timerExecILjava_lang_Runnable() {
 	try {
 		final boolean[] timerExecRan = new boolean[] {false};
 		final boolean[] threadRan = new boolean[] {false};
-		
+
 		try {
 			display.timerExec(0, null);
 			fail("No exception thrown for timerExec with null runnable");
 		} catch (IllegalArgumentException e) {
 			assertSWTProblem("Incorrect exception thrown for timerExec with null runnable", SWT.ERROR_NULL_ARGUMENT, e);
 		}
-		
-		display.timerExec(-100, new Runnable() {
-			@Override
-			public void run() {
-				timerExecRan[0] = true;
-			}
-		});
-				
+
+		display.timerExec(-100, () -> timerExecRan[0] = true);
+
 		final int delay = 3000;
 		final long startTime = System.currentTimeMillis();
-		display.timerExec(delay, new Runnable() {
-			@Override
-			public void run() {
-				long endTime = System.currentTimeMillis();
-				// debug intermittent test failure
-				if (endTime < (startTime + delay)) {
-					System.out.println("Display.timerExec ran early " + ((startTime + delay) - endTime));
-				}
-				//assertTrue("Timer ran early! ms early: ", endTime >= (startTime + delay));
-				threadRan[0] = true;
+		display.timerExec(delay, () -> {
+			long endTime = System.currentTimeMillis();
+			// debug intermittent test failure
+			if (endTime < (startTime + delay)) {
+				System.out.println("Display.timerExec ran early " + ((startTime + delay) - endTime));
 			}
+			//assertTrue("Timer ran early! ms early: ", endTime >= (startTime + delay));
+			threadRan[0] = true;
 		});
 		while (!threadRan[0]) {
 			// The read and dispatch loop must be running in order
 			// for the runnable in the timer exec to be executed.
 			if (!display.readAndDispatch ()) display.sleep();
 		}
-		
+
 		// Verify the timerExec with less than zero milliseconds didn't execute.
 		assertFalse("< 0 ms timer did execute", timerExecRan[0]);
 	} finally {
