@@ -77,6 +77,17 @@ public void test_addSelectionListenerLorg_eclipse_swt_events_SelectionListener()
 	assertTrue("Expected exception not thrown", exceptionThrown);
 }
 
+@Test
+public void test_addSelectionListenerWidgetSelectedAdapterLorg_eclipse_swt_events_SelectionListener() {
+	listenerCalled = false;
+	SelectionListener listener = SelectionListener.widgetSelectedAdapter(e -> listenerCalled = true);
+
+	scrollBar.addSelectionListener(listener);
+	scrollBar.setSelection(100);
+	assertTrue(":a:", listenerCalled == false);
+	scrollBar.removeSelectionListener(listener);
+}
+
 @Test
 public void test_getParent() {
 	assertEquals(canvas, scrollBar.getParent());
@@ -100,7 +111,7 @@ public void test_isEnabled() {
 @Test
 public void test_isVisible() {
 	scrollBar.setVisible(true);
-	assertTrue(scrollBar.isVisible()); 
+	assertTrue(scrollBar.isVisible());
 	scrollBar.setVisible(false);
 	assertTrue(!scrollBar.isVisible());
 }
@@ -121,7 +132,7 @@ public void test_setIncrementI() {
 	{
 		scrollBar.setIncrement(cases[i]);
 		assertEquals(cases[i], scrollBar.getIncrement());
-	} 
+	}
 
 	scrollBar.setIncrement(25);
 	scrollBar.setIncrement(0); // setting to 0 fails silently
@@ -161,7 +172,7 @@ public void test_setPageIncrementI(){
 	{
 		scrollBar.setPageIncrement(cases[i]);
 		assertEquals(scrollBar.getPageIncrement(), cases[i]);
-	} 
+	}
 
 	scrollBar.setPageIncrement(25);
 	scrollBar.setPageIncrement(0); // setting to 0 fails silently
