@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,9 @@ package org.eclipse.swt.tests.junit;
 
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 
 import java.io.IOException;
@@ -30,6 +32,7 @@ import org.eclipse.swt.graphics.Region;
 import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Display;
+import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Shell;
 import org.junit.Assert;
 import org.junit.Before;
@@ -63,7 +66,7 @@ public void test_Constructor() {
 @Test
 public void test_ConstructorI() {
 	/* this should test various combinations of STYLE bits, for now just test individual bits */
-	int[] cases = {SWT.NO_TRIM, SWT.RESIZE, SWT.TITLE, SWT.CLOSE, SWT.MENU, SWT.MIN, SWT.BORDER, 
+	int[] cases = {SWT.NO_TRIM, SWT.RESIZE, SWT.TITLE, SWT.CLOSE, SWT.MENU, SWT.MIN, SWT.BORDER,
 				   SWT.CLIP_CHILDREN, SWT.CLIP_SIBLINGS, SWT.ON_TOP, SWT.FLAT, SWT.SMOOTH};
 	Shell newShell;
 	for (int i = 0; i < cases.length; i++) {
@@ -83,7 +86,7 @@ public void test_ConstructorLorg_eclipse_swt_widgets_Display() {
 
 @Test
 public void test_ConstructorLorg_eclipse_swt_widgets_DisplayI() {
-	int[] cases = {SWT.NO_TRIM, SWT.RESIZE, SWT.TITLE, SWT.CLOSE, SWT.MENU, SWT.MIN, SWT.BORDER, 
+	int[] cases = {SWT.NO_TRIM, SWT.RESIZE, SWT.TITLE, SWT.CLOSE, SWT.MENU, SWT.MIN, SWT.BORDER,
 				   SWT.CLIP_CHILDREN, SWT.CLIP_SIBLINGS, SWT.ON_TOP, SWT.FLAT, SWT.SMOOTH};
 	Shell newShell;
 	Display display = shell.getDisplay();
@@ -104,7 +107,7 @@ public void test_ConstructorLorg_eclipse_swt_widgets_Shell() {
 @Test
 public void test_ConstructorLorg_eclipse_swt_widgets_ShellI() {
 	/* this should test various combinations of STYLE bits, for now just test individual bits */
-	int[] cases = {SWT.NO_TRIM, SWT.RESIZE, SWT.TITLE, SWT.CLOSE, SWT.MENU, SWT.MIN, SWT.BORDER, 
+	int[] cases = {SWT.NO_TRIM, SWT.RESIZE, SWT.TITLE, SWT.CLOSE, SWT.MENU, SWT.MIN, SWT.BORDER,
 				   SWT.CLIP_CHILDREN, SWT.CLIP_SIBLINGS, SWT.ON_TOP, SWT.FLAT, SWT.SMOOTH};
 	Shell newShell;
 	for (int i = 0; i < cases.length; i++) {
@@ -148,7 +151,7 @@ public void test_addShellListenerLorg_eclipse_swt_events_ShellListener() {
 	shell.forceActive();
 	/* can't assume listener is synchronously called when forceActive returned */
 	/* assertTrue(":a:", listenerCalled == true); */
-	
+
 	listenerCalled = false;
 	shell.removeShellListener(listener);
 	shell.forceActive();
@@ -163,6 +166,246 @@ public void test_addShellListenerLorg_eclipse_swt_events_ShellListener() {
 	assertTrue("Expected exception not thrown", exceptionThrown);
 }
 
+@Test
+public void test_addShellListenerShellActivatedAdapterLorg_eclipse_swt_events_ShellListener() {
+	ShellListener listener = ShellListener.shellActivatedAdapter(e -> eventOccurred = true);
+	shell.addShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertFalse(eventOccurred);
+
+	shell.removeShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertFalse(eventOccurred);
+}
+
+@Test
+public void test_addShellListenerShellDeactivatedAdapterLorg_eclipse_swt_events_ShellListener() {
+	ShellListener listener = ShellListener.shellDeactivatedAdapter(e -> eventOccurred = true);
+	shell.addShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertFalse(eventOccurred);
+
+	shell.removeShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertFalse(eventOccurred);
+}
+
+@Test
+public void test_addShellListenerShellDeiconifiedAdapterLorg_eclipse_swt_events_ShellListener() {
+	ShellListener listener = ShellListener.shellDeiconifiedAdapter(e -> eventOccurred = true);
+	shell.addShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertFalse(eventOccurred);
+
+	shell.removeShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertFalse(eventOccurred);
+}
+
+@Test
+public void test_addShellListenerShellIconifiedAdapterLorg_eclipse_swt_events_ShellListener() {
+	ShellListener listener = ShellListener.shellIconifiedAdapter(e -> eventOccurred = true);
+	shell.addShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertFalse(eventOccurred);
+
+	shell.removeShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertFalse(eventOccurred);
+}
+
+@Test
+public void test_addShellListenerShellClosedAdapterLorg_eclipse_swt_events_ShellListener() {
+	ShellListener listener = ShellListener.shellClosedAdapter(e -> eventOccurred = true);
+	shell.addShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertTrue(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertFalse(eventOccurred);
+
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.removeShellListener(listener);
+	eventOccurred = false;
+
+	shell.notifyListeners(SWT.Activate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deactivate, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Deiconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Iconify, new Event());
+	assertFalse(eventOccurred);
+
+	shell.notifyListeners(SWT.Close, new Event());
+	assertFalse(eventOccurred);
+}
+
 @Test
 public void test_close() {
 
@@ -264,18 +507,18 @@ public void test_setActive() {
 	/* Create shell2 and make it active. */
 	Shell shell2 = new Shell();
 	shell2.open();
-	
+
 	/* Test setActive for visible shell. */
 	shell.setVisible(true);
 	shell.setActive();
 	assertTrue("visible shell was not made active", shell.getDisplay().getActiveShell() == shell);
-	
+
 	/* Test setActive for visible dialog shell. */
 	shell2.setActive();
 	testShell.setVisible(true);
 	testShell.setActive();
 	assertTrue("visible dialog shell was not made active", testShell.getDisplay().getActiveShell() == testShell);
-	
+
 	/* Test setActive for non-visible shell. */
 	shell2.setActive();
 	shell.setVisible(false);
@@ -287,7 +530,7 @@ public void test_setActive() {
 	testShell.setVisible(false);
 	testShell.setActive();
 	assertTrue("non-visible dialog shell was made active", testShell.getDisplay().getActiveShell() != testShell);
-	
+
 	shell2.dispose();
 }
 
@@ -318,7 +561,7 @@ public void test_setVisibleZ() {
 @Test
 public void test_getParent () {
 	// overriding Control.test_getParent
-	assertTrue(shell.getParent()==null);
+	assertNull(shell.getParent());
 	assertTrue(testShell.getParent() == shell);
 }
 
@@ -393,7 +636,6 @@ public void test_setBoundsLorg_eclipse_swt_graphics_Rectangle() {
  */
 @Test
 public void test_setBounds() throws Exception {
-	if (IS_GTK_BUG_445900) System.out.println("Running Test_org_eclipse_swt_widgets_Shell.test_setBounds():");
 
 	Rectangle bounds = new Rectangle(100, 200, 200, 200);
 	Rectangle bounds2 = new Rectangle(150, 250, 250, 250);
@@ -435,21 +677,21 @@ public void a_test_setRegion() {
 	Region region = new Region();
 	region.add(new Rectangle(10, 20, 100, 200));
 	// test shell without style SWT.NO_TRIM
-	assertTrue(":a:", shell.getRegion() == null);
+	assertNull(":a:", shell.getRegion());
 	shell.setRegion(region);
-	assertTrue(":b:", shell.getRegion() == null);
+	assertNull(":b:", shell.getRegion());
 	shell.setRegion(null);
-	assertTrue(":c:", shell.getRegion() == null);
+	assertNull(":c:", shell.getRegion());
 	// test shell with style SWT.NO_TRIM
 	Display display = shell.getDisplay();
 	Shell shell2 = new Shell(display, SWT.NO_TRIM);
-	assertTrue(":d:", shell2.getRegion() == null);
+	assertNull(":d:", shell2.getRegion());
 	shell2.setRegion(region);
 	assertTrue(":e:", shell2.getRegion().handle == region.handle);
 	region.dispose();
 	assertTrue(":f:", shell2.getRegion().isDisposed());
 	shell2.setRegion(null);
-	assertTrue(":g:", shell2.getRegion() == null);
+	assertNull(":g:", shell2.getRegion());
 }
 @Override
 @Test
@@ -473,7 +715,7 @@ public void test_setSizeII() {
 			newSize.y -= 100;
 		}
 	}
-	
+
 }
 
 @Override
@@ -510,7 +752,7 @@ private void createShell() {
 	testShell.setText("Shell");
     testShell.setLayout(new FillLayout());
     setWidget(testShell);
-   
+
 }
 
 @Test
@@ -534,11 +776,11 @@ public void test_consistency_Open() {
 				    }
 				});
 	    }}.start();
-	
+
 	    while(!shell.isDisposed()) {
 	        if(!display.readAndDispatch()) display.sleep();
 	    }
-	    setUp();        
+	    setUp();
 	    String[] results = events.toArray(new String[events.size()]);
 	    assertArrayEquals(getTestName() + " event ordering", temp, results);
 	}
@@ -577,4 +819,19 @@ public void test_consistency_Dispose() {
     consistencyEvent(pt.x, pt.y, 1, 0, ConsistencyUtility.MOUSE_CLICK, events);
     createShell();
 }
+
+@Test
+public void test_setAlpha() {
+    createShell();
+    testShell.setAlpha(128);
+    int alpha = testShell.getAlpha();
+    if (SwtTestUtil.isGTK && alpha == 255) {
+    	System.out.println("Test_org_eclipse_swt_widgets_Shell.test_setAlpha(): expected 128, but was 255. "
+    			+ "Probably missing window manager functionality, see bug 498208.");
+    } else {
+    	assertEquals(128, alpha);
+    }
+    testShell.setAlpha(255);
+    assertEquals(255, testShell.getAlpha());
+}
 }
